<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" >
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddHeader.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS1120FScheduleHStyle.xsl"/>

  <xsl:output method="html" indent="yes" />
  <xsl:strip-space elements="*" />

  <!-- Defines the stage of the data, e.g. original or latest -->
  <xsl:param name="FormData" select="$RtnDoc/IRS1120FScheduleH" />
  <xsl:template match="/">
    <html>
      <head>
        <title>
          <xsl:call-template name="FormTitle">
            <xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param>
          </xsl:call-template>
        </title>
        <!-- No Browser Caching -->
        <meta http-equiv="Pragma" content="no-cache" />
        <meta http-equiv="Cache-Control" content="no-cache" />
        <meta http-equiv="Expires" content="0" />
        <!-- No Proxy Caching -->
        <meta http-equiv="Cache-Control" content="private" />
        <!-- Define Character Set -->
        <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
        <meta name="Description" content="Form IRS1120FScheduleH" />        
        <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
        <xsl:call-template name="InitJS"></xsl:call-template>
        <style type="text/css">    
          <xsl:if test="not($Print) or $Print=''">
            <xsl:call-template name="IRS1120FScheduleHStyle"></xsl:call-template>
            <xsl:call-template name="AddOnStyle"></xsl:call-template>        
          </xsl:if>
        </style>
        <xsl:call-template name="GlobalStylesForm"/>
      </head>
      <body class="styBodyClass">
      <form name="Form1120FScheduleH">
        <!-- BEGIN WARNING LINE -->
        <xsl:call-template name="DocumentHeader"  />  
        <!-- END WARNING LINE -->
      
        <!--Begin Header-->
        <div class="styTBB" style="width:187mm;">
          <table cellspacing="0" cellpadding="0">
	     <tbody>    
              <tr>
              <!--Form Number-->
                <th rowspan="2" class="sty1120FSchHFNBox" style="width:36mm" scope="col">
                  SCHEDULE H
                  <br />
                  (Form 1120-F)
                  <div class="sty1120FSchHAgency" style="padding-top:1.5mm">Department of the Treasury</div>
                  <div class="sty1120FSchHAgency">Internal Revenue Service</div>
                </th>
                <!--Form Name-->
                <th rowspan="2" class="sty1120FSchHFTBox" style="width:119mm" scope="col">
                  <div class="sty1120FSchHMainTitle">
                    Deductions Allocated To Effectively Connected<br />Income Under Regulations Section 1.861-8
                  </div>
                  <div class="styFST" style="padding-top:0.5mm">
                    <img src="{$ImagePath}/1120FScheduleH_Bullet.gif" alt="Bullet Image" />
                    Attach to Form 1120-F.
                    <br />
                    <img src="{$ImagePath}/1120FScheduleH_Bullet.gif" alt="Bullet Image" />
                    See separate instructions.
                  </div>
                </th>
                <!--OMB/Tax Year-->
                <th class="sty1120FSchHOMB" style="width:32mm" scope="col">
                    OMB No. 1545-0126
                </th>
              </tr>
              <tr>
                <td  class="sty1120FSchHTY">
                  20<span class="styTYColor">07</span>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
        <!--End header-->

        <!--Begin Name/EIN-->
        <div style="width:187mm">
          <div class="styTableCell" style="width:135mm;float:left;height:10mm;text-align:left">
            Name of corporation
            <br />
              <xsl:call-template name="PopulateReturnHeaderFiler">
                <xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param>
              </xsl:call-template>
            <br />
              <xsl:call-template name="PopulateReturnHeaderFiler">
                <xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param>
              </xsl:call-template>
          </div>
          <div class="styTableCell" style="width:52mm;border-right-width:0px;padding-left:2mm;float:left;height:10mm;text-align:left">
            <b>Employer identification number</b>
            <br />
            <br />
              <xsl:call-template name="PopulateReturnHeaderFiler">
                <xsl:with-param name="TargetNode">EIN</xsl:with-param>
              </xsl:call-template>
          </div>
        </div>
        <!--End Name/EIN-->
        
                
        <!--Begin Part 1-->
        
        <!--Part 1 Header-->
        <div class="styBB" style="width:187mm">
          <div class="styPartName">Part I</div>
          <div class="styPartDesc">
            Deductions Directly Allocated and Apportioned to ECI and Non-ECI<br />
            <span style="font-size:6pt">Note. 
              <span style="font-weight:normal">
              <label>
                <xsl:call-template name="PopulateLabel">
                  <xsl:with-param name="TargetNode" select="$FormData/InUSDollars" />
                  <xsl:with-param name="BackupName">IRS1120FSchHUSDollars</xsl:with-param>
                </xsl:call-template>Enter all amounts in Part I in only U.S. dollars or in only functional currency. If U.S. dollars, check box
              </label>
              </span>
              <span style="width:1mm" />
              <input type="checkbox" class="styCkbox">
                <xsl:call-template name="PopulateCheckbox">
                  <xsl:with-param name="TargetNode" select="$FormData/InUSDollars" />
                  <xsl:with-param name="BackupName">IRS1120FSchHUSDollars</xsl:with-param>
                </xsl:call-template>
              </input>
              <span>.</span>
              <span style="font-weight:normal"> Otherwise, specify currency</span>
              <span style="width:1mm" />
                <img src="{$ImagePath}/1120FScheduleH_Bullet_Md.gif" alt="Bullet Image" />
            </span>
            <!-- check string length to determine string display -->
            <xsl:if test="$FormData/FunctionalCurrency">
              <xsl:choose>
                <xsl:when test="string-length($FormData/FunctionalCurrency) > 9">
                  <br /> 
                  <div class="styPartDesc" style="width:169mm;text-align:right;">
                    <span style="font-weight:normal; font-size:6pt">
                      <xsl:call-template name="PopulateText">
                        <xsl:with-param name="TargetNode" select="$FormData/FunctionalCurrency" />
                      </xsl:call-template>         
                    </span>
                  </div>
                </xsl:when>
                <xsl:otherwise>
                  <span style="width:0.5mm;" />
                  <span style="font-weight:normal; font-size:6pt;">
                    <xsl:call-template name="PopulateText">
                      <xsl:with-param name="TargetNode" select="$FormData/FunctionalCurrency" />
                    </xsl:call-template>
                  </span>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </div>
        </div>
        <!--Begin Lines 1-14-->
        <div class="styTBB" style="width:187mm">
          <table cellpadding="0" cellspacing="0" style="width:187mm;font-size:7pt">
            <tbody>
            <!-- Begin if it is USCurrency -->
            
            
            <!--Line 1-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">1</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Total expenses on the books of the home office
                  <span class="sty1120FSchHDotLn" style="padding-left:2.1mm">........</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">1</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/TotExpensesOnBksOfHomeOffice" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/TotExpensesOnBksOfHomeOfficeF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 2-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">2</td>
                <td class="sty1120FSchHLNDescShort" style="font-size:6pt" scope="row">
                  Adjustments for U.S. tax principles (attach schedule - see instructions)
                  <span class="sty1120FSchHDotLn" style="padding-left:0.8mm;font-size:7pt">....</span>
                  <span style="width:1.1mm" />
                    <xsl:if test="$FormData/InUSDollars">
                      <xsl:call-template name="SetFormLinkInline">
                        <xsl:with-param name="TargetNode" select="$FormData/PartIAdjustmentsForUSTaxPrin" />
                      </xsl:call-template>
                    </xsl:if>
                    <xsl:if test="$FormData/FunctionalCurrency">
                      <xsl:call-template name="SetFormLinkInline">
                        <xsl:with-param name="TargetNode" select="$FormData/PartIAdjustmentsForUSTaxPrinF" />
                      </xsl:call-template>
                    </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBox">2</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/PartIAdjustmentsForUSTaxPrin" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/PartIAdjustmentsForUSTaxPrinF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 3-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">3</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Total adjusted deductions on the books of the home office. Combine lines 1 and 2
                  <span class="sty1120FSchHDotLn" style="padding-left:0.9mm">.......</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">3</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/TotalAdjustedDeductions" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/TotalAdjustedDeductionsF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              <!--Line 4-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">4</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Interest expense (included in line 3)
                  <span class="sty1120FSchHDotLn" style="padding-left:0.5mm">............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">4</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/InterestExpense" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/InterestExpenseF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
               <!--Line 5-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">5</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Bad debt expense (included in line 3)
                  <span class="sty1120FSchHDotLn" style="padding-left:3.7mm">...........</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">5</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/BadDebtExpense" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/BadDebtExpenseF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 6-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">6</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Total of interest expense and bad debt expense. Add lines 4 and 5
                  <span class="sty1120FSchHDotLn" style="padding-left:0.8mm">............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">6</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/TotalIntAndBadDebtExpense" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/TotalIntAndBadDebtExpenseF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              <!--Line 7-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">7</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  General and administrative deductions included in line 3. Subtract line 6 from line 3
                  <span class="sty1120FSchHDotLn" style="padding-left:1.9mm">......</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">7</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/GeneralAndAdminDeductions" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/GeneralAndAdminDeductionsF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              <!--Line 8-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox">8</td>
                <td class="sty1120FSchHLNDescShort" style="font-size:6pt" scope="row">
                  Deductions directly allocable to non-effectively connected income from subsidiaries
                  <span class="sty1120FSchHDotLn" style="padding-left:3.5mm;font-size:7pt">.</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">8</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedAllcblToNonECISubsidiaries" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedAllcblToNonECISubsidiariesF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 9-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBox" style="padding-bottom:3.5mm">9</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Deductions directly allocable to other non-effectively connected income booked in the home country
                  <span class="sty1120FSchHDotLn" style="padding-left:0.3mm">...............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">9</td>
                <td class="sty1120FSchHLNAmountBox" style="padding-top:3.5mm"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedAllcblToOthNonECIHomeCntry" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedAllcblToOthNonECIHomeCntryF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 10-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD" style="padding-bottom:3.5mm">10</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Deductions directly allocable to other non-effectively connected income booked in other countries (including the United States)
                  <span class="sty1120FSchHDotLn" style="padding-left:0.1mm">......</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">10</td>
                <td class="sty1120FSchHLNAmountBox" style="padding-top:3.5mm"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedAllcblToOthNonECIOthCntrs" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedAllcblToOthNonECIOthCntrsF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 11-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">11</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Add lines 8 through 10
                  <span class="sty1120FSchHDotLn" style="padding-left:2.3mm">..........................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">11</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedDirectlyAllcblToNonECISum" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedDirectlyAllcblToNonECISumF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              <!--Line 12-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD" style="padding-bottom:3.5mm">12</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Remaining deductions on the books of the home office allocable under Regulations section 1.861-8. Subtract line 11 from line 7
                  <span class="sty1120FSchHDotLn" style="padding-left:0.5mm">.........................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">12</td>
                <td class="sty1120FSchHLNAmountBox" style="padding-top:3.5mm"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/RmngDedAllcblUnderSect18618" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/RmngDedAllcblUnderSect18618F" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              <!--Line 13-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">13</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Less: Deductions directly allocated to effectively connected income
                  <span class="sty1120FSchHDotLn" style="padding-left:2.3mm">...........</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">13</td>
                <td class="sty1120FSchHLNAmountBox"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedDirectlyAllocatedToECI" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/DedDirectlyAllocatedToECIF" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              <!--Line 14-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD" style="padding-bottom:3.5mm">14</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Remaining deductions on the books of the home office indirectly allocable under Regulations section 1.861-8. Subtract line 13 from line 12
                  <span class="sty1120FSchHDotLn" style="padding-left:1.5mm">.....................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxNBB">14</td>
                <td class="sty1120FSchHLNAmountBoxNBB" style="padding-top:3.5mm"><span style="width:1px" />
                  <xsl:if test="$FormData/InUSDollars">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/RmngDedIndrAllcblUndSect18618" />
                    </xsl:call-template>
                  </xsl:if>
                  <xsl:if test="$FormData/FunctionalCurrency">
                    <xsl:call-template name="PopulateAmount">
                      <xsl:with-param name="TargetNode" select="$FormData/RmngDedIndrAllcblUndSect18618F" />
                    </xsl:call-template>
                  </xsl:if>
                </td>
              </tr>
              
              <!-- End if it is USCurrency -->
              
              <!--End Lines 1-14-->
              
              <!--End Part I-->
              
              <!--Begin Part II-->
              
              <!--Part II Header-->
              <tr>
                <td class="styBB" colspan="6" style="border-top-width:1px">
                  <div class="styPartName">Part II</div>
                  <div class="styPartDesc">
                    Home Office Deductions Indirectly Allocated and Apportioned to ECI and Non-ECI<br />
                    Note.<span style="font-weight:normal"> Enter the amounts in Part II, lines 16 through 21, in U.S. dollars.</span>
                  </div>
                </td>
              </tr>
        
              <!--Begin Lines 15-21-->
              
              <!--Line 15-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">15</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Average exchange rate used to convert allocable deductions to U.S. dollars (see instructions)
                  <span class="sty1120FSchHDotLn" style="padding-left:0.1mm">...</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">15</td>
                <td class="sty1120FSchHLNAmountBox" style="font-size:6pt">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/AverageExchangeRateUsed" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 16-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD" style="padding-bottom:3.5mm">16</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  <b>Deductions indirectly allocable under Regulations section 1.861-8.</b> Enter the amount from line<br />
                  14 in U.S. dollars. If line 14 is stated in functional currency, multiply line 14 by line 15
                  <span class="sty1120FSchHDotLn" style="padding-left:1.3mm">.....</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">16</td>
                <td class="sty1120FSchHLNAmountBox" style="padding-top:3.5mm">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DedIndrAllocableUnderSect18618" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 17-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">17</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Indirect allocation and apportionment of line 16 amount to ECI (attach computation)
                  <span class="sty1120FSchHDotLn" style="padding-left:0.6mm">.....</span>
                  <span style="width:0.8mm" />
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/IndirectAllocationToECI" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBox">17</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/IndirectAllocationToECI" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 18-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD"  style="padding-bottom:3.5mm">18</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Deductions directly allocated to ECI from line 13, in U.S. dollars. If stated in foreign currency,<br />
                  multiply line 13 by line 15
                  <span class="sty1120FSchHDotLn" style="padding-left:2.2mm">.........................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">18</td>
                <td class="sty1120FSchHLNAmountBox" style="padding-top:3.5mm">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DedDirectlyAllocToECIInUSDol" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 19-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">19</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Total home office deductions allocated to effectively connected income. Add lines 17 and 18
                  <span class="sty1120FSchHDotLn" style="padding-left:1.6mm">...</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">19</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalHomeOfficeDedAllocToECI" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 20-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD" style="padding-bottom:3.5mm">20</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Total deductions from other non-U.S. locations allocated and apportioned to effectively connected income
                  <span class="sty1120FSchHDotLn" style="padding-left:3.5mm">...............................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">20</td>
                <td class="sty1120FSchHLNAmountBox" style="padding-top:3.5mm">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalDedOthNonUSLocAllocToECI" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 21-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD" style="padding-bottom:3.5mm">21</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  <b>Total deductions allocated and apportioned to effectively connected income.</b> Add lines 19 and 20 and enter the amount here and on Form 1120F, section II, line 26
                  <span class="sty1120FSchHDotLn" style="padding-left:1.4mm">............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxNBB">21</td>
                <td class="sty1120FSchHLNAmountBoxNBB" style="padding-top:3.5mm">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalDeductionsAllocatedToECI" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--End Lines 15-21-->
              
              <!--End Part II-->
              
              <!--Begin Part III-->
              
              <!--Part III Header-->
              <tr>
                <td class="styBB" colspan="6" style="border-top-width:1px">
                  <div class="styPartName">Part III</div>
                  <div class="styPartDesc">
                    Indirect Allocation and Apportionment Methods and Financial Records<br />
                    Note.<span style="font-weight:normal"> Enter the amounts in Part III, lines 22a, 22b, 23a, 23b, and 25 (if applicable), in U.S. dollars.</span>
                  </div>
                </td>
              </tr>
              
              <!--Part III Notes-->
              <tr>
                <td class="styBB" colspan="6" style="padding-top:1mm">
                  <div style="float:right;clear:none">
                    <span class="sty1120FSchHDotLn">.....................</span>
                    <span style="width:2mm" />
                    <input type="checkbox" class="styCkbox">
                      <xsl:call-template name="PopulateCheckbox">
                        <xsl:with-param name="TargetNode" select="$FormData/MethodDifferentFromPriorYear" />
                        <xsl:with-param name="BackupName">IRS1120FSchHPriorMethodDiff</xsl:with-param>
                      </xsl:call-template>
                    </input> 
                  </div>
                  <img src="{$ImagePath}/1120FSchH_Bullet_Round.gif" alt="Bullet Image" />
                  <span style="width:1mm" />
                  <label>
                    <xsl:call-template name="PopulateLabel">
                      <xsl:with-param name="TargetNode" select="$FormData/MethodDifferentFromPriorYear" />
                      <xsl:with-param name="BackupName">IRS1120FSchHPriorMethodDiff</xsl:with-param>
                    </xsl:call-template>If one or more methods used are different than in prior year, check box
		     </label>
                  <div style="float:none;clear:right">
                    <img src="{$ImagePath}/1120FSchH_Bullet_Round.gif" alt="Bullet Image" />
                    <span style="width:1mm" />
                    <label>
                      <xsl:call-template name="PopulateLabel">
                        <xsl:with-param name="TargetNode" select="$FormData/IsRecordedAsInterbranchAmount" />
                        <xsl:with-param name="BackupName">IRS1120FSchHIsInterbranchAmount</xsl:with-param>
                      </xsl:call-template>If any amount on line 21 is recorded as an interbranch amount on books and records used to prepare Form 1120F, Schedule
                    </label>
                  </div>
                  <div style="float:right;clear:none">
                    <span class="sty1120FSchHDotLn">..............................</span>
                    <span style="width:2mm" />
                    <input type="checkbox" class="styCkbox">
                      <xsl:call-template name="PopulateCheckbox">
                        <xsl:with-param name="TargetNode" select="$FormData/IsRecordedAsInterbranchAmount" />
                        <xsl:with-param name="BackupName">IRS1120FSchHIsInterbranchAmount</xsl:with-param>
                      </xsl:call-template>
                    </input>
                  </div>
                  <span style="width:3.3mm" />
                  L, include on Part IV, line 36 and check box
                </td>
              </tr>
        
              <!--Begin Lines 22-26-->
              
              <!--Line 22-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">22</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">Gross Income Ratio:</td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 22a-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">a</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Effectively connected gross income
                  <span class="sty1120FSchHDotLn" style="padding-left:1.7mm">............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">22a</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/EffConnectedGrossIncome" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 22b-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">b</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Worldwide gross income
                  <span class="sty1120FSchHDotLn" style="padding-left:1.1mm">................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">22b</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/WorldwideGrossIncome" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 22c-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">c</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Divide line 22a by line 22b
                  <span class="sty1120FSchHDotLn" style="padding-left:1.1mm">.........................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">22c</td>
                <td class="sty1120FSchHLNAmountBox">
                  <div style="float:right;padding-top:0.5mm">
                    <xsl:call-template name="PopulatePercent">
                      <xsl:with-param name="TargetNode" select="$FormData/GrossIncomeRatio" />
                    </xsl:call-template>
                  </div>
                </td>
              </tr>
              <!--Line 23-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">23</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">Gross Asset Ratio:</td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 23a-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">a</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Average U.S. assets from Schedule I, line 5, column (d)
                  <span class="sty1120FSchHDotLn" style="padding-left:3mm">.....</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">23a</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/AverageUSAssets" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 23b-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">b</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Worldwide assets (if applicable, from Schedule I, line 6b)
                  <span class="sty1120FSchHDotLn" style="padding-left:1.5mm">.....</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">23b</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/WorldwideAssets" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 23c-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">c</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Divide line 23a by line 23b
                  <span class="sty1120FSchHDotLn" style="padding-left:1.1mm">.........................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">23c</td>
                <td class="sty1120FSchHLNAmountBox">
                  <div style="float:right;padding-top:0.5mm">
                    <xsl:call-template name="PopulatePercent">
                      <xsl:with-param name="TargetNode" select="$FormData/GrossAssetRatio" />
                    </xsl:call-template>
                  </div>
                </td>
              </tr>
              <!--Line 24-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">24</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">Number of Personnel:</td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 24a-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">a</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Personnel of U.S. trade or business within the United States
                  <span class="sty1120FSchHDotLn" style="padding-left:1.4mm">....</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">24a</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/NumberOfPersonnelWithinUS" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 24b-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">b</td>
                <td class="sty1120FSchHLNDescShort" scope="row">
                  Worldwide personnel of foreign corporation
                  <span class="sty1120FSchHDotLn" style="padding-left:0.7mm">..........</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">24b</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/NumberOfWorldwidePersonnel" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 24c-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">c</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Divide line 24a by line 24b
                  <span class="sty1120FSchHDotLn" style="padding-left:1.1mm">.........................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBox">24c</td>
                <td class="sty1120FSchHLNAmountBox">
                  <div style="float:right;padding-top:0.5mm">
                    <xsl:call-template name="PopulatePercent">
                      <xsl:with-param name="TargetNode" select="$FormData/NumberOfPersonnelRatio" />
                    </xsl:call-template>
                  </div>
                </td>
              </tr>
              <!--Line 25-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">25</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Other ratio based methods (attach schedule)
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherRatioBasedMethods" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB" style="background-color:lightgrey"><span style="width:1px" /></td>
              </tr>
              <!--Line 26-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">26</td>
                <td class="sty1120FSchHLNDesc" colspan="3" scope="row">
                  Other methods (e.g., time spent analysis) (attach schedule)
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherMethods" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB" style="background-color:lightgrey"><span style="width:1px" /></td>
              </tr>
            </tbody>
          </table>
        </div>
        <!--End Lines 22-26-->
        
        <!--Begin Page 1 Footer-->
        <div style="width:187mm;clear:both;padding-top:1mm;font-size:6pt">
          <div style="width:118mm;" class="styGenericDiv"><b>For Privacy Act and Paperwork Reduction Act Notice, see the instructions for Form 1120-F.</b></div>
          <div style="width:24mm;text-align:center;font-size:6pt" class="styGenericDiv">Cat. No. 49679V</div>
          <div style = "float:right;" class="styGenericDiv"><b>Schedule H (Form 1120-F) 2007</b></div>
        </div><br />
        <div class="pageEnd"></div>
        <!-- End Page 1 Footer-->

        <!--BEGIN PAGE 2-->
        
        <!--Page 2 Header-->
        <div class="styTBB" style="width:187mm">
          <div style="float:right;clear:none">
            Page <span style="font-size:8pt;font-weight:bold">2</span>
          </div>
          <div>Schedule H (Form 1120-F) 2007</div>
        </div>
        
        <!--Part III Header Continued-->
        <div class="styBB" style="width:187mm">
          <div class="styPartName">Part III</div>
          <div class="styPartDesc">
            Indirect Allocation and Apportionment Methods and Financial Records
            <span style="font-weight:normal"><i>(continued)</i></span>
          </div>
        </div>
        
        <!--Part III Secondary Header-->
        <div class="styBB" style="width:187mm">
          <div class="styPartDesc" style="width:187mm;font-weight:normal;text-align:center">
            Financial and other records used to identify deductions allocated and apportioned to ECI
          </div>
        </div>
        
        <!--Begin Lines 27-29-->
        <div class="styBB" style="width:187mm">
          <table cellpadding="0" cellspacing="0" style="width:187mm;font-size:7pt">
            <tbody>
            <!--Header-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD"></td>
                <td class="sty1120FSchHLNDescLong"></td>
                <td class="sty1120FSchHLNRightNumBox">Yes</td>
                <td class="sty1120FSchHLNRightNumBox">No</td>
              </tr>
              <!--Line 27a-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">27a</td>
                <td class="sty1120FSchHLNDescLong" scope="row">
                  Published or other non-public audited financial statements
                  <span class="sty1120FSchHDotLn" style="padding-left:2.5mm">....................</span>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateYesBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/AuditedFinancialStatements" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateNoBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/AuditedFinancialStatements" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 27b-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter">b</td>
                <td class="sty1120FSchHLNDescLong" scope="row">
                  Non-audited financial statements
                  <span class="sty1120FSchHDotLn" style="padding-left:3.8mm">............................</span>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateYesBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/NonAuditedFinancialStatements" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateNoBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/NonAuditedFinancialStatements" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 28-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">28</td>
                <td class="sty1120FSchHLNDescLong" scope="row">
                  Home office management or other departmental cost accounting reports
                  <span class="sty1120FSchHDotLn" style="padding-left:0.5mm">................</span>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateYesBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/HomeOfficeMgmtCostAcctReports" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateNoBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/HomeOfficeMgmtCostAcctReports" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 29-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">29</td>
                <td class="sty1120FSchHLNDescLong" scope="row">
                  Other (e.g., home country regulatory reports) (attach schedule)
                  <span class="sty1120FSchHDotLn" style="padding-left:4mm">.................</span>
                  <span style="width:0.5mm" />
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherRecords" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateYesBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherRecords" />
                  </xsl:call-template> 
                </td>
                <td class="sty1120FSchHLNYesNoBox">
                  <xsl:call-template name="PopulateNoBoxText">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherRecords" />
                  </xsl:call-template>
                </td>
              </tr>
              <tr style="height:3mm">
                <td colspan="4"><span style="width:187mm" /></td>
              </tr>
            </tbody>
          </table>
        </div>
        <!--End Lines 27-29-->
        
        <!--End Part III-->
        
        <!--Begin Part IV-->
        
        <!--Part IV Header-->
        <div class="styBB" style="width:187mm">
          <div class="styPartName">Part IV</div>
          <div class="styPartDesc" style="font-size:7.5pt;">
            Allocation and Apportionment of Deductions on Books and Records Used to Prepare Form 1120F, Schedule L<br />
            Note.<span style="font-weight:normal"> Enter all amounts in Part IV in U.S. dollars.</span>
          </div>
        </div>
        
        <!--Begin Lines 30-38-->
        <div class="styBB" style="width:187mm">
          <table cellpadding="0" cellspacing="0" style="width:187mm;font-size:7pt">
            <tbody>
              <!--Line 30-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">30</td>
                <td class="sty1120FSchHLNDescTall" colspan="3" scope="row">
                  Total expenses per books and records used to prepare Form 1120F, Schedule L
                  <span class="sty1120FSchHDotLn" style="padding-left:3.8mm">......</span> 
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">30</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalExpensesPerBooks1120FSchL" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Spacer-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxLetter"></td>
                <td class="sty1120FSchHLNDesc" colspan="3"></td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 31-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxDD">31</td>
                <td class="sty1120FSchHLNDescShort" style="font-size:6pt" scope="row">
                  Adjustments for U.S. tax principles (attach schedule - see instructions)
                  <span class="sty1120FSchHDotLn" style="padding-left:2mm;font-size:7pt">...</span>
                  <span style="width:1.2mm" />
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/PartIVAdjustmentsForUSTaxPrin" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBox">31</td>
                <td class="sty1120FSchHLNAmountBox">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/PartIVAdjustmentsForUSTaxPrin" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 32-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">32</td>
                <td class="sty1120FSchHLNDescTallShort" style="font-size:6pt" scope="row">
                  Total deductions per line 30 books and records. Combine lines 30 and 31
                  <span class="sty1120FSchHDotLn" style="padding-left:3.5mm;font-size:7pt">...</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">32</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalDeductionsPerBooks" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxTallNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 33a-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">33a</td>
                <td class="sty1120FSchHLNDescTallShort" scope="row">
                  Third party interest expense per books and records
                  <span class="sty1120FSchHDotLn" style="padding-left:2.2mm">......</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">33a</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/ThirdPartyIntExpensePerBooks" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxTallNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 33b-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallLetter">b</td>
                <td class="sty1120FSchHLNDescTallShort" scope="row">
                  Interbranch interest expense per books and records
                  <span class="sty1120FSchHDotLn" style="padding-left:1mm">......</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">33b</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/InterbranchIntExpensePerBooks" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxTallNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 34-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">34</td>
                <td class="sty1120FSchHLNDescTallShort" scope="row">
                  Bad debt expense per books and records
                  <span class="sty1120FSchHDotLn" style="padding-left:0.3mm">..........</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">34</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/BadDebtExpensePerBooks" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxTallNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 35-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">35</td>
                <td class="sty1120FSchHLNDescTallShort" scope="row">
                  Other third party deductions not allocable (attach schedule)
                  <span class="sty1120FSchHDotLn" style="padding-left:2.5mm">..</span>
                  <span style="width:1.5mm" />
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/Other3rdPartyDedNotAllocable" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">35</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/Other3rdPartyDedNotAllocable" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxTallNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 36-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">36</td>
                <td class="sty1120FSchHLNDescTallShort" style="font-size:6pt" scope="row">
                  Interbranch expenses per books not included on line 33b (attach schedule)
                  <span class="sty1120FSchHDotLn" style="padding-left:1.4mm;font-size:7pt">..</span>
                  <span style="width:1.5mm" />
                  <xsl:call-template name="SetFormLinkInline">
                    <xsl:with-param name="TargetNode" select="$FormData/InterbranchExpensesNotIncluded" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">36</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/InterbranchExpensesNotIncluded" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallShadedNBB"><span style="width:1px" /></td>
                <td class="sty1120FSchHLNAmountBoxTallNBB"><span style="width:1px" /></td>
              </tr>
              <!--Line 37-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD">37</td>
                <td class="sty1120FSchHLNDescTall" colspan="3" scope="row">
                  Add lines 33a through 36
                  <span class="sty1120FSchHDotLn" style="padding-left:3.6mm">........................</span> 
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">37</td>
                <td class="sty1120FSchHLNAmountBoxTall">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/SumOfDeductionsNotAllocable" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 38-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDDTwoLines">38</td>
                <td class="sty1120FSchHLNDescTall" colspan="3" scope="row">
                  Deductions on books and records allocable and apportionable under Regulations section 1.861-8. Subtract line 37 from line 30
                  <span class="sty1120FSchHDotLn" style="padding-left:3.5mm">.......................</span> 
                </td>
                <td class="sty1120FSchHLNRightNumBoxTallNBB">38</td>
                <td class="sty1120FSchHLNAmountBoxTallNBBTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DedOnBooksAllcblUnderSect18618" />
                  </xsl:call-template>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
        <!--End Lines 30-38-->
        
        <!--Begin Lines 39-42-->
        <div class="styTBB" style="width:187mm">
          <table cellpadding="0" cellspacing="0" style="width:187mm;font-size:7pt">
            <tbody>
            <!--Header-->
              <tr>
                <th class="sty1120FSchHLNDescHeader" colspan="3" style="font-size:6pt" scope="col">
                  Reconciliation of allocable expenses on books under Reg. 1.861-8 (from line 38)
                </th>
                <th class="sty1120FSchHLNAmountBoxHeader" scope="col">(a)<br />ECI amounts</th>
                <th class="sty1120FSchHLNAmountBoxHeader" scope="col">(b)<br />Non-ECI Amounts</th>
                <th class="sty1120FSchHLNAmountBoxHeader" scope="col">(c)<br />Total: Add columns<br />(a)and (b)</th>
              </tr>
              <!--Line 39a-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDDTwoLines">39a</td>
                <td class="sty1120FSchHLNDescTallShortest" scope="row">
                  Derivative transaction deductions directly allocated under<br />section 1.861-8 (from line 38)
                  <span class="sty1120FSchHDotLn" style="padding-left:2.2mm">............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">39a</td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DerTransDedDirectlyAllocated/ECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DerTransDedDirectlyAllocated/NonECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DerTransDedDirectlyAllocated/TotalAmounts" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 39b-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallLetter">b</td>
                <td class="sty1120FSchHLNDescTallShortest" scope="row">
                  Other deductions directly allocated and apportioned
                  <span class="sty1120FSchHDotLn" style="padding-left:1.9mm">.....</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">39b</td>
                <td class="sty1120FSchHLNAmountBoxTallShort">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherDedDirectlyAllocated/ECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShort">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherDedDirectlyAllocated/NonECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShort">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/OtherDedDirectlyAllocated/TotalAmounts" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 40-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDDTwoLines">40</td>
                <td class="sty1120FSchHLNDescTallShortest" scope="row">
                  Total expenses directly allocated and apportioned. Add lines<br />39a and 39b
                  <span class="sty1120FSchHDotLn" style="padding-left:2.2mm">..................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">40</td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalExpensesDirectlyAllocated/ECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalExpensesDirectlyAllocated/NonECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalExpensesDirectlyAllocated/TotalAmounts" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 41-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDDTwoLines">41</td>
                <td class="sty1120FSchHLNDescTallShortest" scope="row">
                  Deductions on books and records indirectly allocated and<br />apportioned
                  <span class="sty1120FSchHDotLn" style="padding-left:3.5mm">..................</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">41</td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DedOnBooksIndirectlyAllocated/ECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DedOnBooksIndirectlyAllocated/NonECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/DedOnBooksIndirectlyAllocated/TotalAmounts" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Line 42-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDDTwoLines">42</td>
                <td class="sty1120FSchHLNDescTallShortest" scope="row">
                  Total deductions allocated and apportioned. Add lines 40 and 41.<br />Column (c) must equal line 38
                  <span class="sty1120FSchHDotLn" style="padding-left:3mm">............</span>
                </td>
                <td class="sty1120FSchHLNRightNumBoxTall">42</td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalDeductionsAllocated/ECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalDeductionsAllocated/NonECIAmounts" />
                  </xsl:call-template>
                </td>
                <td class="sty1120FSchHLNAmountBoxTallShortTwoLines">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/TotalDeductionsAllocated/TotalAmounts" />
                  </xsl:call-template>
                </td>
              </tr>
              <!--Note-->
              <tr>
                <td class="sty1120FSchHLNLeftNumBoxTallDD"></td>
                <td class="sty1120FSchHLNDescTallShortest" colspan="5" style="width:181mm">
                  <b>Note.</b> Line 42, column (a) is the total of the deductions reported on Form 1120F, Section II, lines 12, 13, 14, 16, 17, 19, 20,<br />
                  21, 22, 23, 24, 25, and 27.
                </td>
              </tr>
            </tbody>
          </table>
        </div>
        <!--End Lines 39-42-->
        
        <!--End Part IV-->
        
        <!--Begin Page 2 Footer-->
        <div style="width:187mm;clear:both;padding-top:1mm">
          <div style = "float:right;" class="styGenericDiv"><b>Schedule H (Form 1120-F) 2007</b></div>
        </div><br />
        <div class="pageEnd"></div>
        <!-- End Page 2 Footer-->

        <!-- BEGIN Left Over Table -->
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
          Additional Data        
        </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData"/>
          </xsl:call-template>
        </table>
        <!-- END Left Over Table -->
           
      </form>
      </body>  
    </html>
  </xsl:template>
</xsl:stylesheet>