<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS5884AStyle.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form5884AData" select="$RtnDoc/IRS5884A" />


<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form5884AData)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 5884A" />
      
      
      
      <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
      <xsl:call-template name="InitJS"></xsl:call-template>

    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 5884A CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS5884AStyle"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>  
    </style>
  <xsl:call-template name="GlobalStylesForm"/>
</head>

  <body class="styBodyClass">
    <form name="Form5884A">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>  

    <!-- Begin Form Number and Name -->
    <div class="styBB" style="width:187mm;">
    <div class="styFNBox" style="width:33mm;height:16mm;border-right:none;">
      <span style="height:7mm;">
        Form <span class="styFormNumber">5884-A</span>
      </span>
      <span class="styAgency" style="line-height:110%;">
        (October 2006)
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form5884AData" />
            </xsl:call-template>
        <br/>
        Department of the Treasury
        <br />
        Internal Revenue Service
      </span>
    </div>
    <div class="styFTBox" style="width:117mm;border-right:1px solid black;border-left:1px solid black;">
      <div style="height:13.5mm;" class="styMainTitle">
       Credits for Employers Affected by<br/>Hurricane Katrina, Rita, or Wilma      </div>      
      <div class="styFST" style="height:5mm;font-size:7pt;">
        <img src="{$ImagePath}/5884A_Bullet.gif" alt="Bullet Image"/>
        Attach to your tax return.
       
      </div>
    </div>
    <div class="styTYBox" style="width:32mm;border-left:none;">
        <div class="styOMB" style="height:9mm;">
          <div style="margin-top:8px;">OMB No. 1545-1978</div>
        </div>
        <div>
       <div style="width:30mm;height:1px;" />
        <span style="padding-right:9mm;">Attachment</span><br/> Sequence No. <span class="styBoldText">77A</span></div>   
    </div>
  </div>    
  <!-- End Form Number and Name section -->
  
    <!-- Begin Names and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:148mm;height:8mm;font-size:7pt;">
        Name(s) shown on return<br/>
        <span>          
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
        </span>
      </div>
      <div class="styEINBox" style="width:35mm;height:4mm;padding-left:2mm;font-size:7pt;font-weight:normal;">
        <b>Identifying number</b><br/>
        <span style="width:34mm; text-align:left;font-weight:normal;"><br/>
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>          
        </span>          
      </div>
    </div>
    
    <!-- End Names and Identifying number section -->
  
  
  
  
  
  
  


    <!-- Begin Allowable credit section-->
    <div class="styBB" style="width:187mm;padding-top:1mm; padding-bottom:1mm;">
      <div style="padding-left:none;font-weight:bold;font-size:8pt;">
      SECTION A. <span style="width:2mm;" /> Employee Retention Credit <span class="styNormalText"> (see instructions)</span>
      </div>
    </div>
    
     <!--Line 1a Begin-->
  <div class="styBB" style="width:187mm;">
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">1a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          Employers affected by Hurricane Katrina, enter the total
qualified wages paid or incurred after August 28, 2005, and
before January 1, 2006, while the business was inoperable
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.           
          </span>
        </div>

        <div class="styLNRightNumBox" style="height:12mm;"><br/><br/>1a</div>
        <div class="styLNAmountBox" style="height:12mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/TotalQlfyWagesPaidIncurdKatrin"/>
          </xsl:call-template>
        </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:12mm;border-right-width:1px;"></div>
      </div>
            <!-- end line 1a -->      
  
      <!-- begin line 1b -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
Employers affected by Hurricane Rita, enter the total qualified
wages paid or incurred after September 23, 2005, and before
January 1, 2006, while the business was inoperable
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:12mm;"><br/><br/>1b</div>
        <div class="styLNAmountBox" style="height:12mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/TotalQlfyWagesPaidIncurdRita"/>
          </xsl:call-template>
         </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:12mm;border-right-width:1px;"></div>
      </div>
      
            <!-- end line 1b -->      
  
      <!-- begin line 1c -->
      

      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:12mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:12mm;">
Employers affected by Hurricane Wilma, enter the total qualified
wages paid or incurred after October 23, 2005, and before
January 1, 2006, while the business was inoperable
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.    
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.   
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.     
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:12mm;"><br/><br/>1c</div>
        <div class="styLNAmountBox" style="height:12mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/TotalQlfyWagesPaidIncurdWilma"/>
          </xsl:call-template>
          </span>
        </div>
        
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:12mm;border-right-width:1px;"></div>
      </div>
      
      <!-- end line 1c -->      
 
      <!-- begin line 1d -->
            
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;"><br/>d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4mm;">
          <br/>Add amounts from lines 1a, 1b, and 1c
            <!--Dotted Line-->
            <span class="styBoldText">
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:8mm;"><br/>1d</div>
        <div class="styLNAmountBox" style="height:8mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/TotalQualifiedWagesPaidIncurd"/>
          </xsl:call-template>
       </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:8mm;border-right-width:1px;"></div>
      </div>
      
      
     <!-- end line 1d -->      
 
      <!-- begin line 2 -->
      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;"><br/>2</div>
        <div class="styLNDesc" style="width:138mm;height:8mm;"><br/>
          Enter 40% of line 1d. You <b>must</b> subtract this amount from your deduction for salaries <br/>and wages
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
                             
  
          </span>
        </div>
        
        <div class="styLNRightNumBox" style="height:12mm;padding-top:0mm;">
        <span style="height:8mm;background-color:lightgrey;width:7.80mm;"></span>
        2
        </div>
        <div class="styLNAmountBox" style="height:12mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/Enter40PctOfLine1"/>
          </xsl:call-template>
        </span>
        </div>
      </div>
      
<!--Line 2 End-->
      
      
      
      
       <!--Line 3 Begin-->
  
        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;"><br/><br/>3</div>
        <div class="styLNDesc" style="width:138mm;height:8mm;"><br/><br/>
          Employee retention credit from partnerships, S corporations, cooperatives, estates,
and trusts
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.                             
  
          </span>
        </div>
        
        <div class="styLNRightNumBox" style="height:12mm;padding-top:0mm;">
        <span style="height:8mm;background-color:lightgrey;width:7.80mm;"></span>
        3
        </div>
        <div class="styLNAmountBox" style="height:12mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/EmployeeRetentionCredit"/>
          </xsl:call-template>
        </span>
        </div>
      </div>
  
        <!--Line 3 End-->
    
 
  <!--Line 4 Begin-->

        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;"><br/>4</div>
        <div class="styLNDesc" style="width:138mm;height:8mm;"><br/>
          <b>Current year credit. </b> Add lines 2 and 3. Report this amount on the applicable line of Form 3800. If you
          have a credit from Section B, see instructions. S corporations, partnerships, estates,
          trusts, cooperatives, regulated investment companies, and real estate investment
          trusts, see instructions
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  
           

          </span>
        </div>
        
        <div class="styLNRightNumBox" style="height:14mm;padding-top:0mm;border-bottom:none;">
        <span style="height:10mm;background-color:lightgrey;width:7.80mm;"></span>
        4
        </div>
        <div class="styLNAmountBox" style="height:14mm;border-bottom:none;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/CurrentYearCredit"/>
          </xsl:call-template>
        </span>
        </div>
      </div>
</div>

  <!--Line 4 End-->

          
    <!-- Start Section B Hurricane Katrina Housing Credit -->
    
    <div class="styBB" style="width:187mm;padding-top:1mm;padding-bottom:1mm;">
      <div style="padding-left:none;font-weight:bold;font-size:8pt;">
      SECTION B. <span style="width:2mm;" /> Hurricane Katrina Housing Credit <span class="styNormalText"> (see instructions)</span>
      </div>
    </div>
    
    
    <!--Line 5 Begin-->
    <div class="styBB" style="width:187mm;">    
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;">5</div>
        <div class="styLNDesc" style="width:138mm;height:8mm;">
            Enter the value (up to $600 per month per employee) of qualified lodging furnished
            in-kind to qualified employees during the tax year from January 1, 2006, through July 1,
            2006 (see instructions)
          <!--Dotted Line-->
          <span class="styBoldText">
           <span style="width:16px;"></span>.
           <span style="width:16px;"></span>. 
           </span>
        </div>


      <div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
      <span style="vertical-align:baseline;height:100%;"></span><span> 5 </span>
        </div>
        <div class="styLNAmountBox" style="height:8mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/QualifiedLodging"/>
          </xsl:call-template>
        </div>

      </div>
  <!--Line 5 End-->
        
   <!--Line 6 Begin-->

      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;"><br/>6</div>
        <div class="styLNDesc" style="height:8mm;">
         <br/> Enter 30% of line 5.  You <span class="styBoldText">must</span> subtract this amount from your deduction for salaries and wages
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>        
       <div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
          <div style="width:7.75mm;border-left-width:0px;background-color:lightgrey;height:4mm;"></div>
          6          
        </div>        
        <div class="styLNAmountBox" style="height:8mm;">
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/Enter30PctOfLine5"/>
          </xsl:call-template>
        </div>

      </div>

       <!--Line 6 End-->
       
       <!--Line 7 Begin-->
  
        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;"><br/><br/>7</div>
        <div class="styLNDesc" style="width:138mm;height:8mm;"><br/><br/>
Hurricane Katrina housing credit from partnerships, S corporations, cooperatives,
estates, and trusts
          <!--Dotted Line-->
          <span class="styBoldText">
                      
  
          </span>
        </div>
        
        <div class="styLNRightNumBox" style="height:12mm;padding-top:0mm;">
        <span style="height:8mm;background-color:lightgrey;width:7.80mm;"></span>
       7
        </div>
        <div class="styLNAmountBox" style="height:12mm;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/HurricaneKatrinaHousingCredit"/>
          </xsl:call-template>
        </span>
        </div>
      </div>
  
        <!--Line7 End-->
    
 
  <!--Line8 Begin-->

        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:8mm;"><br/>8</div>
        <div class="styLNDesc" style="width:138mm;height:8mm;"><br/>
          <b>Current year credit. </b> Add lines 6 and 7. Report this amount on the applicable line of
Form 3800. If you have a credit from Section A, see instructions. S corporations,
partnerships, estates, trusts, cooperatives, regulated investment companies, and real
estate investment trusts, see instructions
          <!--Dotted Line-->
          <span class="styBoldText">
            <span style="width:16px;"></span>.  

          </span>
        </div>
        
        <div class="styLNRightNumBox" style="height:14mm;padding-top:0mm;border-bottom:none;">
        <span style="height:10mm;background-color:lightgrey;width:7.80mm;"></span>
       8
        </div>
        <div class="styLNAmountBox" style="height:14mm;border-bottom:none;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form5884AData/SectionBCurrentYearCredit"/>
          </xsl:call-template>
        </span>
        </div>
      </div>
</div>

  <!--Line 8 End-->
  
  
  

    <!-- End Part II Current Year Credit -->


  <!--End of form-->

    <div style="width:187mm;">
    <span class="styBoldText">For Paperwork Reduction Act Notice, see page 4. </span> 
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      
      Cat. No. 47425B
      <span style="width:14px;"></span>  
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
      <span style="width:14px;"></span>
  <span style="width:14px;"></span> <span style="width:14px;"></span>
  
      <span style="font-size:7pt;padding-right:1mm;">Form</span> <span class="styBoldText" style="font-size:8pt;">5884-A</span> <span style="font-size:7pt;padding-left:1mm;">(10-2006)</span>
  </div>

        <br/>
        <br class="pageEnd"/>
        
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form5884AData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
        </table>
        <!-- END Left Over Table -->    
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
