<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS6478Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form6478Data" select="$RtnDoc/IRS6478" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" 
    select="local-name($Form6478Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching   -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Author" content="Ravi Venigalla" />
    <meta name="Description" content="TY 2007 IRS Form 6478" />
    
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!-- Form 6478 CSS Styles are located in the template called below -->
        <xsl:call-template name="IRS6478Style"></xsl:call-template>  
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>
    </style>    
  <xsl:call-template name="GlobalStylesForm"/>
</head>
  
  <body class="styBodyClass">
    <form name="Form6478">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>
      
      <!-- Begin Form6478 Number and Name -->
      
      <div class="styBB" style="width:187mm;">
      <div class="styFNBox" style="width:31mm;height:22mm;padding-top:2.75mm;">
      
        Form <span class="styFormNumber">6478</span>
         
          <br/>
         <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form6478Data"/>
            </xsl:call-template>
          <br/>
          <br/> 
        <span class="styAgency" >Department of the Treasury</span>
        <br/>
        <span class="styAgency">Internal Revenue Service</span>
      </div>
      <div class="styFTBox" style="width:123mm;height:11mm;">
        <span style="height: 1mm;" />
        <div class="styMainTitle" style="height:8.5mm;">
          Credit for Alcohol Used as Fuel
        </div>
        <br/>
        <div class="styFST" style="height:5mm;font-size:7pt;">
          <img src="{$ImagePath}/6478_Bullet.gif" width="4" height="7" alt="Bullet Image"/>
          Attach to your tax return.
        </div>
      </div>
      <div class="styTYBox" style="width:33mm;height:12mm;">
        <div class="styOMB" style="height:2mm;">
          OMB No. 1545-0231
        </div>
        <div class="styTY" style="height:13mm;padding-top:3mm;">
          20<span class="styTYColor">07</span>
        </div>
        <div>Attachment<br/> Sequence No.<span class="styBoldText">
        <span style="width:4px;"></span>83</span></div>
      </div>
    </div>
    
<!-- End Form Number and Name section -->
    
<!-- Begin Name and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:130mm;height:8mm;font-size:7pt;">
        Name(s) shown on return
        <br/>
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
        <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
      </div>
      <div class="styEINBox" style="width:50mm;height:4mm;font-size:7pt;padding-left:2mm;">
        Identifying number<br/><br/>
        <span style="font-weight:normal;">
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
        </span>
      </div>
    </div>
       
<!-- Start Caution -->

   <div style="width: 187mm; font-size: 7.5pt;padding-top:1mm;">
   <div style="width:187mm;height:6mm;padding-bottom:1mm;" class="styBB">
            <span class="styBoldText" style="vertical-align: top;">Caution:</span>
          <span class="styItalicText" style="width: 165mm; padding-left: 2mm;"> You cannot claim any amounts on Form 6478 that you claimed (or will claim)
          	 on Schedule C (Form 720), Form 8849, or Form 4136. </span>
          </div>
       <!--   <div class="styBB" style="width: 187mm;">-->
       <!--     <span class="styItalicText" style="width: 149mm; padding-left: 21mm">or Form 4136.</span>
          </div>-->
</div>
  
<!-- End Caution -->     

<!-- Start part I -->
<div style="width:187mm;"></div>
     
<div style="width:187mm;height:6mm" class="styBB">

  <div class="styPartName" style="width:15mm;padding-top:.25mm;">Part I</div>
  <div class="styPartDesc" style="padding-left:3mm;padding-top:.25mm;">
    Current Year Credit 
  </div>
</div>
<!-- End part I -->     



    <!-- End Names and Identifying number section -->
    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" align="center" style="width:101.75mm;height:9mm; padding-top:3mm;font-size:7pt;">
        Type of Alcohol Fuel
      </div>
      
      <div class="styNameBox" align="center" style="width:32mm;height:9mm;">
        <span class="styBoldText">(a)</span><br/>Number of Gallons of <br/>Alcohol  Sold or Used
      </div>
      <div class="styNameBox" align="center" style="width:21mm;height:9mm;">
        <span class="styBoldText">(b)</span><br/>Rate*      
      </div>
      <div align="center" ><span class="styBoldText" style="font-size:6pt;">(c)</span><br/>Column(a) x Column(b)</div>

    </div>

<!--  Start line 1 -->        

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          1
        </div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">Qualified ethanol fuel production (in gallons)</span>
        </div>      
        <div class="styLNAmountBox" style="border-bottom-width:0px;width:5mm;padding-right:2mm;"></div>

        <div class="styLNAmountBox" style="width:32mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:21mm;text-align:center;border-bottom-width:0px;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0px;">
          
        </div>
    </div>
<!-- End line 1 -->
    
<!-- start line 1 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">(see instructions for election)</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:right;padding-right:1mm">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>. 
          </span>
     </div>      
     <div class="styLNAmountBox" style="width:5mm;padding-right:2mm;">1</div>
        <div class="styLNAmountBox" style="width:32mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="8"/>          
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            QualifiedEthanolFuelProduction"/>
          </xsl:call-template>
        </div>
         <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:21mm;text-align:center;">
          $
          <xsl:if test="$Form6478Data/QualifiedEthanolFuelProdRate">
            <xsl:call-template name="PopulateText">
               <xsl:with-param name="TargetNode"
                select="$Form6478Data/QualifiedEthanolFuelProdRate"/>
            </xsl:call-template>
          </xsl:if>
          <!--xsl:if test="not($Form6478Data/QualifiedEthanolFuelProdRate) or ($Form6478Data/QualifiedEthanolFuelProdRate='')" -->
          <xsl:if test="not($Form6478Data/QualifiedEthanolFuelProdRate)">
            .10
          </xsl:if>
        </div>

        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            QualifiedEthanolFuelCredit"/>
          </xsl:call-template>        
        </div>
    </div>
    
<!-- End line 1 extention -->
 
 <!--  Start line 2 -->        
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          2
        </div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">Alcohol 190 proof or greater</span>
          <span style="font-weight:bold"> and </span>
          <span style="font-weight:normal">alcohol 190 proof or greater</span>
        </div>      
        <div class="styLNAmountBox" style="border-bottom-width:0px;width:5mm;padding-right:2mm;"></div>

        <div class="styLNAmountBox" style="width:32mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:21mm;text-align:center;border-bottom-width:0px;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0px;">
          
        </div>
    </div>
<!-- End line 2 -->
    
<!-- start line 2 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">in fuel mixtures</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:right;padding-right:1mm">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>. 
            <span style="width:16px;"></span>.
           </span>
     </div>      
     <div class="styLNAmountBox" style="width:5mm;padding-right:2mm;">2</div>
        <div class="styLNAmountBox" style="width:32mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="8"/>          
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            Alcohol190ProofOrHigherPrf"/>
          </xsl:call-template>
        </div>
        
  <div class="styLNAmountBox" style="width:21mm;text-align:center;">  
          $   
          <xsl:if test="$Form6478Data/RateFor190OrHigherPrfAlcohol">
          <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            RateFor190OrHigherPrfAlcohol"/>
          </xsl:call-template> 
          </xsl:if>                      
           <xsl:if test="not($Form6478Data/RateFor190OrHigherPrfAlcohol)">.51
          </xsl:if>                      
       </div>
        
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            Alcohol190ProofOrGreaterCredit"/>
          </xsl:call-template>        
        </div>
    </div>
    
<!-- End line 2 extention -->

 <!--  Start line 3 -->        
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          3
        </div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
        <span style="float:left">Alcohol less than 190 proof but at least 150 proof </span>
        <span style="font-weight:bold"> and </span><span style="font-weight:normal">alcohol</span>
        </div>      
        <div class="styLNAmountBox" style="border-bottom-width:0px;width:5mm;padding-right:2mm;"></div>

        <div class="styLNAmountBox" style="width:32mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        <div class="styLNAmountBox" style="width:21mm;text-align:center;border-bottom-width:0px;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0px;">
          
        </div>
    </div>
<!-- End line 3 -->
    
<!-- start line 3 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:88.7mm;height:4mm;">
          <span style="float:left">less than 190 proof but at least 150 proof in fuel mixtures</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:right;padding-right:1mm">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
           </span>
     </div>      
     <div class="styLNAmountBox" style="width:5mm;padding-right:2mm;">3</div>
        <div class="styLNAmountBox" style="width:32mm;padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="MaxSize" select="8"/>          
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            GallonsOf150To189ProofAlcohol"/>
          </xsl:call-template>
        </div>
        
        <div class="styLNAmountBox" style="width:21mm;text-align:center;">  
          $     
          <xsl:if test="$Form6478Data/RateFor150To189ProofAlcohol">
                <xsl:call-template name="PopulateText">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            RateFor150To189ProofAlcohol"/>
          </xsl:call-template> 
          </xsl:if>
           <xsl:if test="not($Form6478Data/RateFor150To189ProofAlcohol)">
           <span style="font-size:6pt;">.3778</span>         
           </xsl:if>                      
         </div>

        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            Alcohol150To189ProofCredit"/>
          </xsl:call-template>        
        </div>
    </div>
    
<!-- End line 3 extention -->
 
  
   <!-- Start line 4 -->
  
   <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
         4
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-size:6.35pt;padding-top:1mm;">
        <span style="float:left">Add the amounts in column (c) on lines 1, 2, and 3.  Include this amount in your income for 2007 (see instructions)  </span>
        </div>
              
      <div class="styLNRightNumBox" >4
        </div>
        <div class="styLNAmountBox"   >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/OtherIncome"/>
          </xsl:call-template>
        </div>
</div>

        
       <!--  <div class="styLNAmountBox" style="border-bottom-width:0px;width:8mm;padding-right:2mm;background-color:red;"></div>
          <div class="styLNAmountBox" style="width:30mm;border-bottom-width:0px;"></div>-->
        <!-- Text is aligned center as it is in center aligned in the PDF -->
       <!-- </div>-->
<!-- End line4 -->
    
<!-- start line 4 extention -->     

  <!--  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;background-color:red;"></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">(see instructions)  </span>-->
          <!--Dotted Line-->
        <!-- <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:18px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
           </span> -->
     
     
    <!--  <div class="styLNRightNumBox" >4
        </div>
        <div class="styLNAmountBox"   >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/OtherIncome"/>
          </xsl:call-template>
        </div> -->

     
  <!-- Start line 5 -->
 
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-top:.5mm;">
         5
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;padding-top:1mm;">
          <span style="float:left">Alcohol fuel credit from a partnership, S corporation,
          	  cooperative, estate, or trust (see instructions)</span>
          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:7px;"></span>.
 				
		</span>
        </div>                
        <div class="styLNRightNumBox" style="padding-top:2mm;padding-bottom:0mm">5
        </div>
        <div class="styLNAmountBox" style="padding-top:2mm;padding-bottom:0mm" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            AlcoholFuelCredit"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- start line 6 -->

   <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
         6
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-size:2.5mm;">
        <span style="float:left">Add lines 4 and 5. Partnerships and S corporations, report this amount on Schedule K. All others, go to </span>
        </div>
         <div class="styLNAmountBox" style="border-bottom-width:0px;width:8mm;padding-right:2mm;"></div>
          <div class="styLNAmountBox" style="width:30mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        </div>
<!-- End line 6 -->
    
<!-- start line 6 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-bottom:.5mm;"></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left"> line 7</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            </span>
     	</div>  
     
      <div class="styLNRightNumBox" >6
        </div>
        <div class="styLNAmountBox"   >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/EthanolAlcoholOtherCredit"/>
          </xsl:call-template>
        </div>
</div>

<!-- end line 6 -->

<!-- start line 7 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          7
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;" >
          <span style="float:left">Alcohol fuel credit included on line 6 from passive activities (see instructions)  </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
           <span style="width:16px;"></span>.
           </span>      
        </div>                
        <div class="styLNRightNumBox" >7
        </div>
        <div class="styLNAmountBox"  style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholCreditFromPassiveActy"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 7 -->


<!-- start line 8-->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          8
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;" >
          <span style="float:left">Subtract line 7 from line 6</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:7px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>. 
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
       </span>      
        </div>                
        <div class="styLNRightNumBox" >8
        </div>
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetAlcoholCredits"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 8 -->

<!-- start line 9 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          9
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;" >
          <span style="float:left">Alcohol fuel credit allowed for 2007 from a passive activity (see instructions)</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
         </span>      
        </div>                
        <div class="styLNRightNumBox" >9
        </div>
        <div class="styLNAmountBox"  style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholPassiveCreditAllowed"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 9 -->


<!-- start line 10 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          10
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;" >
          <span style="float:left">Carryforward from 2006 and carryback from 2008 of the alcohol fuel credit (see instructions)</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">
          <span style="width:7px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
  
          </span>      
        </div>                
        <div class="styLNRightNumBox" >10
        </div>
        <div class="styLNAmountBox"  style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlcoholFuelCreditCfwdCybk"/>
          </xsl:call-template>
        </div>
    </div>  

<!-- end line 10-->


<!-- start line 11 -->

   <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-right:0mm;">
         11
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        <span style="float:left">Add lines 8 through 10. Cooperatives, estates, and trusts, go to line 12. All others, 
        use this amount to </span>
        </div>
         <div class="styLNAmountBox" style="border-bottom-width:0px;width:8mm;"></div>
          <div class="styLNAmountBox" style="width:30mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        </div>
<!-- End line 11 -->
    
<!-- start line 11 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" ></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">complete Part II</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
               <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.

          </span>
     	</div>  
        <div class="styLNRightNumBox" >11
        </div>
        <div class="styLNAmountBox"   >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/TotalCYCreditForAlcoholAsFuel"/>
          </xsl:call-template>
        </div>
</div>

<!-- end line 11 -->


<!-- start line 12 -->

  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-right:0mm;">
         12
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        <span style="float:left">Amount allocated to patrons of the cooperative or beneficiaries of the estate or trust  (see</span>
        </div>
         <div class="styLNAmountBox" style="border-bottom-width:0px;width:8mm;"></div>
          <div class="styLNAmountBox" style="width:30mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        </div>
<!-- End line 12 -->
    
<!-- start line 12 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" ></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">instructions)</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  
          </span>
     	</div>  
        <div class="styLNRightNumBox" >12
        </div>
        <div class="styLNAmountBox"   >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AmtAllocatedToBeneficiaries"/>
          </xsl:call-template>
        </div>
</div>


 <!-- <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
         12
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;font-size:2.5mm;">
        <span style="float:left">Amount allocated to patrons of the cooperative or beneficiaries of the estate or trust (see instructions)</span>
        </div>
   
        <div class="styLNRightNumBox" >12
        </div>
        <div class="styLNAmountBox" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AmtAllocatedToBeneficiaries"/>
          </xsl:call-template>
        </div>
</div>-->


<!-- end line 12 -->

   <!-- Start line 13 -->
      
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-right:0mm;">
         13
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        <span style="float:left">Cooperatives, estates, and trusts. Subtract line 12 from line 11. Use this amount to complete </span>
        </div>
         <div class="styLNAmountBox" style="border-bottom-width:0px;width:8mm;"></div>
          <div class="styLNAmountBox" style="width:30mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        </div>
<!-- End line 13 -->
    
<!-- start line 13 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" ></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">Part II</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
          </span>
     	</div>
     	
     	<div class="styLNRightNumBox" style="height:4.5mm;padding-top:1mm;padding-bottom:0mm;border-bottom-width:0px;">13
        </div>
  
        <div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;border-bottom-width:0px;"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/EstatesTrustsCooperatives"/>
          </xsl:call-template>
        </div>
</div>

 <!--  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-top:.5mm;">
         13
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        <span style="float:left">Cooperatives, estates, and trusts. Subtract line 12 from line 11. Use this amount to complete Part II</span>-->
         <!--Dotted Line-->
<!--          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:12px;"></span>.
            </span>
        </div>
    
      <div class="styLNRightNumBox" style="height:4.5mm;padding-top:1mm;padding-bottom:0mm;border-bottom-width:0px;">13
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;border-bottom-width:0px;"  >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/EstatesTrustsCooperatives"/>
          </xsl:call-template>
        </div>
</div> -->

<!-- END LINE 13 -->

  <div class="styBB" style="width:187mm;border-top-width:1px">
    <div class="styLNDesc" style="width:187mm;">  
    <span style="width:16px;"></span>
   * Only the rate for ethanol is shown. See instructions for lines 2 and 3 for rates
     for alcohol other than ethanol.
    <br />
    </div>
  </div>
  
  <!-- Start Part II -->
  
<div style="width:187mm;" class="styBB">
  <div class="styPartName" style="width:15mm;">Part II</div>
  <div class="styPartDesc" style="padding-left:3mm;">
    Allowable Credit
  </div>
</div>
  
<!-- End PartII -->

<!-- Start line 14-->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          14
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
            Regular tax before credits (see instructions)
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          14         
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/RegularTaxBeforeCredits"/>
          </xsl:call-template>    
        </div>                
    </div>
  
<!-- End line 14 --> 

<!-- Start line 15-->
    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          15
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
        
            Alternative minimum tax (see instructions)
     
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          15         
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlternativeMinimumTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 15 --> 

<!-- Start line 16 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          16
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
    
          Add lines 14 and 15
          
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          16          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
           RegularTaxPlusAltMinimumTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 16 --> 

<!-- Start line 17 -->

    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:8mm;float:left;">
          17a
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:8mm;">
          <span style="float:left">Credits from Form 1040, lines 47 through 50 and 52 through 54 (or
                Form 1040NR, lines 44, 45, and 47 through 49)
            <span class="styBoldText">         
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.

</span></span>
          </div>
          <!--  Line 17a  -->
          
        <div class="styLNRightNumBox" style="height:8mm;padding-top:4mm">17a</div>      
        <div class="styLNAmountBox" style="padding-right:1mm;height:8mm;padding-top:4mm" >
          <!-- xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/ForeignTaxCredit"/>
          </xsl:call-template -->
        </div>
        <div class="styShadingCell" style="width:8mm;height:8mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:8mm;"></div>          
    </div>

<!-- Start Line 17b -->
    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm;">
          b
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4.5mm;">
          <span style="float:left">Foreign tax credit</span>
            <span class="styBoldText">         
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            </span>
        </div>
        <div class="styLNRightNumBox" style="padding-top:0mm;height:4.5mm;">17b</div>      
        <div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;padding-bottom:0mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/ForeignTaxCredit"/>
          </xsl:call-template> 
    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;padding-right:1mm;"></div>
    		</div>  
   <!-- End Line 17b -->
   
   <!-- Start Line 17c  -->    
       
    <div style="width:187mm">                        
    <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          c
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4.5mm;">
          <span style="float:left">Credits from Forms 5735 and 8834</span>
          <span class="styBoldText">          
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			 <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         
            </span>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">17c</div>
        <div class="styLNAmountBox" style="height:4.5mm;padding-right:1mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/CrFrom5735And8834"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
    
    <!-- End Line 17c -->
    
    <!-- Start Line 17d -->              
    </div><div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          d
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Non-business alternative motor vehicle credit (Form 8910, line 18)</span>
          <span class="styBoldText">
            <span style="width:16px;"></span>.          
         
          </span>

        </div>
        <div class="styLNRightNumBox" style="height:4mm;">17d</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            AlternativeMotorVehicleCredit"/>
          </xsl:call-template>    
        </div>
          <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
          <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
        </div>
<!-- END Line 17d -->

<!-- START Line 17e -->
    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          e
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
        Non-business alternative fuel vehicle refueling property credit (Form
          8911, line 19)
          <span class="styBoldText">         
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.

            </span>

        </div>
        <div class="styLNRightNumBox" style="height:8mm;padding-top:4mm">17e</div>
        <div class="styLNAmountBox" style="padding-right:1mm;height:8mm;height:8mm;padding-top:4mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/AlternativeRefuelingPropertyCr"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:8mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:8mm;"></div>        
      </div>
  
  <!-- END Line 17e -->
  
  <!-- START Line 17f -->  
    <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
        f
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">Add lines 17a through 17e</span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.                                        
          </span>
       </div>
      
        <div class="styLNRightNumBox">17f
        </div>
          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/TaxCreditTotal"/>
          </xsl:call-template>    
        </div>
    </div>

<!-- End line 17-->

<!-- Start line 18-->

     <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;padding-right:0mm;">
         18
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        <span style="float:left">Net income tax. Subtract line 17f from line 16. If zero, skip lines 19 through 22 and enter -0- on </span>
        </div>
         <div class="styLNAmountBox" style="border-bottom-width:0px;width:8mm;"></div>
          <div class="styLNAmountBox" style="width:30mm;border-bottom-width:0px;"></div>
        <!-- Text is aligned center as it is in center aligned in the PDF -->
        </div>
<!-- End line 18 -->
    
<!-- start line 18 extention -->     

    <div style="width:187mm">
        <div class="styLNLeftNumBox" ></div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">line 23</span>
          <!--Dotted Line-->
          <span class="styBoldText" style="float:left;padding-right:1mm;">
            <span style="width:7px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
			  <span style="width:16px;"></span>.
          </span>
     	</div>
     	
     <div class="styLNRightNumBox">
          18         
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetIncomeTax"/>
          </xsl:call-template>    
        </div>	
     </div>
    
    <!--  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          18
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
            <span class="stySmallText;">
           Net income tax. Subtract line 17f from line 16. If zero, skip lines 19 through 22 and enter -0- on line 23
            </span>
          </span>
         
        </div>      
        <div class="styLNRightNumBox">
          18         
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetIncomeTax"/>
          </xsl:call-template>    
        </div>                
    </div> -->

<!-- End line 18 --> 

<!-- Start line 19 -->


   <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:1mm">
          19
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Net regular tax. Subtract line 17f from line 14. If zero or less, enter -0-</span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">19</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetRegularTax"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
    </div>

<!-- End line 19 -->

<!-- Start line 20 -->

  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          20
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
           
           Enter 25% (.25) of the excess, if any, of line 19 over $25,000 (see instructions)
      
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          20         
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetRegularTax25PctOfExcess"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 20 -->    

<!-- Start line 21 -->

    
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          21
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
          
            Subtract line 20 from line 18. If zero or less, enter -0-
       
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
         </span>
        </div>      
        <div class="styLNRightNumBox">
          21          
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/NetIncomeTaxLessExcess"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 21 --> 


<!-- Start line 22a -->
   <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:1mm">
          22a
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">General business credit (Form 3800, line 19)
          
             <span class="styBoldText">         
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
             </span>
        </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">22a</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/GeneralBusinessCredit"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
    </div>

    
<!-- End line 22a --> 

<!-- Start line 22b -->
      <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4mm">
          b
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
        Empowerment zone and renewal community employment credit (Form8844, line 26)   
         <span class="styBoldText">         
             <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
         </span>

        </div>
        <div class="styLNRightNumBox" style="height:8mm;padding-top:4mm">22b</div>
        <div class="styLNAmountBox" style="padding-right:1mm;height:8mm;height:8mm;padding-top:4mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/EmpowermentZoneCommunityCr"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:8mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:8mm;"></div>        
      </div>

<!-- End line 22b -->

<!-- Start line 22c -->
   <div style="width:187mm">
        <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.5mm">
          c
        </div>
        <div class="styLNDesc" style="width:98.75mm;height:4mm;">
          <span style="float:left">Work opportunity credit (Form 5884, line 22)
               <span class="styBoldText">         
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
                  <span style="width:16px;"></span>.
             </span>
          </span>
        </div>
        <div class="styLNRightNumBox" style="height:4mm;">22c</div>
        <div class="styLNAmountBox" style="padding-right:1mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/WorkOpportunityCredit"/>
          </xsl:call-template>    
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;"></div>
    </div>


<!-- End line 22c -->

<!-- Start line 22d -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm; padding-left:4mm;">
          d
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         Add lines 22a through 22c
           </span>
          <span class="styBoldText" style="padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          22d
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            SumOfLines22aThru22c"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 22d -->

<!-- Start line 23 -->

      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          23
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:4mm;">
          <span style="float:left">
         Subtract line 22d from line 21. If zero or less, enter -0-
          </span>
          <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
          </span>
        </div>      
        <div class="styLNRightNumBox">
          23         
        </div>          
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form6478Data/
            AdjustedNetIncomeTax"/>
          </xsl:call-template>    
        </div>                
    </div>

<!-- End line 23--> 

<!-- Start line 24 -->
  
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          24
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:3.5mm;">
          <span class="styBoldText">Credit allowed for the current year. Cooperatives, estates, and trusts.</span> Enter the smaller of 
          
        </div>
        <div class="styShadingCell" style="width:8mm;height:4.5mm;padding-top: 1.0mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>
     </div>
     
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
       </div>
        <div class="styLNDesc" style="width:138.75mm;height:3.5mm;"><span style="float:left">
          line 13 or 23. Report this amount on Form 1120-C, Schedule J, line 5c; or Form 1041, Schedule </span> 
        </div>        
        <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>        
       </div>
       
        <div style="width:187mm">
          <div class="styLNLeftNumBox" style="height:4mm;">        
          </div>
          <div class="styLNDesc" style="width:138.75mm;height:3.5mm;">
            <span style="float:left">G, line 2c. If line 23 is smaller than line 13, see instructions.<b> All others.</b>  Enter the smaller of line </span>
            </div> 
                   
           <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>           
        </div> 
          
          <div style="width:187mm">
          <div class="styLNLeftNumBox" style="height:4mm;">        
          </div>
          <div class="styLNDesc" style="width:138.75mm;height:3.5mm;">
            <span style="float:left">11 or 23. Report this amount on Form 1040, line 55; Form 1040NR, line 50; Form 1120, Schedule </span>
            </div> 
               <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
       		 <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>   
           </div> 
           
           <div style="width:187mm">
          <div class="styLNLeftNumBox" style="height:4mm;">        
          </div>
          <div class="styLNDesc" style="width:138.75mm;height:3.5mm;">
            <span style="float:left">J, line 5c; or the applicable line of your return. If line 23 is smaller than </span>
            </div> 
               <div class="styShadingCell" style="width:8mm;height:4.5mm;"></div>
       		 <div class="styLNAmountBoxNBB" style="height:4.5mm;" ></div>   
           </div> 
     
      <div style="width:187mm">
          <div class="styLNLeftNumBox" style="height:4mm;">        
          </div>
          <div class="styLNDesc" style="width:138.75mm;height:3.5mm;">
            <span style="float:left">line 11, see instructions</span>
            <span class="styBoldText" style="float:right;padding-right:1mm">          
            <span style="width:1px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
			   <span style="width:16px;"></span>.
             <span style="width:16px;"></span>.
            

          </span>
			</div>
     
          <div class="styLNRightNumBoxNBB" style="height:4.5mm;">24          
          </div>          
          <div class="styLNAmountBoxNBB" style="height:4.5mm;" >
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form6478Data/
              CYCreditForAlcoholAsFuel"/>
            </xsl:call-template>    
          </div>                
           </div> 
<!-- End line 24 -->      
  <!-- END Part II Line Items -->  
  
      <div class="styFooter" style="width:187mm; font-size:7pt; border-top:2 solid black; padding-top:1mm;">    
        <div style="float:left; font-size:8.5pt">
          <b>For Paperwork Reduction Act Notice, see instructions</b>
        </div>    
        <div style="float:right;font-size:6pt">
          Cat. No. 13605J
          <span style="width:35mm"></span>
          Form <b style="font-size:9pt">6478<span  style="font-size:6pt"> (2007)</span></b>
        </div>      
      </div>        
      
      <p style="page-break-before:always" />      

<!-- BEGIN Left Over Table -->  
<!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form6478Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template> 
        </table>
        <!-- END Left Over Table -->  
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
