<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8827Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8827Data" select="$RtnDoc/IRS8827" />
<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8827Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    <meta name="Description" content="IRS Form 8827" />
              
      <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
      <xsl:call-template name="InitJS"></xsl:call-template>
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
        <!--   Form 8827 CSS Styles are located in the template called below    -->
        <xsl:call-template name="IRS8827Style"></xsl:call-template>
        <xsl:call-template name="AddOnStyle"></xsl:call-template>
      </xsl:if>
    </style>  
  <xsl:call-template name="GlobalStylesForm"/>
</head>
  
  <body class="styBodyClass">
    <form name="Form8827">
      <xsl:call-template name="DocumentHeader"></xsl:call-template>      
      
      <!-- Begin Form Number and Name -->
      <div class="styBB" style="width:187mm;">
      <div class="styFNBox" style="width:31mm;height:19mm;">
        Form <span class="styFormNumber">8827</span>
        <br/><br/>
        <span class="styAgency">Department of the Treasury</span>
        <br/>
        <span class="styAgency">Internal Revenue Service</span>
      </div>
      <div class="styFTBox" style="width:123mm;height:13mm;">
        <div class="styMainTitle" style="height:8mm;">
          Credit for Prior Year Minimum Tax-Corporations
        </div>
        <br/>        
        <div class="styFST" style="height:5mm;font-size:7pt;">
          <img src="{$ImagePath}/8827_Bullet_Title.gif" width="4" height="7" alt="Bullet Image"/>
          Attach to the corporation's tax return.
        </div>
      </div>
      <div class="styTYBox" style="width:32mm;height:19mm;">
        <div class="styOMB" style="height:2mm;">
          OMB No. 1545-1257
        </div>
        <div class="styTY" style="height:11mm;padding-top:2mm;">
          20<span class="styTYColor">07</span>
        </div>        
      </div>
    </div>    
    <!-- End Form Number and Name section -->
    <!-- Begin Names and Identifying number section -->

    <div class="styBB" style="width:187mm;">
      <div class="styNameBox" style="width:140.75mm;height:8mm;font-size:7pt;">
        Name<br/>
        <div style="font-family:verdana;font-size:6pt;height:7mm">
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
        </div>
      </div>
      
      <div class="styEINBox" style="width:46mm;height:4mm;font-size:7pt;float:left;padding-left:1mm;">
        Employer identification number<br/><br/>
        <span style="font-weight:normal;">  
          <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
        </span>
      </div>
    </div>
    
    <!-- End Names and Identifying number section -->
        
    <div class="styBB" style="width:187mm">  
    <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;">
        1
      </div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        Alternative minimum tax (AMT) for 2006.  Enter the amount from line 14 of the 2006 Form 4626                
      </div>        
      <div class="styLNRightNumBox">
        1        
      </div>
      <div class="styLNAmountBox" style="height:4mm;" >
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$Form8827Data/AlternativeMinimumTaxForPY"/>
        </xsl:call-template>
      </div>        
    </div>  
    <div style="width:187mm">          
      <div class="styLNLeftNumBox" style="height:4mm;">
        2
      </div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        Minimum tax credit carryforward from 2006.  Enter the amount from line 9 of the 2006 Form 8827      
      </div>          
      
      <div class="styLNRightNumBox">
        2          
      </div>
      <div class="styLNAmountBox" style="height:4mm;" >
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$Form8827Data/MinimumTaxCreditFromPY"/>
        </xsl:call-template>
      </div>
        
    </div>  
    <div style="width:187mm">      

        <div class="styLNLeftNumBox" style="height:4mm;">
          3
        </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            Enter any 2006 unallowed qualified electric vehicle credit (see instructions). 
            <span class="styBoldText">
              
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.   
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.                                              
            </span>          
          </div>              
        
        <div class="styLNRightNumBox" >
          3          
        </div>
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$Form8827Data/PYElectricVehicleCredit"/>
        
          </xsl:call-template>
        </div>        
    </div>
    <div style="width:187mm">
      
      <div class="styLNLeftNumBox" style="height:4mm;">
        4
      </div>
      <div class="styLNDesc" style="width:138.75mm;height:4mm;">
        Add lines 1, 2, and 3          
        <span class="styBoldText">
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.  
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.
          <span style="width:16px;"></span>.                                  
        </span>            
      </div>              
      
      <div class="styLNRightNumBox">
        4          
      </div>
      <div class="styLNAmountBox" style="height:4mm;" >
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$Form8827Data/CreditForPYMinimumTax"/>
        </xsl:call-template>
      </div>        
    </div>
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          5
        </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            Enter the corporation's 2007 regular income tax liability minus allowable tax credits (see instructions)                    
          </div>              
        
        <div class="styLNRightNumBox">
          5          
        </div>
        <div class="styLNAmountBox" style="height:4mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8827Data/CYIncomeTaxLiability"/>
          </xsl:call-template>
        </div>        
    </div>
    <div style="width:187mm">
      
        <div class="styLNLeftNumBox" style="height:4mm;">
          6
        </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            Is the corporation a "small corporation" exempt from the AMT for 2007 (see instructions)?
            <br/>
            <img src="{$ImagePath}/8827_Bullet_Round.gif" width="6" height="6" alt="Bullet Image"/>
            <span class="styBoldText">  Yes. </span> Enter 25% of the excess of line 5 over $25,000.  If line 5 is $25,000 or less, enter -0-
            <br/>
            <img src="{$ImagePath}/8827_Bullet_Round.gif" width="6" height="6" alt="Bullet Image"/>
            <span class="styBoldText">  No. </span> 
            Complete Form 4626 for 2007 and enter the tentative minimum tax from line 12
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
               <span style="width:16px;"></span>.
                                
            </span>          

                                
          </div>              
        
        <div class="styLNRightNumBox" style="padding-top:6.5mm;">
          6          
        </div>
        <div class="styLNAmountBox" style="height:4mm;padding-top:6.5mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8827Data/SmallCorpExemptAmount"/>
          </xsl:call-template>
        </div>        
    </div>
    <div style="width:187mm">
    <!-- Empty space
      <div style="width:187mm">
        <div class="styLNDesc" style="width:146.5mm;height:2mm;"></div>
        <div class="styLNRightNumBoxNBB" style="width:8mm;"></div>
        <div class="styLNAmountBoxNBB" style="height:3mm;" ></div>
      </div>
    -->  
        <div class="styLNLeftNumBox" style="height:3mm;">
          7
        </div>
        <div class="styLNDesc" style="width:138.75mm;height:3mm;">
          Subtract line 6 from line 5.  If zero or less, enter -0-          
          <span class="styBoldText">
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.  
            <span style="width:16px;"></span>.
            <span style="width:16px;"></span>.                                    
          </span>          
        </div>              
        
        <div class="styLNRightNumBox" style="height:3.5mm;" >
          7          
        </div>
        <div class="styLNAmountBox" style="height:3.5mm;" >
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8827Data/CreditForSmallCorporation"/>
          </xsl:call-template>
        </div>        
    </div>
    <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">
          8
        </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            <span class="styBoldText">Minimum tax credit. </span>Enter the <span class="styBoldText">smaller</span> of line 4 or line 7 here and on Form 1120, Schedule J, line 5d or the appropriate 
            line of the corporation's income tax return.  If the corporation had a post-1986 ownership change or has pre-acquisition excess credits, see instructions 
             <!-- Adding pen image -->
            <span style="width:2px;"></span>
            <xsl:call-template name="LinkToLeftoverDataTableInline">
              <xsl:with-param name="Desc">Line 8 - Statement SEC</xsl:with-param>
              <xsl:with-param name="TargetNode" select="$Form8827Data/MinimumTaxCredit/@statementSEC"/>
            </xsl:call-template>          
        
              <span style="width:15px;"></span>  
            <!-- Form to Form Link -->
            <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$Form8827Data/MinimumTaxCredit"/>
            </xsl:call-template>
                        
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>. 
              <span style="width:16px;"></span>.
                                               
            </span>                   
          </div>                 
        <div class="styLNRightNumBox" style="height:10.5mm;" >
          <br/><br/>
          8          
        </div>
        <div class="styLNAmountBox" style="height:10.5mm;" >
          <br/><br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8827Data/MinimumTaxCredit"/>
          </xsl:call-template>
        </div>        
    </div>
    <div style="width:187mm">      
        <div class="styLNLeftNumBox" style="height:4mm;">
          9
        </div>
          <div class="styLNDesc" style="width:138.75mm;height:4mm;">
            <span class="styBoldText">Minimum tax credit carryforward to 2008. </span> Subtract line 8 from line 4.  Keep a record of this 
            amount to carry forward and use in future years          
            <span class="styBoldText">
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.  
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.
              <span style="width:16px;"></span>.                                                            
            </span>          
          </div>      
        
          <div class="styLNRightNumBoxNBB" style="height:8mm;padding-top:4mm;">
            9
          </div>
       
        <div class="styLNAmountBoxNBB" style="height:8mm;" >
          <br/>
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8827Data/MinimumTaxCreditForNextYear"/>
          </xsl:call-template>           
         </div>        
      </div>  
      </div>    

      <div style="width:187mm;text-align:right;">                            
        Cat. No. 13008K        
        <span style="width:240px;"></span>  
        Form <span class="styBoldText">8827</span> (2007)        
      </div>           
        <br/>
        <br class="pageEnd"/>  
      
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$Form8827Data" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>          
          <xsl:call-template name="PopulateLeftoverRow">
            <xsl:with-param name="Desc">Line 8 - Statement SEC</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$Form8827Data/MinimumTaxCredit/@statementSEC"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>
        </table>
        <!-- END Left Over Table -->  

      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
