<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="IRS8835Style.xsl"/>
<xsl:include href="AddOnTable.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>

<xsl:strip-space elements="*" />
<xsl:param name="FormData" select="$RtnDoc/IRS8835" />


<xsl:template match="/">
  	<html>
<head>  
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>
  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache"/>
  <meta http-equiv="Cache-Control" content="no-cache"/>
  <meta http-equiv="Expires" content="0"/>
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private"/>  
  <meta name="Author" content="Michelle Hayden - haydem@us.ibm.com" />
  <meta name="Description" content="Form IRS 8835"/>
  <meta name="GENERATOR" content="IBM WebSphere Studio"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/header.css"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/body.css"/>
  <link rel="stylesheet" type="text/css" href="{$CSSPath}/general.css"/>
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>  
  <style type="text/css">    
  <xsl:if test="not($Print) or $Print=''">  
      <xsl:call-template name="IRS8835Style"></xsl:call-template>
      <xsl:call-template name="AddOnStyle"></xsl:call-template>  
 </xsl:if>   
  </style>      
  
</head>

<body class="styBodyClass">
  <form name="Form8835">    
    <xsl:call-template name="DocumentHeader"></xsl:call-template>  
    
  <!--Title of Form -->    
  <div class="styBB" style="width:187mm;height: 20mm">
    <div class="styFNBox" style="width:31mm;font-size: 7pt;height: 20mm">
      Form <span class="styFormNumber">8835</span>      
      <br/>
      <xsl:call-template name="LinkToLeftoverDataTableInline">
        <xsl:with-param name="Desc">Fiscal Year Taxpayer Indicator</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/@fiscalYearTaxpayerIndicator"/>
        <xsl:with-param name="Style">padding-left:3mm;</xsl:with-param>
      </xsl:call-template>
      <br/>
      <div class="styAgency" style="padding-top: 1.5mm">Department of the Treasury</div><span class="styAgency">Internal Revenue Service</span>
    </div>
    <div class="styFTBox" style="height: 20mm;width:125mm">
      <div class="styMainTitle" style="height: 8mm; padding-top: 1.5mm">Renewable Electricity, Refined Coal,<br />and Indian Coal Production Credit</div>
      <div class="styFST" style="font-size:7pt;margin-left:3mm;font-weight:bold; padding-top: 5mm">
        <img src="{$ImagePath}/8835_Bullet.gif" alt="MediumBullet"/>  
        Attach to your tax return.
      </div>
    </div>
    <div class="styTYBox" style="width:30mm;height:20mm; border-left-width: 1px">
      <div class="styOMB" style="height:2mm;">OMB No. 1545-1362</div>
      <div class="styTaxYear" style="height:10mm">20<span class="styTYColor">07</span></div>
      <div class="stySequence">Attachment<br/>Sequence No. <b>95</b></div>
    </div>
  </div>
  <!--  End title of Form  -->
   
  <!--  Name and Employer identification number  -->
  <div class="styBB" style="width:187mm">
    <div class="styNameBox" style="width:141mm;font-size:7pt;">
      Name(s) shown on return<br/>
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
    </div>
    <div class="styEINBox" style=" padding-left:2mm;font-size:7pt;"><span class="BoldText">Identifying number</span>
      <div style="text-align:left;font-weight:normal;">    
        <br/>
        <xsl:choose>
          <xsl:when test="normalize-space($FormData/IdentifyingNumber) != ''">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$FormData/IdentifyingNumber" /></xsl:call-template>
          </xsl:when>  
          <xsl:otherwise>  
            <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>  
          </xsl:otherwise>
        </xsl:choose>
      </div>    
    </div>
  </div>  
  <!--  End Name and Employer indentification number  -->
 <div class="styBB" style="width: 187mm">
       <div class="styBoldText" style="padding-bottom:0mm;"><span style="font-size: 10pt">Section A. </span><span style="width: 1mm" /><span style="font-size: 9pt"> Electricity produced at qualified facilities placed in service prior to October 23, 2004</span></div>
       <br/>
 </div>  
  <!--  Line 1 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 4mm">1</div>
    <span class="styLNDesc" style="width: 137mm">
      Kilowatt-hours produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ..
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/NumKwHrsProducedAndSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>0.02</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">1</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalKwHrsProducedAndSoldCr"/>
          </xsl:call-template>
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalKwHrsProducedAndSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 1 -->
  
  <!--  Line 2 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left:4mm">2</div>
    <span class="styLNDesc" style="width: 137mm">
      Phaseout adjustment (see instructions)  
      <span style="width: 26.5mm">
        <span class="styDotLn" style="float: none">  
          .......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 34mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditBeforePhaseoutAdjustment"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/PhaseoutAdjustmentRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">2</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalPhaseoutAdjustment"/>
          </xsl:call-template>
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalPhaseoutAdjustment"/>
        </xsl:call-template>
      </span>          
  </div>
  <!--  Line 2 -->
  
  <!--  Line 3 -->  
  <div style="width:187mm">
    <div class="styLNLeftNumBox" style="padding-left: 4mm; height:4mm;">3</div>
    <div style="float: left; padding-top: .5mm">
      Credit before reduction. Subtract line 2 from line 1     
    </div>   
     <div style="float: right"> 
      <!--Dotted Line-->
        <div class="styDotLn" style="padding-top: .5mm">  
          .................
        </div>
    <div class="styLNRightNumBox" style="height:4.5mm">3
    </div>
    <div class="styLNAmountBox" style="height:4.5mm; width: 34mm">
      <xsl:call-template name="PopulateAmount">     
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditBeforeReduction"/>
      </xsl:call-template>
    </div>
    </div>
  </div>

  <!--  Line 3 -->

  <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Reduction for government grants, subsidized financing, and other credits:
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
  
  <!--  Line 4 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 4mm">4</div>
    <div style="float: left; padding-top: .5mm; font-size:6pt; ">
      Total of government grants, proceeds of tax-exempt government obligations, subsidized energy financing,
    </div>
    <div style="float: right">
      <span class="styLNRightNumBox" style="background-color: lightgrey; border-bottom-width: 0px" />
      <span class="styLNAmountBox" style="width: 34mm; background-color: lilghtgrey; border-bottom-width: 0px" />        
    </div>
  </div>
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox"/>
    <div style="float: left; padding-top: .5mm; font-size:6pt;">
       and any federal tax credits allowed for the project for this and all prior tax years (see instructions)
    </div>
    <div style="float: right">    
        <span class="styDotLn" style="padding-top: .5mm">  
         .......
      </span>
      <span class="styLNRightNumBox" style="height: 5mm">4</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalOfGovernmentGrants"/>
        </xsl:call-template>
      </span>        
    </div>
  </div>
  <!--  Line 4 -->
  
  <!--  Line 5 -->  
    <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 4mm">5</div>
    <div style="float: left; padding-top: .5mm">
     Total of additions to the capital account for the project for this and all prior tax years
     </div>
   <div style="float: right">
        <span class="styDotLn" style="padding-top: .5mm">  
          ...... 
      </span>
      <span class="styLNRightNumBox" style="height: 5mm">5</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
       
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalOfCapitalAccountAdditions"/>
        </xsl:call-template>
      </span> 
    </div>       
  </div>
  <!--  Line 5 -->
  
  <!--  Line 6 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 4mm">6</div>
    <div style="float:left; padding-top: .5mm">
      Divide line 4 by line 5. Show as a decimal carried to at least 4 places  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ...........
      </span>        
      <div class="styLNRightNumBox">6</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditReductionPercentage"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!--  Line 6 -->
  
  <!--  Line 7 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 4mm">7</div>
    <div style="float:left; padding-top: .5mm">
      Multiply line 3 by line 6  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ..........................
      </span>        
      <div class="styLNRightNumBox">7</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/CreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 7  -->
  
  <!--  Line 8 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 4mm">8</div>
    <div style="float:left; padding-top: .5mm">
      Subtract line 7 from line 3  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        .........................
      </span>        
      <div class="styLNRightNumBox">8</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/AdjustedCreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 8  -->
  
  <!--  Line 9  -->
  
         <div style="width:187mm;float:left;clear:none;">
               <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:4mm;">9</div>
               <div class="styLNDesc" style="width:137mm;height:4.5mm;">
                      Section A renewable electricity production credit from partnerships, S corporations,
                       cooperatives, estates, and trusts  
                      <span class="styBoldText">
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                        <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                        <span style="width:16px;"></span>.
                       <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                        <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                        <span style="width:16px;"></span>.
                  </span>
                      
               </div>
               <div class="styLNRightNumBoxNBB" style="height:4.3mm;background-color:lightgrey;"></div>
               <div class="styLNAmountBoxNBB" style="height:4.3mm;"></div>
               <div class="styLNRightNumBox" style="height:4.5mm;">9</div>
               <div class="styLNAmountBox" style="width:34.25mm;">
                     <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/RenewableElectricityProdCr"/>
      
                    </xsl:call-template>
               </div>
           </div>

  
    

  <!--  Line 10 -->  
         <div style="width:187mm;float:left;clear:none;">
               <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:2mm;">10</div>
               <div class="styLNDesc" style="width:137mm;height:4.5mm;">
                    Add lines 8 and 9. Cooperatives, estates, and trusts, go to line 11; partnerships and S corporations,
                     report this amount on Schedule K; all others, report this amount on Form 3800, line 1f
                      <span class="styBoldText">
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                  </span>
                      
               </div>
               <div class="styLNRightNumBoxNBB" style="height:2mm;"></div>
               <div class="styLNAmountBoxNBB" style="height:2mm;"></div>
               <div class="styLNRightNumBox" style="height:1mm;">10</div>
               <div class="styLNAmountBox" style="width:34.25mm;">
                     <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/AdjCrRedandRnwbleElecProdCr"/>
                      </xsl:call-template>
               </div>
           </div>
  
  <!--  Line 10 -->
  
   <!--  Line 11 -->  
     <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">11</div>
    <div style="float:left; padding-top: .5mm;">
      Amount allocated to patrons of the cooperative or beneficiaries of the estate or trust (see instructions)  
    </div>    
    <div style="float:right">    
<!--      <span class="styDotLn" style="padding-top: .5mm">  
        .
      </spa>        -->
      <div class="styLNRightNumBox">11</div>
      <div class="styLNAmountBox" style="width: 34.25mm; ">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/AmtAllocToPatronsofCooporBenef"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  
    <!--  Line 11 -->
  
   <!--  Line 12 -->  
          <div style="width:187mm;float:left;clear:none;">
               <div class="styLNLeftNumBox" style="height:4.5mm;padding-left:2mm;">12</div>
               <div class="styLNDesc" style="width:137mm;height:4.5mm;">
                <span class="styBoldText">Cooperatives, estates, and trusts.</span> Subtract line 11 from line 10. Report the credit on
                   <div>Form 3800, line 1f 
                    <span class="styBoldText">
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                         <span style="width:16px;"></span>.
                      
                  </span>
                    </div>  
               </div>
               <div class="styLNRightNumBoxNBB" style="height:2mm;"></div>
               <div class="styLNAmountBoxNBB" style="height:2mm;"></div>
               <div class="styLNRightNumBoxNBB" style="height:1mm;">12</div>
               <div class="styLNAmountBoxNBB" style="width:34.25mm;">
                     <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/EstatesTrustsandCooperativesCr"/>
                      </xsl:call-template>
               </div>
           </div>
  <!--  Line 12 -->
<!-- Section B Box -->
 <div class="styBB" style="width: 187mm;border-top-width: 1px">
       <div class="styBoldText"><span style="font-size: 10pt">Section B.</span><span style="width: 1mm" /><span style="font-size: 8pt"> Electricity and refined coal produced at qualified facilities placed in service after <br /><span style="width: 21.5mm" /> October 22, 2004
       and Indian coal produced at facilities placed in service after August 8, 2005</span></div>
 </div>   

<!-- Section B Box -->

 <!--  Part II Title-->
    <!--  End Part II Title-->


<!-- Section B Box -->

  <!--  Part II Title-->
  <div class="styBB" style="width: 187mm; border-top-width: 0px">
    <div class="styPartName" style="width: 15mm">Part I</div>
    <div class="styPartDesc" style="width: 172mm">Current Year Credit </div>
  </div>
  <!--  End Part II Title-->
    
    <!-- Start here I--> 
    
  <div style="width187mm;">
      <div class="styLNDesc"><span style="padding-left:9mm;font-weight:bold; width:145mm;">Electricity produced at qualified facilities using wind, closed-loop biomass geothermal, and solar</span></div>
       <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;"></div>
       <div class="styLNAmountBoxNBB"></div>
   </div>
    
    <!-- Part I Line 1 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">1</div>
    <span class="styLNDesc" style="width: 137mm">
      Kilowatt-hours produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ..
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NumClosedLoopKwHrsPrdcdAndSold"/>
        </xsl:call-template>  
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>0.02</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">1</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotClosedLoopKwHrsPrdcdSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 1 -->

 <div style="width187mm;">
      <div class="styLNDesc"><span style="padding-left:9mm;font-weight:bold; width:145mm;">Electricity produced at qualified facilities using open-loop biomass, small irrigation power,</span></div>
       <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;"></div>
       <div class="styLNAmountBoxNBB"></div>
   </div>
   <div style="width187mm;">
      <div class="styLNDesc"><span  style="font-weight:bold; width:145mm; padding-left:9mm;">landfill gas, trash combustion, and hydropower</span></div>
       <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;"></div>
       <div class="styLNAmountBoxNBB"></div>
   </div>
    
    <!-- Part I Line 2 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">2</div>
    <span class="styLNDesc" style="width: 137mm">
      Kilowatt-hours produced and sold (see instructions)
      <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          ..
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NumOpenLoopPrdcdSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>.01</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">2</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
<!--          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalKwHrsProducedAndSoldCr"/>
          </xsl:call-template>  -->
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotOpenLoopPrdcdSold"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 2 -->
  
    <!-- Part I Line 3 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">3</div>
    <div style="float:left; padding-top: .5mm">
      Add lines 1 and 2  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ..........................
      </span>        
      <div class="styLNRightNumBox">3</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotClosedOpenKwHrsPrdcdSoldCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 3  -->

 <!-- Part I Line 4 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">4</div>
    <span class="styLNDesc" style="width: 137mm">
      Phaseout adjustment (see instructions)  
      <span style="width: 26.5mm">
        <span class="styDotLn" style="float: none">  
          .......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 34mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopCrBfrPhaseoutAdj"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopPhaseoutAdjRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">4</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
  <!--        <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalPhaseoutAdjustment"/>
          </xsl:call-template>   -->
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopTotalPhaseoutAdj"/>
        </xsl:call-template>
      </span>          
  </div>
  <!--  Line 4 -->

 <!-- Part I  Line 5 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">5</div>
    <div style="float:left; padding-top: .5mm">
      Subtract line 4 from line 3  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        .........................
      </span>        
      <div class="styLNRightNumBox">5</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ClosedOpenLoopKwHrsCrMinusAdj"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 5  -->

   <div style="width187mm;">
      <div class="styLNDesc"><span  style="font-weight:bold; width:145mm; padding-left:9mm;">Refined coal produced at a qualified refined coal production facility</span></div>
       <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;"></div>
       <div class="styLNAmountBoxNBB"></div>
   </div>


    <!-- Part I Line 6 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">6</div>
    <span class="styLNDesc" style="width: 137mm">
      Tons produced and sold (see instructions)
        <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          .....
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NumRefinedCoalTonsPrdcdAndSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>$5.877</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">6</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
   <!--       <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesPriorTo1023/TotalKwHrsProducedAndSoldCr"/>
          </xsl:call-template>   -->
        </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotRefinedCoalTonsPrdcdSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 6 -->

<!-- Part I Line 7 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">7</div>
    <span class="styLNDesc" style="width: 137mm">
      Phaseout adjustment (see instructions)  
      <span style="width: 26.5mm">
        <span class="styDotLn" style="float: none">  
          .......
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 34mm">$
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalCrBeforePhaseoutAdj"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span><span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 10mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalPhaseoutAdjRate"/>
        </xsl:call-template>
        </span>
      </span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">7</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
    <!--      <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalPhaseoutAdjustment"/>
          </xsl:call-template>  -->
        </span> 
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalTotalPhaseoutAdj"/>
        </xsl:call-template>
      </span>          
  </div>
  <!--  Line 7 -->

 <!-- Part I  Line 8 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">8</div>
    <div style="float:left; padding-top: .5mm">
      Subtract line 7 from line 6  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        .........................
      </span>        
      <div class="styLNRightNumBox">8</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalTonsCreditMinusAdj"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 8  -->

   <div style="width187mm;">
      <div class="styLNDesc"><span  style="font-weight:bold; width:145mm; padding-left:9mm;">Indian Coal produced at a qualified Indian coal production facility</span></div>
       <div class="styLNRightNumBoxNBB"></div>
       <div class="styLNAmountBoxNBB"></div>
   </div>


    <!-- Part I Line 9 -->    
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 2mm">9</div>
    <span class="styLNDesc" style="width: 137mm">
      Tons produced and sold (see instructions)
        <span style="width: 7mm">
        <span class="styDotLn" style="float: none">  
          .....
        </span>  
      </span>
      <span style="border-color: black; border-style: solid; border-right-width: 0px; border-left-width: 0px; border-top-width: 0px; border-bottom-width: 1px; width: 36mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="MaxSize" select="18"/>        
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/IndianCoalProducedAndSold"/>
        </xsl:call-template>
      </span>
      <span style="width: 22mm"><span style="width: 2mm"></span> X<span style="width: 2mm"></span>$1.544</span>
    </span>
      <span class="styLNRightNumBox" style="height: 5mm">9</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">
        <span style="float: left; clear:none">
         </span>
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotIndianCoalProducedAndSoldCr"/>
        </xsl:call-template>
      </span>        
  </div>
  <!--  Line 9 -->

 <!-- Part I  Line 10 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">10</div>
    <div style="float:left; padding-top: .5mm">
      Credit before reduction. Add lines 5, 8, and 9  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ...................
      </span>        
      <div class="styLNRightNumBox">10</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RefinedCoalCrBeforeReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 10  -->

  <div style="width: 187mm">  
    <div style="float:left; padding-left: 8.5mm; padding-top: .5mm">
      <span class="styBoldText">
        Reduction for government grants, subsidized financing, and other credits:
      </span>
    </div>    
    <div style="float:right">          
      <div class="styLNRightNumBox" style="background-color: lightgrey; height: 4mm; border-bottom-width: 0px"></div>
      <div class="styLNAmountBox" style="height: 4mm; border-bottom-width: 0px; width: 34.25mm">        
      </div>          
    </div>
  </div>
  
  <!--  Part I Line 11 -->  
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">11</div>
    <div style="float: left; padding-top: .5mm; font-size:6pt; ">
      Total of government grants, proceeds of tax-exempt government obligations, subsidized energy financing,
    </div>
    <div style="float: right">
      <span class="styLNRightNumBox" style="background-color: lightgrey; border-bottom-width: 0px" />
      <span class="styLNAmountBox" style="width: 34mm; background-color: lilghtgrey; border-bottom-width: 0px" />        
    </div>
  </div>
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox"/>
    <div style="float: left; padding-top: .5mm; font-size:6pt;">
       and any federal tax credits allowed for the project for this and all prior tax years (see instructions)
    </div>
    <div style="float: right">    
        <span class="styDotLn" style="padding-top: .5mm">  
         .......
      </span>
      <span class="styLNRightNumBox" style="height: 5mm">11</span>
      <span class="styLNAmountBox" style="width: 34mm; height: 5mm">        
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalOfGovernmentGrants"/>
        </xsl:call-template>
      </span>        
    </div>
  </div>
  <!--  Line 11 -->

<!-- Part I  Line 12 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">12</div>
    <div style="float:left; padding-top: .5mm">
        Total of additions to the capital account for the project for this and all prior tax years
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ......
      </span>        
      <div class="styLNRightNumBox">12</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalOfCapitalAccountAdditions"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 12  -->

<!-- Part I  Line 13 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">13</div>
    <div style="float:left; padding-top: .5mm">
      Divide line 11 by line 12. Show as a decimal carried to at least 4 places  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ..........
      </span>        
      <div class="styLNRightNumBox">13</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateText">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CreditReductionPercentage"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 13  -->

<!-- Part I  Line 14 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">14</div>
    <div style="float:left; padding-top: .5mm">
      Multiply line 10 by the lesser of 1⁄2 or line 13  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ...................
      </span>        
      <div class="styLNRightNumBox">14</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 14  -->

<!-- Part I  Line 15 -->
  <div class="styBB" style="width:187mm;">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">15</div>
    <div style="float:left; padding-top: .5mm">
      Subtract line 14 from line 10  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ........................
      </span>        
      <div class="styLNRightNumBox">15</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjustedCreditReduction"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 15  -->



<!--  FOOTER-->
        <div style="width:187mm;">
          <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions.</span> 
          <span style="width:20mm;"></span>                      
          Cat. No. 14954R 
          <span style="width:170px"></span>  
          Form <span class="styBoldText">8835</span> (2007)
        </div>
        <div class="pageEnd" />      
<!--END FOOTER-->

<!--BEGIN HEADER-->
<div class="styBB" style="width:187mm">
	<div style="float: left; clear: none">Form 8835 (2007)</div>				
	<div style="float:right">
		Page <span class="styBoldText" style="font-size: 8pt">2</span>
	</div>			
</div> 
<!--END HEADER-->

<!--  Part II Title-->
  <div class="styBB" style="width: 187mm; border-top-width: 0px">
    <div class="styPartName" style="width: 15mm">Part I</div>
    <div class="styPartDesc" style="width: 172mm"><i>Continued </i></div>
  </div>
  <!--  End Part II Title-->
  

     <!-- Part I Line 16  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">16</div>
        <div style="float:left; padding-top: .5mm">
          Section B renewable electricity, refined coal, and Indian coal production credit from partnerships,        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
        S corporations, cooperatives, estates, and trusts
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              .................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">16</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RenElecRfndandIndianCoalProdCr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 16  -->
  
       <!-- Part I Line 17  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">17</div>
        <div style="float:left; padding-top: .5mm">
             Add lines 15 and 16. Partnerships and S corporations, report this amount on Schedule K;
         </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
        all others continue to line 18
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ........................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">17</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/GovtGrantsAndModifBiomassCr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 17  -->
  
     <!-- Part I Line 18  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">18</div>
        <div style="float:left; padding-top: .5mm">
           Renewable electricity, refined coal, and Indian coal production credit included on line 17 from
        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
             passive activities (see instructions)
         </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ......................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">18</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RenewableElecRefinedCoalProdCr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 18  -->
  
<!-- Part I  Line 19 -->
  <div style="width: 187mm">  
    <div class="styLNLeftNumBox" style="padding-left: 1mm">19</div>
    <div style="float:left; padding-top: .5mm">
      Subtract line 18 from line 17  
    </div>    
    <div style="float:right">    
      <span class="styDotLn" style="padding-top: .5mm">  
        ........................
       </span>        
      <div class="styLNRightNumBox">19</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjGovtGrantsAndModifBiomassCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>  
  <!--  Line 19  -->

     <!-- Part I Line 20  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">20</div>
        <div style="float:left; padding-top: .5mm">
           Renewable electricity, refined coal, and Indian coal production credit allowed for 2007 from a
        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
             passive activity (see instructions)
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ......................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">20</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RnwblElecRefinedCoalCrAllwed"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 20  -->

     <!-- Part I Line 21  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">21</div>
        <div style="float:left; padding-top: .5mm">
           Carryforward of renewable electricity, refined coal, and Indian coal production credit to 2007.
              <!-- Form to Form Link -->
        <xsl:call-template name="LinkToLeftoverDataTableInline">
          <xsl:with-param name="Desc">Line 21 - Form 8884 Indicator</xsl:with-param>
          <xsl:with-param name="TargetNode" 
          select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalCr/@form8884Indicator"/>
        </xsl:call-template>
              <xsl:call-template name="LinkToLeftoverDataTableInline">
          <xsl:with-param name="Desc">Line 21 - Form 8884 Amount</xsl:with-param>
          <xsl:with-param name="TargetNode" 
          select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalCr/@form8884Amount"/>
        </xsl:call-template>


        </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;">21</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" 
            select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalCr"/>
          </xsl:call-template>
        </div>

        </div>
      </div>
    
      <!--  Line 21  -->

     <!-- Part I Line 22  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">22</div>
        <div style="float:left; padding-top: .5mm">
           Carryback of renewable electricity, refined coal, and Indian coal production credit from 2008 (see        
         </div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
             instructions.)
         </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              .............................
            </span>          
        <div class="styLNRightNumBox" style="height:4.5mm;">22</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CybkRnwblElecRefinedCoalCr"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 22  -->


     <!-- Part I Line 23  -->
  <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">23</div>
        <div style="float:left; padding-top: .5mm">
           Add lines 19 through 22.  Cooperatives, estates, and trusts, go to line 24; all others, go to Part II
            <span style="width:2px;"></span>
        <!-- Form to Form Link -->
        <xsl:call-template name="LinkToLeftoverDataTableInline">
          <xsl:with-param name="Desc">Line 23 - Form 6478 Indicator</xsl:with-param>
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalAllowedTaxCredit/@form6478Indicator"/>
        </xsl:call-template>
        
            <xsl:call-template name="LinkToLeftoverDataTableInline">
          <xsl:with-param name="Desc">Line 23 - Form 6478 Indicator</xsl:with-param>
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalAllowedTaxCredit/@form6478Amount"/>
        </xsl:call-template>
    
        
        
         </div>
        <div style="float: right">        
      <div class="styLNRightNumBox" style="height:4.5mm;">23</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalAllowedTaxCredit"/>
          </xsl:call-template>
        </div>

        </div>
      </div>
     
  <!--I Line 23  -->

 <!--  Part  Line 24 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">24</div>
      <div style="float: left; padding-top: .5mm">
        Amount allocated to patrons of the cooperative or beneficiaries of the estate or trust (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            
          </span>        
      <div class="styLNRightNumBox">24</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AmtAlloctoPtronsofCooporBenef"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 24 -->
   
    <!-- Part   Line 25 -->  
  <div class="styBB"  style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">25</div>
      <div style="float: left; padding-top: .5mm"><span class="styBoldText">Cooperatives, estates, and trusts.</span><span style="text-weight:normal;">Subtract line 24 from line 23. Use this amount to complete Part II</span>
        </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            
          </span>        
      <div class="styLNRightNumBoxNBB">25</div>
      <div class="styLNAmountBoxNBB" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/EstatesTrustsandCooperativesCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 25 -->

<!--  Part II Title-->
  <div class="styBB" style="width: 187mm; border-top-width: 0px">
    <div class="styPartName" style="width: 15mm">Part II</div>
    <div class="styPartDesc" style="width: 172mm">Allowable Credit</div>
  </div>
  <!--  End Part II Title-->


  <!-- Part II  Line 26 -->  
  <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">26</div>
      <div style="float: left; padding-top: .5mm">
        Regular tax before credits (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ...................
          </span>        
      <div class="styLNRightNumBox">26</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RegularTaxBeforeCredits"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
    <!-- End Line 26 -->
    
    <!-- Part II  Line 27 -->
    <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">27</div>
      <div style="float: left; padding-top: .5mm">
        Alternative minimum tax (see instructions) 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            ....................
          </span>        
      <div class="styLNRightNumBox">27</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AlternativeMinimumTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>
  <!-- Part II  Line 27 -->    
      
      <!-- Line 28-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">28</div>
        <div style="float: left; padding-top: .5mm">
          Add lines 26 and 27
        </div>
          <!--Dotted Line-->
        <div style="float: right">
          <span class="styDotLn" style="padding-top: .5mm">  
            ...........................
          </span>  
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top=1mm;">28</div>
        <div class="styLNAmountBox" style="height:5mm;width: 34.25mm">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/RegTaxPlusAlternativeMinTax"/>
          </xsl:call-template>
        </div>
      </div>
      </div>
      <!-- Part II Line 28-->

    <!-- Part II  Line 29a  -->        
        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">29a</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         Credits from Form 1040, lines 47 through 50 and lines 52 through 54
        </div>
        <div class="styLNRightNumBoxNBB" style="height:4.5mm" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px" />
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;" />
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4mm;"></div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         (or Form 1040NR, lines 44, 45  and 47 through 49)           
           <!--Dotted Line-->
            <span style="letter-spacing:3.5mm; font-weight:bold">  
              ......
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">29a</div>
        <div class="styLNAmountBox" style="height:4.5mm">
          </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;" />
      </div>
      <!--  Part II Line 29a  -->
      
      <!-- Line 29b-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:5mm;">b</div>
        <div class="styLNDesc" style="width:97mm;height:4mm">
          Foreign tax credit
          <span class="styDotLn" style="float: none">  
            ..................
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">29b</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/ForeignTaxCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 29b-->     
      
      <!--Part II  Line 29c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Credits from Forms 5735 and 8834
             <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              ............
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">29c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CreditsFromForms5735And8834"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 29c -->
      
      <!-- Part II Line 29d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Non-business Alternative motor vehicle credit (Form 8910, line 18)
            <!--Dotted Line-->
           
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">29d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AlternativeMotorVehicleCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 29d -->
      
      <!-- Part II Line 29e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">e</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
           Non-business Alternative fuel vehicle refueling property credit (Form 8911, line 19)
           <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
            
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:8mm;padding-top:4mm">29e</div>
        <div class="styLNAmountBox" style="height:8mm;padding-top:4mm">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AltFuelVehicleRefuelingPropCr"/>
          </xsl:call-template>
          </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:8mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 29e -->
      
      <!--  Part II Line 29f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">f</div>
        <div style="float: left">
          Add lines 29a through 29e
        </div>
        <div style="float:right">
          <!--Dotted Line-->
            <span class="styDotLn">  
              .........................
            </span>  
        <div class="styLNRightNumBox" style="height:4.5mm;">29f</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalTaxCredits"/>
          </xsl:call-template>
        </div>
      </div>
      </div>
      <!-- Line 29f  -->
      
      <!--Part II  Line 30  -->
 <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">30</div>
      <div style="float: left; padding-top: .5mm">
       Net income tax. Subtract line 29f from line 28. If zero, skip lines 31 through 34 and enter-0- on line 35 
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
            
          </span>        
      <div class="styLNRightNumBox">30</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NetIncomeTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>

      <!--  Line 30  -->
      
       
      
       <!--Part II  Line 31  -->
 <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">31</div>
      <div style="float: left; padding-top: .5mm">
            Net regular tax. Subtract line 29f from line 26. If zero or less, enter -0-
       </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
             ..........      
          </span>        
      <div class="styLNRightNumBox">31</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/NetRegularTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>

      <!--  Line 31  -->
      
      
                    <!--Part II  Line 32  -->
 <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">32</div>
      <div style="float: left; padding-top: .5mm">
            Enter 25% (.25) of the excess, if any, of line 31 over $25,000 (see instructions)
       </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
             .......       
          </span>        
      <div class="styLNRightNumBox">32</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/Pct25OfExcessNetRegularTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>

      <!--  Line 32  -->

      
      
             <!--Part II  Line 33  -->
 <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">33</div>
      <div style="float: left; padding-top: .5mm">
            Subtract line 32 from line 30. If zero or less, enter -0-
       </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
             ................       
          </span>        
      <div class="styLNRightNumBox">33</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjustedNetIncomeTax"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>

<!--  Line 33  -->

<!-- Part II  Line 34 a -->        
        <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">34a</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         General business credit (Form 3800, Line 19)
          <span class="styDotLn" style="float: none">  
            ........
          </span>  
 
        </div>
     <div class="styLNRightNumBox" style="height:4.5mm;">34a</div>

        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 1px">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/GeneralBusinessCredit"/>
          </xsl:call-template>

        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;" />
      </div>
         
 <!--  Part II Line 34a  -->
      
      <!-- Line 34b-->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;padding-left:5mm;">b</div>
        <div class="styLNDesc" style="width:97mm;height:4mm">
         Empowerment Zone and renewal community employment credit (Form 8844, Line 26)
          <span class="styDotLn" style="float: none">  
            ..................
          </span>  
        </div>
        <div class="styLNRightNumBox" style="height:8mm;padding-top:4mm">34b</div>
        <div class="styLNAmountBox" style="height:8mm;padding-top:4mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/EmpowermentZoneRnwlComEmplmnCr"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:8mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34b-->     
      
      <!--Part II  Line 34c -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">c</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
         Work opportunity credit (Form 5884, Line 22)
             <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              ......
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34c</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/WorkOpportunityCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34c -->
      
      <!-- Part II Line 34d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">d</div>
        <div class="styLNDesc" style="width:97mm;height:4mm;">
          Alcohol fuels credit (Form 6478, Line 24)
            <!--Dotted Line-->
            <span class="styDotLn" style="float: none">  
              .....
            </span>  
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">34d</div>
        <div class="styLNAmountBox" style="height:4.5mm;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AlcoholFuelsCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <!-- Line 34d -->
   
      <!--  Part II Line 34e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBoxDD" style="height:4mm;">e</div>
        <div style="float: left">
          Add lines 34a through 34d
        </div>
        <div style="float:right">
          <!--Dotted Line-->
            <span class="styDotLn">  
              .........................
            </span>  
        <div class="styLNRightNumBox" style="height:4.5mm;">34e</div>
        <div class="styLNAmountBox" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalCredit"/>
          </xsl:call-template>
        </div>
      </div>
      </div>
      <!-- Line 34e  -->

 <!-- Part II Line 35  -->
 <div style="width:187mm;">
      <div class="styLNLeftNumBox" style="height:4mm;">35</div>
      <div style="float: left; padding-top: .5mm">
            Subtract line 34e from line 33. If zero or less, enter -0-
      </div>        
      <div style="float:right">    
          <span class="styDotLn" style="padding-top: .5mm">  
             ................       
          </span>        
      <div class="styLNRightNumBox">35</div>
      <div class="styLNAmountBox" style="width: 34.25mm">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/AdjNetIncomeTaxMinusGenBusCr"/>
        </xsl:call-template>
      </div>          
    </div>
  </div>

      <!--  Line 35  -->

  
   <!--  Line 36  -->
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;">36</div>
        <div style="float:left; padding-top: .5mm">
          <span class="styBoldText">Credit allowed for the current year. Cooperatives, estates, and trusts.</span> Enter the <span class="styBoldText">smaller </span>of</div>
        <div style="float: right">        
        <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
        <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
          line 25 or line 35. Report this amount on Form 1041, Schedule G, line 2c; or Form 1120-C,</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
      <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
           Schedule J, line 5c. If line 35 is smaller than line 25, see instructions. <b>All others.</b> Enter the <span class="styBoldText"> smaller</span></div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
       <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
          of line 23 or line 35. Report this amount on Form 1040, line 55; Form 1040NR, line 50; Form 1120,</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>
  <div style="width:187mm">
      <div class="styLNLeftNumBox" style="height:4mm;" />
        <div style="float:left;padding-top: .5mm">
          Schedule J, line 5c; or the applicable line of your return. If line 35 is smaller than line 23, see</div>
        <div style="float: right">        
            <div class="styLNRightNumBox" style="height:4.5mm;background-color:lightgrey;border-bottom-width: 0px" />
            <div class="styLNAmountBox" style="height:4.5mm;border-bottom-width: 0px;width: 34.25mm" />
        </div>
      </div>

      <div class="styBB"  style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4mm;"></div>
        <div style="float:left">
          instructions
        </div>
        <div style="float: right">
            <!--Dotted Line-->
            <span class="styDotLn">  
              ..............................
            </span>          
        <div class="styLNRightNumBoxNBB" style="height:4.5mm;">36</div>
        <div class="styLNAmountBoxNBB" style="height:4.5mm;width: 34.25mm">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CurrentYearCreditAllowed"/>
          </xsl:call-template>
        </div>
        </div>
      </div>
      <!--  Line 43  -->
      
 
  
     
       
      <!--  FOOTER-->
        <div style="width:187mm">
        <span style="float: right">
          Form <span class="styBoldText">8835</span> (2007)
        </span>
        </div>

        <br class="pageEnd"/>
        <br/><br/>

<!--END FOOTER-->
          
        <!-- BEGIN Left Over Table -->  
        <!-- Additonal Data Title Bar and Button -->
        <div class="styLeftOverTitleLine" id="LeftoverData">
          <div class="styLeftOverTitle">
            Additional Data        
          </div>
          <div class="styLeftOverButtonContainer">
            <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
          </div>      
        </div>
        <!-- Additional Data Table -->
        <table class="styLeftOverTbl">
          <xsl:call-template name="PopulateCommonLeftover">
            <xsl:with-param name="TargetNode" select="$FormData" />
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template>  
          
          
          <xsl:call-template name="PopulateLeftoverRow">
            <xsl:with-param name="Desc">Fiscal Year Taxpayer Indicator</xsl:with-param>
            <xsl:with-param name="TargetNode" select="$FormData/@fiscalYearTaxpayerIndicator"/>
            <xsl:with-param name="DescWidth" select="100"/>
          </xsl:call-template> 
          
          <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 21 - Form 8884 Indicator</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalCr/@form8884Indicator"/>
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
      
              <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 21 - Form 8884 Amount</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/CfwdRnwblElecRefinedCoalCr/@form8884Amount"/>
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>
  
      
      <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 23 - Form 6478 Indicator</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalAllowedTaxCredit/@form6478Indicator"/>
	   <xsl:with-param name="DescWidth" select="100"/>
     </xsl:call-template>

      <xsl:call-template name="PopulateLeftoverRow">
        <xsl:with-param name="Desc">Line 23 - Form 6478 Amount</xsl:with-param>
        <xsl:with-param name="TargetNode" select="$FormData/QualifiedFacilitiesAfter1022/TotalAllowedTaxCredit/@form6478Amount"/>
	   <xsl:with-param name="DescWidth" select="100"/>
     </xsl:call-template>






        </table>
      <!-- END Left Over Table -->      
  </form>  
</body>
</html>

</xsl:template>    

</xsl:stylesheet>
