<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="AddHeader.xsl"/>
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS8844Style.xsl"/>
  <xsl:output method="html" indent="yes" />
  <xsl:strip-space elements="*" />  
  <xsl:param name="Form8844Data" select="$RtnDoc/IRS8844" />  
  <xsl:template match="/">
    <html lang="EN-US">
      <head>
        <title>
          <xsl:call-template name="FormTitle">
            <xsl:with-param name="RootElement" select="local-name($Form8844Data)">
            </xsl:with-param>
          </xsl:call-template>
        </title>
        <!-- No Browser Caching -->
        <meta http-equiv="Pragma" content="no-cache" />
        <meta http-equiv="Cache-Control" content="no-cache" />
        <meta http-equiv="Expires" content="0" />
        <!-- No Proxy Caching  -->
        <meta http-equiv="Cache-Control" content="private" />
        <!-- Define Character Set -->
        <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
        <meta name="Description" content="IRS Form 8844" />
        <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
        <xsl:call-template name="InitJS"></xsl:call-template>
        <style type="text/css">
          <xsl:if test="not($Print) or $Print=''">
            <xsl:call-template name="IRS8844Style"></xsl:call-template>
            <xsl:call-template name="AddOnStyle"></xsl:call-template>
          </xsl:if>  
        </style>
        <xsl:call-template name="GlobalStylesForm"/>
      </head>
      <body class="styBodyClass">
        <form id="Form8844">
          <xsl:call-template name="DocumentHeader"></xsl:call-template>
          <div class="styTBB" style="width:187mm;">
            <div class="styFNBox" style="width:30mm;height:16mm;">
              <div style="height:9mm;">Form<span class="styFormNumber">  8844</span>
              <br />
              </div>
              <div style="height:6mm;padding-top:5mm;">
                <span class="styAgency">Department of the Treasury</span>
                <br />
                <span class="styAgency">Internal Revenue Service</span>
              </div>
            </div>
            <div class="styFTBox" style="width:125mm;height:16mm;">
              <div class="styMainTitle" style="height:12mm;font-size:13pt;padding-top:1mm;">
                Empowerment Zone and Renewal <br />Community Employment Credit
              </div>
              <div class="styFMT" style="height:4mm;font-size:7pt;padding-top:5mm;">
                <img src="{$ImagePath}/8844_Bullet.gif" alt="Bullet Image" />
                Attach to your tax return.
              </div>
            </div>
            <div class="styTYBox" style="width:32mm;height:12mm;">
              <div class="styOMB" style="height:3mm;padding-top:0mm;">
                OMB No. 1545-1444
              </div>
              <div class="styTY" style="height:3mm;font-size:21pt;padding-top:0mm;padding-bottom:0mm;">
                    20<span class="styTYcolor">07</span>
              </div>
              <div class="styOMB" style="height:3.5m;text-align:left;padding-left:5mm;border-bottom-width:0px;">
                    Attachment <br />Sequence No. <span class="styBoldText">99</span>
              </div>
            </div>
          </div>    
          <!-- End Form Number and Name section -->
          <!-- Begin Names and Identifying number section -->
          <div style="width:187mm;" class="styBB">
            <div style="width:138mm;height:8mm;font-weight:normal;font-size:7pt;" class="styNameBox">
              Name(s) shown on return<br />
             <div style="font-family:verdana;font-size:6pt;height:6.25mm">      
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
             <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
             </div>            
            </div>
            
            <div style="width:49mm;height:4mm;padding-left:2mm;font-size:7pt;" class="styEINBox">
              Identifying number<br /><br />
              <span style="font-weight:normal;">  
      		<xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
              </span>      
            </div>
          </div>    
          <!-- End Names and Identifying number section -->
          <!-- Start Part I Current Year Credit -->    
          <div style="width:187mm;" class="styBB">
            <div class="styPartName" style="width:15mm;">Part I</div>
            <div class="styPartDesc" style="padding-left:3mm;">
              Current Year Credit  
            </div>
          </div>
          <!-- Part I, line 1 -->          
          <div style="width:187mm;">
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">1
                </div>
                <div class="styLNDesc" style="height:4mm;">        
                  Enter the total qualified wages paid or incurred during <span class="styBoldText">calendar year 2007</span> only (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4mm;border-right-width:1px;border-right-width:0px;">
                </div>
                <div class="styLNAmountBoxNBB">
                </div>
              </div>
            </div>      
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:5mm;">a</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Qualified empowerment zone wages
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ......
                </div>
                <div style ="width:3mm;float:left;clear:none;">
                  $   
                </div>
                <div style ="width:32mm;text-align:right;float:left;clear:none;">
                  <xsl:if test="not($Form8844Data/QualifiedEmpowermentZoneWages) or $Form8844Data/QualifiedEmpowermentZoneWages = ''">
                    <span style="width:1px;"></span>
                  </xsl:if>
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/QualifiedEmpowermentZoneWages"/>
                  </xsl:call-template>
                </div>
                <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 20% (.20)</div>
                <div style="width:12mm;float:left;Clear:none;"></div>
                <div class="styLNRightNumBox">
                  1a
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalQualifiedEmpwrZoneWages"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:5mm;">b</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Qualified renewal community wages
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ......
                </div>
                <div style ="width:3mm;float:left;clear:none;">
                  $   
                </div>
                <div style ="width:32mm;text-align:right;float:left;clear:none;">
                  <xsl:if test="not($Form8844Data/QualifiedRenewalCommunityWages) or $Form8844Data/QualifiedRenewalCommunityWages = ''">
                    <span style="width:1px;"></span>
                  </xsl:if>
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/QualifiedRenewalCommunityWages"/>
                  </xsl:call-template>
                </div>
                <div style="width:18mm;float:left;Clear:none;"><span style="width:4px;"></span>X 15% (.15)</div>
                <div style="width:12mm;float:left;Clear:none;"></div>
                <div class="styLNRightNumBox">
                  1b
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalQlfyRnwlCommunityWages"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>
            <!-- Part I, line 2 -->            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">2</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 1a and 1b. You <span class="styBoldText">must</span> subtract this amount from your deduction for salaries and wages
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBox">
                  2
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CurrentYearCredit1"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 3 -->            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="padding-left:3mm;">3</div>
                <div class="styLNDesc">
                    Employment zone and renewable community employment credit from parterships, S corporations,
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
            <div style="width:187mm;">
            	<div style="float:left;">
              		<div class="styLNLeftNumBox"></div>
                	<div class="styLNDesc" style="width:46mm;">
					cooperatives, estates, and trusts
				</div>
			</div>
			<div style="float:right;">
              		<div class="styDotLn" style="width:93mm;">
              			......................
              		</div>
                 	<div class="styLNRightNumBox">3</div>
                	<div class="styLNAmountBox">
                  		<xsl:call-template name="PopulateAmount">
                    		<xsl:with-param name="TargetNode" select="$Form8844Data/CreditsFromFlowthruEntities"/>
                  		</xsl:call-template>
                  	</div>        
                </div>
              </div>
            <!-- Part I, line 4 -->
             <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="padding-left:3mm;">4</div>
                <div class="styLNDesc">
                    Add lines 2 and 3. Partnerships and S corporations,  report this amount on Schedule K; all others, 
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
            <div style="width:187mm;">
            	<div style="float:left;">
              		<div class="styLNLeftNumBox"></div>
                	<div class="styLNDesc" style="width:28mm;">
					 continue on to line 5
				</div>
			</div>
			<div style="float:right;">
              		<div class="styDotLn" style="width:53mm;">
              			........................
              		</div>
                 	<div class="styLNRightNumBox">4</div>
                	<div class="styLNAmountBox">
                  		<xsl:call-template name="PopulateAmount">
                    		<xsl:with-param name="TargetNode" select="$Form8844Data/TotalCurrentYearEZRCECredit"/>
                  		</xsl:call-template>
                  	</div>        
                </div>
              </div>
            <!-- Part I, line 5 -->            
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">5</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Empowerment zone and renewal community employment credit included on line 4 from passive
                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBoxNBB">
                </div>
                <div class="styLNAmountBoxNBB" >
                </div>
              </div>
            </div>  
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;"></div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  activities (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ........................
                </div>
                <div class="styLNRightNumBox">
                  5
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/EZRCECreditFromPassiveActy"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 6 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">6</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Subtract line 5 from line 4
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  .........................
                </div>
                <div class="styLNRightNumBox">
                  6
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditWithoutPssvActyForPY"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 7 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">7</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Passive activity credit allowed for 2007 (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  .............
                </div>
                <div class="styLNRightNumBox">
                  7
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/PssvActivityCreditAllowedForPY"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 8 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">8</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Carryforward of empowerment zone and renewal community employment credit to 2007
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ....
                </div>
                <div class="styLNRightNumBox">
                  8
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CarryForwardOfEZECrToPY"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 9 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;padding-left:3mm;">9</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                  Carryback of empowerment zone and renewal community employment credit from 2008 (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBox">
                  9
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CarrybackEZECRAndRCECr"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>  
            <!-- Part I, line 10 -->
             <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox">10</div>
                <div class="styLNDesc">
                    Add lines 6 through 9. Cooperatives, estates, and trusts, continue on to line 11. All others, use this 
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
            <div style="width:187mm;">
            	<div style="float:left;">
              		<div class="styLNLeftNumBox"></div>
                	<div class="styLNDesc" style="width:36mm;">
					 amount to complete Part II
				</div>
			</div>
			<div style="float:right;">
              		<div class="styDotLn" style="width:103mm;height:2mm;">
              			.........................
              		</div>
                 	<div class="styLNRightNumBox">10</div>
                	<div class="styLNAmountBox">
                  		<xsl:call-template name="PopulateAmount">
                    		<xsl:with-param name="TargetNode" select="$Form8844Data/SumOfLinesSixThroughNine"/>
                  		</xsl:call-template>
                  	</div>        
                </div>
              </div>
          </div>  
          <!-- Part I, line 11 -->
           <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox">11</div>
                <div class="styLNDesc">
                    Amount allocated to the patrons of the cooperative or the beneficiaries of the estate or trust  
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
            <div style="width:187mm;">
            	<div style="float:left;">
              		<div class="styLNLeftNumBox"></div>
                	<div class="styLNDesc" style="width:26mm;">
					 (see instructions)
				</div>
			</div>
			<div style="float:right;">
              		<div class="styDotLn" style="width:113mm;">
              			..........................
              		</div>
                 	<div class="styLNRightNumBox">11</div>
                	<div class="styLNAmountBox">
                  		<xsl:call-template name="PopulateAmount">
                    		<xsl:with-param name="TargetNode" select="$Form8844Data/AmountAllocatedToBeneficiaries"/>
                  		</xsl:call-template>
                  	</div>        
                </div>
              </div>
    <!-- Part I, line 12 -->
            <div class="styBB" style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">12</div>
                <div style="height:4mm;" class="styForm8844LnDesc">
                <b>Cooperatives, estates, and trusts.</b> Subtract line 11 from line 10. Use this amount to complete Part II                                </div>
              </div>
              <div style="float:right;">
                <div class="styLNRightNumBoxNBB">
                  12
                </div>
                <div class="styLNAmountBoxNBB" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/EstatesTrustsCooperativeCr"/>
                  </xsl:call-template>        
                </div>
              </div>
            </div>

          <!-- End PartII Current Year Credit -->    
    
          <!-- Begin Allowable credit section-->
          <!-- Begin part II -->
          <div class="styBB" style="width:187mm;">
            <div class="styPartName">Part II</div>
            <div class="styPartDesc" style="padding-left:3mm;">
              Allowable Credit
            </div>
          </div>
          <!--Part II, Line 13 Begin -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox">13</div>
              <div style="float:left;padding-top:.5mm;">
                Regular tax before credits:                
              </div>
              <div style="float:right">  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <!-- Part II, line 13 -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Individuals. Enter the amount from Form 1040, line 44; Form 1040NR, line 41                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ..
                </span>
                <div class="styLNLeftNumBox" style="position:relative;width:25mm;">
                    <!-- bracket -->
                      <span style="position:absolute;top:0mm;left:-3mm;">
                        <img src="{$ImagePath}/8844_Bracket_Lger.gif" alt="bracket" border="0"/>
                      </span>
                    <!-- end bracket -->
                </div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Corporations. Enter the amount from Form 1120, Schedule J, line 2; or the              
              </div>
              <div style="float:right">  
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"></div>
              <div style="float:left;padding-top:.5mm;">
                applicable line of your return                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  .................
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;">
	                <span class="styDotLn">      
	                  ......
	                </span>
                </div>  
                <div class="styLNRightNumBox" style="height:4.5mm;">13</div>  
                <div class="styLNAmountBox" style="height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/RegularTaxBeforeCredits"/>
                  </xsl:call-template>
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G,             
              </div>
              <div style="float:right">  
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"></div>
              <div style="float:left">
                lines 1a and 1b, or the amount from the applicable line of your return                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ....
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>            
            <!-- Part II, line 14 -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox">14</div>
              <div style="float:left;padding-top:.5mm;">
                Alternative minimum tax:
              </div>
              <div style="float:right">
	              <div class="styLNLeftNumBox" style="position:relative;width:25mm;">
	                 <!-- bracket -->
	                   <span style="position:absolute;top:0mm;left:-3mm;">
	                     <img src="{$ImagePath}/8844_Bracket_Lg.gif" alt="bracket" border="0"/>
	                   </span>
	                 <!-- end bracket -->
	              </div>  
                <div class="styLNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <!-- First bullet point -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Individuals. Enter the amount from Form 6251, line 35                
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ..........
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;"></div>
                <div class="styLNRightNumBox" style="border-bottom-width:1px;height:4.5mm;">14</div>  
                <div class="styLNAmountBox" style="border-bottom-width:1px;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/AlternativeMinimumTax"/>
                  </xsl:call-template>
                </div>    
              </div>
            </div>
            <!-- Second bullet point -->    
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Corporations. Enter the amount from Form 4626, line 14            
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  .........
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;">
	                <span class="styDotLn" style="position:relative;top:-4mm;">      
	                  ......
	                </span>
                </div>  
                <div class="styLNRightNumBox" style="border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>    
            <!-- Third bullet point -->
            <div style="width:187mm">  
              <div class="styLNLeftNumBox" style="padding-left:4mm;"><img src="{$ImagePath}/8844_Bullet_Round.gif" alt="dot"/></div>
              <div style="float:left;padding-top:.5mm;">
                Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56             
              </div>
              <div style="float:right">  
                <span class="styDotLn">      
                  ....
                </span>
                <div class="styLNLeftNumBox" style="width:25mm;"></div>  
                <div class="styLNRightNumBox" style="border-bottom:0;height:4.5mm;"></div>  
                <div class="styLNAmountBox" style="border-bottom:0;height:4.5mm;">
                </div>    
              </div>
            </div>   
	          <!-- End Part II, line 14 -->
				  <!-- Part II, line 15 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">15</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 13 and 14    
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                  ...........................
                </div>
                <div class="styLNRightNumBox">
                  15
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SumOfRegularAndAltMinmumTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 16a Line 1 -->
            <div style="width:187mm;">
              <div style="float:left;clear:none;">
               <div class="styLNLeftNumBox" style="height:4mm;">16a</div>
                <div class="styForm8844LnDesc" style="height:4.5mm;">
                  Credits from Form 1040, lines 47 through 50 and lines 52 through 54 (or    
                </div>
              </div>
              <div style="float:right;clear:none;">
                <!--div class="styDotLn">..</div>-->
                <div class="styLNRightNumBoxNBB" style="border-left:0px;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB"  style="border-left:0px;padding-right:.5mm;height:4.5mm;">
                  <!--<xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/ForeignTaxCredit"/>
                  </xsl:call-template>-->
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
              <!-- Part II, line 16a Line 2 -->
            <div style="width:187mm;">
              <div style="float:left;clear:none;">
                <!--<div class="styLNLeftNumBox" style="height:4mm;">16a</div>-->
                <div class="styForm8844LnDesc" style="padding-left:8mm;height:4.5mm;width:74mm;">
                  Form 1040NR, lines 44, 45, and 47 through 49)
                </div>
                 <span class="styDotLn" style="width:32mm;">.......</span>
              </div>
              <div style="float:right;clear:none;">
               
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  16a
                </div>
                <div class="styLNAmountBox"  style="padding-right:.5mm;height:4.5mm;">
                  </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 16b -->
            <div style="width:187mm;">
              <div style="float:left;clear: none;">
                <div class="styLNLeftLtrBox" style="height:4.5mm;padding-left:4.2mm;">b</div>
                <div class="styForm8844LnDesc" style="height:4.5mm;">
                Foreign tax credit  
                </div>
              </div>
              <div style="float:right;clear:none;">
              	<div class="styDotLn">
                  ..................
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  16b
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/ForeignTaxCredit"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 16c -->
            <div style="width:187mm;">
              <div style="float:left;clear:none;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">c</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Credits from Forms 5735 and 8834
                </div>
              </div>
              <div style="float:right;clear:none;">
                <div class="styDotLn">.......
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  16c
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditsFrom5735And8834"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 16d -->
            <div style="width:187mm;">
              <div style="float:left;clear:none;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">d</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Alternative motor vehicle credit (Form 8910, line 18)
                </div>
              </div>
              <div style="float:right;clear:none;">
                <div class="styDotLn">......
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  16d
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/AlternativeMotorVehicleCr"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 16e -->
            <div style="width:187mm;">
              <div style="float:left;clear:none;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">e</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Alternative fuel vehicle refueling property credit (Form 8911, line 19)
                </div>
              </div>
              <div style="float:right;clear:none;">
                <div class="styDotLn">.
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  16e
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/AltFuelVehicleRefuelingPropCr"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>   
            <!-- Part II, line 16f -->       
            <div style="width:187mm;">
              <div style="float:left;clear:none;">
                <div class="styLNLeftLtrBox" style="height:4mm;padding-left:4.2mm;">f</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Add lines 16a through 16e
                </div>
              </div>
              <div style="float:right;clear:none;">
                <div class="styDotLn">.........................
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  16f
                </div>
                <div class="styLNAmountBox" style="height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TotalCredits"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 17 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">17</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Net income tax. Subtract line 16f from line 15. If zero, skip lines 18 through 24 and enter -0- on line 25                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  17
                </div>
                <div class="styLNAmountBox" style="height:4.5mm;" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/NetIncomeTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>   
            <!-- Part II, line 18 -->       
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">18</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Net regular tax. Subtract line 16f from line 13. If zero or less, enter -0-
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  18
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/NetRegularTax"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 19 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">19</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Tentative minimum tax (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">..........
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  19
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TentativeMinimumTax"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 20 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">20</div>
                <div class="styForm8844LnDesc" style="height:4mm;font-size:6pt;">
                  Enter 25% (.25) of the excess, if any, of line 18 over $25,000 (see instructions)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">.
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  20
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/TwentyFivePercentOfExcess"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 21 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">21</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Multiply line 19 by 75% (.75)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">..............
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  21
                </div>
                <div class="styLNAmountBox" style="padding-right:.5mm;height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SeventyFivePercentOfTentMinTax"/>
                  </xsl:call-template>
                </div>
                <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:4.5mm;">
                </div>
                <div class="styLNAmountBoxNBB" style="height:4.5mm;">
                </div>
              </div>
            </div>
            <!-- Part II, line 22 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">22</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Enter the greater of line 20 or line 21
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">.....................
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  22
                </div>
                <div class="styLNAmountBox" style="height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/GreaterOfTentMinTaxOrExcess"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 23 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">23</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Subtract line 22 from line 17. If zero or less, enter -0-
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">................
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  23
                </div>
                <div class="styLNAmountBox" style="height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SubtractGreaterFromNetIncTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 24 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">24</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  General business credit (Form 3800, line 19)
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">
                ...................
                </div>
                <div class="styLNRightNumBox" style="height:4.5mm;">
                  24
                </div>
                <div class="styLNAmountBox" style="height:4.5mm;">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/GeneralBusinessCredit"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>    
            <!-- Part II, line 25 -->  
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox" style="height:4mm;">25</div>
                <div class="styForm8844LnDesc" style="height:4mm;">
                  Subtract line 24 from line 23
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">........................
                </div>
                <div class="styLNRightNumBox">
                  25
                </div>
                <div class="styLNAmountBox" >
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/SubtractGenBusCreditFromTax"/>
                  </xsl:call-template>
                </div>
              </div>
            </div>
            <!-- Part II, line 26 -->
            <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox">26</div>
                <div class="styLNDesc">
                  <span class="styBoldText">Credit allowed for the current year. Cooperatives, estates, and trusts.</span> 
                  Enter the <b>smaller</b> of line 12 or 
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:2.5mm;"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
             <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox"></div>
                <div class="styLNDesc">
                    line 25. Report this amount on Form 1041, Schedule G, line 2c; 
                  	or Form 1120-C, Schedule J, line 5c.   
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:2.5mm;"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
		  <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox"></div>
                <div class="styLNDesc">
                    If line 25 is smaller than line 12, see instructions. <b>All others.</b> 
                  Enter the <b>smaller</b> of line 10 or line 25. 
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:2.5mm;"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
		   <div style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox"></div>
                <div class="styLNDesc">
                    Report this amount on Form 1040, line 55; Form 1040NR, 
                  line 50; Form 1120, Schedule J, line 5c;
                </div>
              </div>
              <div style="float:right;">
              <div class="styLNRightNumBoxNBB" style="background-color:lightgrey;height:2.5mm;"></div>
              <div class="styLNAmountBoxNBB"></div>
              </div>
            </div>
              <div  class="styBB"  style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox"></div>
                <div class="styLNDesc" style="width:114mm;">
                  or the applicable line of your return. If line 25 is smaller than line 12, see instructions
                </div>
              </div>
              <div style="float:right;">
                <div class="styDotLn">......
                </div>
              <div class="styLNRightNumBoxNBB" style="height:2.5mm;">26</div>
              <div class="styLNAmountBoxNBB">
              	<xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditAllowedForCY"/>
                  </xsl:call-template>
              </div>
              </div>
            </div>
              <!-- <div class="styBB" style="width:187mm;">
              <div style="float:left;">
                <div class="styLNLeftNumBox"></div>
                <div class="styLNDesc" style="width:22mm;">
                  see instructions
                </div>
              </div>
              <div  style="float:right;">
                <div class="styDotLn">............................
                </div>
                <div class="styLNRightNumBoxNBB">26</div>
                <div class="styLNAmountBoxNBB">
                  <xsl:call-template name="PopulateAmount">
                    <xsl:with-param name="TargetNode" select="$Form8844Data/CreditAllowedForCY"/>
                  </xsl:call-template>
                </div>
              </div>
            </div> -->
        <!--Page End-->
          <div style="width:186mm;clear:both;padding-top:1mm;">
            <div style="width:90mm;font-weight:bold;" class="styGenericDiv">For Paperwork Reduction Act Notice, see instructions.</div>
            <div style="width:55mm;text-align:center;" class="styGenericDiv">Cat. No. 16145S</div>
            <div style = "float:right;" class="styGenericDiv">Form <span class="styBoldText">8844</span> (2007)</div>
          </div>    
          <p class="pageend"></p>        
          <!-- BEGIN Left Over Table -->  
          <!-- Additonal Data Title Bar and Button -->
          <div class="styLeftOverTitleLine" id="LeftoverData">
            <div class="styLeftOverTitle">
              Additional Data        
            </div>
            <div class="styLeftOverButtonContainer">
              <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
            </div>      
          </div>
          <!-- Additional Data Table -->
          <table class="styLeftOverTbl">
            <xsl:call-template name="PopulateCommonLeftover">
              <xsl:with-param name="TargetNode" select="$Form8844Data" />
              <xsl:with-param name="DescWidth" select="100"/>
            </xsl:call-template>          
          </table>
          <!-- END Left Over Table -->  
        </form>
      </body>
    </html>
  </xsl:template>
</xsl:stylesheet>
