<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:include href="PopulateTemplate.xsl"/>
	<xsl:include href="AddHeader.xsl"/>
	<xsl:include href="CommonPathRef.xsl"/>
	<xsl:include href="AddOnTable.xsl"/>
	<xsl:include href="IRS8846Style.xsl"/>
	<xsl:output method="html" indent="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:param name="Form8846Data" select="$RtnDoc/IRS8846"/>
	<xsl:template match="/">
		<html lang="EN-US">
			<head>
				<title>
					<xsl:call-template name="FormTitle">
						<xsl:with-param name="RootElement" select="local-name($Form8846Data)"/>
					</xsl:call-template>
				</title>
				<!-- This is a comment line to be taken out later -->
				<!-- No Browser Caching -->
				<meta http-equiv="Pragma" content="no-cache"/>
				<meta http-equiv="Cache-Control" content="no-cache"/>
				<meta http-equiv="Expires" content="0"/>
				<!-- No Proxy Caching -->
				<meta http-equiv="Cache-Control" content="private"/>
				<!-- Define Character Set -->
				<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
				<meta name="Description" content="IRS Form 8846"/>
				<script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"/>
				<xsl:call-template name="InitJS"/>
				<style type="text/css">
					<xsl:if test="not($Print) or $Print=''">
						<!-- Form 8846 CSS Styles are located in the template called below -->
						<xsl:call-template name="IRS8846Style"/>
						<xsl:call-template name="AddOnStyle"/>
					</xsl:if>
				</style>
				<xsl:call-template name="GlobalStylesForm"/>
			</head>
			<body class="styBodyClass">
				<form name="Form8846" id="Form8846">
					<xsl:call-template name="DocumentHeader"/>
					<!-- Begin Form Number and Name -->
					<div class="styBB" style="width:187mm;">
						<div class="styFNBox" style="width:31mm;height:21mm;">
          Form <span class="styFormNumber">8846</span>
							<br/>
							<br/>
							<div style="padding-top:2mm;">
								<span class="styAgency">Department of the Treasury</span>
								<br/>
								<span class="styAgency">Internal Revenue Service</span>
							</div>
						</div>
						<div class="styFTBox" style="width:125mm;height:13mm;">
							<div class="styMainTitle">
          	Credit for Employer Social Security and Medicare Taxes<br/>
          	Paid on Certain Employee Tips      
              </div>
							<br/>
							<div class="styFST" style="height:5mm;font-size:7pt;padding-top:4mm;">
								<img src="{$ImagePath}/8846_Bullet_Md.gif" width="4" height="7" alt="Bullet Image"/>
          Attach to your tax return.
        </div>
						</div>
						<!-- This can be taken out later -->
						<div class="styTYBox" style="width:30mm;height:21mm;">
							<div class="styOMB" style="height:2mm;">OMB No. 1545-1414</div>
							<div class="styTY" style="height:7.5mm;font-size:24pt;">
         		 20<span class="styTYColor">07</span>
							</div>
							<div class="stySequence">Attachment<br/>Sequence No. <b>98</b>
							</div>
						</div>
					</div>
					<!-- End Form Number and Name section -->
					<!-- Begin Names and Identifying number section -->
					<div class="styBB" style="width:187mm;">
						<div class="styNameBox" style="width:156mm;height:8mm;font-weight:normal;font-size:7pt;">
        Name(s) shown on return<br/>
							<xsl:call-template name="PopulateReturnHeaderFiler">
								<xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param>
							</xsl:call-template>
							<br/>
							<xsl:call-template name="PopulateReturnHeaderFiler">
								<xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param>
							</xsl:call-template>
						</div>
						<div class="styEINBox" style="width:30mm;height:4mm; padding-left:2mm;font-size:7pt;">
              Identifying number<br/>
							<br/>
							<span style="font-weight:normal;">
								<xsl:call-template name="PopulateReturnHeaderFiler">
									<xsl:with-param name="TargetNode">EIN</xsl:with-param>
								</xsl:call-template>
							</span>
						</div>
					</div>
					<div class="styBB" style="width:187mm;padding-top:1mm;padding-bottom:1mm;">
						<b>Note.</b>
						<i> Claim this credit <b>only</b> for social security and Medicare taxes paid by a food or beverage establishment where tipping is customary for providing food or beverages. See the instructions for line 1.</i>
					</div>
					<div style="width:187mm" class="styBB">
						<div class="styGenericDiv" style="width:187mm;float:left;">
							<div class="styPartName">Part I</div>
							<div class="styPartDesc" style="width:167mm;">Current Year Credit</div>
						</div>
					</div>
					<!-- End Names and Identifying number section -->
					<!-- Line 1 -->
					<div class="styBB" style="width:187mm;">
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;padding-top:1mm;">1</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-top:1mm;">
          	Tips received by employees for services on which you paid or incurred employer social security and Medicare taxes during the tax year (see instructions)          <!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
              </div>
               1
               </div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/TipsRcvdByEmployeesForServices"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 2 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;padding-top:3.5mm;">2</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;padding-top:4mm;">
         		 Tips not subject to the credit provisions (see instructions)
         		<!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.............</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
              </div>
               2
               </div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/TipsNotSubjectToTheCreditPrvsn"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 3 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;padding-top:3.5mm;">3</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;padding-top:4mm;">
          	Creditable tips. Subtract line 2 from line 1
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
              </div>  
              3
              </div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/CreditableTips"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 4 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;">4</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
								<label>
									<xsl:call-template name="PopulateLabel">
										<xsl:with-param name="TargetNode" select="$Form8846Data/EmpWagesExceededMaxAmt"/>
										<xsl:with-param name="BackupName">IRS8846EmpWagesExceededMaxAmt</xsl:with-param>
									</xsl:call-template>
                   			Multiply line 3 by 7.65% (.0765). If you had any tipped employees whose wages (including tips) exceeded $97,500, see instructions and check here  
		              <xsl:call-template name="SetFormLinkInline">
										<xsl:with-param name="TargetNode" select="$Form8846Data/EmpWagesExceededMaxAmt"/>
									</xsl:call-template>
								</label>
								<!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.............</span>
								<img src="{$ImagePath}/8846_Bullet_Md.gif" width="4" height="7" alt="Bullet Image"/>
								<span style="width:1mm;"/>
								<input type="checkbox" class="styCkbox">
									<xsl:call-template name="PopulateCheckbox">
										<xsl:with-param name="TargetNode" select="$Form8846Data/EmpWagesExceededMaxAmt"/>
										<xsl:with-param name="BackupName">IRS8846EmpWagesExceededMaxAmt</xsl:with-param>
									</xsl:call-template>
								</input>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
              </div>
                4
                </div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/CurrentYearCredit"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 5 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;">5</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
         		Credit for employer social security and Medicare taxes paid on certain employee tips from
			partnerships and S corporations.
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..........................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
        			</div>
				5
	  		</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/CrdtsForEmplrSSAndMedicareTxs"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 6 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;">6</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
        Add lines 4 and 5. Partnerships and S corporations, report this amount on Schedule K; all others, go to line 7
		<!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..............................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
          </div>
        		6
        </div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/AddLines4And5"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 7 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;">7</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
         		Credit for employer social security and Medicare taxes paid on certain employee tips included
			on line 6 from passive activities (see instructions)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
        			</div>
				7
	  		</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/EmployerCrForEmployeeTipsIncld"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 8 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:4mm;">8</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Subtract line 7 from line 6 &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.......................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;">
				8
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/SubtractLine7From6"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 9 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBoxSD" style="height:8mm;">9</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
         		Credit for employer social security and Medicare taxes paid on certain employee tips allowed
			for 2007 from passive activities (see instructions)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
        			</div>
				9
	  		</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/EmployerCrForEmployeeTipsAllw"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 10 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:8mm;">10</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
         		Carryback of the credit for employer social security and Medicare taxes paid on certain employee
			tips from 2008 (see instructions)
				<xsl:call-template name="LinkToLeftoverDataTableInline">          
             				 <xsl:with-param name="Desc">Form 8846, Line 10 - Credit Indicator</xsl:with-param>    
              			<xsl:with-param name="TargetNode" select="$Form8846Data/CarrybackCredit/@creditIndicator"/>    
            			</xsl:call-template>    
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.4mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">......................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
        			</div>
				10
	  		</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
								<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/CarrybackCredit"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 11 -->
						<div style="width:187mm" class="styBB">
							<div class="styLNLeftNumBox" style="height:4.5mm;">11</div>
							<div class="styLNDesc" style="width:139mm;height:4.5mm;padding-right:1mm;">
         		Add lines 8 through 10. Use this amount to complete Part II &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.............</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.5mm;padding-top:.5mm;border-bottom:0px">
				11
	  		</div>
							<div class="styLNAmountBox" style="height:4.5mm;padding-top: .5mm;border-bottom:0px">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/AddLines8Through10"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Part II  Allowable Credit-->
						<div style="width:187mm" class="styBB">
							<div class="styGenericDiv" style="width:187mm;float:left;">
								<div class="styPartName">Part II</div>
								<div class="styPartDesc" style="width:167mm;">Allowable Credit</div>
							</div>
						</div>
						<!-- Line 12 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">12</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Regular tax before credits (see instructions)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				12
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/RegularTax"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 13 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">13</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Alternative minimum tax (see instructions) &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				13
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/AlternativeMinimumTax"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 14 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">14</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Add lines 12 and 13 &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..........................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				14
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/SumLines12And13"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 15 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:8mm">15a</div>
							<div class="styLNDesc" style="width:99mm">
         						Credits from Form 1040, lines 47 through 50 and 52 through 54 (or
							Form 1040NR, lines 44, 45, and 47 through 49)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">..........</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:4mm;">15a</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:4mm;">
								<!-- Commented out - 1040 data not available
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/xxxx"/>
								</xsl:call-template>
					-->
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:8mm;border-right:0px"/>
							<div class="styShadingCell" style="height:8mm;background-color:white;"/>
						</div>
						<!-- 15b-->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm">b</div>
							<div class="styLNDesc" style="width:99mm">
				         		Foreign tax credit 
         		        		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">..................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.5mm;padding-top:0mm;">15b</div>
							<div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/ForeignTaxCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0px"/>
							<div class="styShadingCell" style="height:4.5mm;background-color:white;"/>
						</div>
						<!-- 15c-->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm">c</div>
							<div class="styLNDesc" style="width:99mm">
				         		Credits from Forms 5735 and 8834
    		     		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">............</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.5mm;padding-top:0mm;">15c</div>
							<div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/CrFromF5735And8834"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0px"/>
							<div class="styShadingCell" style="height:4.5mm;background-color:white;"/>
						</div>
						<!-- 15d-->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm">d</div>
							<div class="styLNDesc" style="width:99mm">
         		Non-business alternative motor vehicle credit (Form 8910, line 18)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">.</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.5mm;padding-top:0mm;">15d</div>
							<div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/NonBusinessMotorVehicleCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0px"/>
							<div class="styShadingCell" style="height:4.5mm;background-color:white;"/>
						</div>
						<!-- 15e-->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="padding-left:4.5mm">e</div>
							<div class="styLNDesc" style="width:99mm">
         						Non-business alternative fuel vehicle refueling property credit (Form
							8911, line 19)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">...................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="height:3.75mm;width:7.75mm;border-left-width:0px;background-color:lightgrey;padding-bottom:0px">
        			</div>
							15e</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:4mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/NonBusinessRefuelingPropertyCr"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:8mm;border-right:0px"/>
							<div class="styShadingCell" style="height:8mm;background-color:white;"/>
						</div>
						<!-- Line 15 f-->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="padding-left:4.5mm;">f</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
		         		Add lines 15a through 15e
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.........................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				15f
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/SumLines15aThrough15e"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 16 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:8mm;">16</div>
							<div class="styLNDesc" style="width:139mm;height:8mm;padding-right:1mm;">
        Net income tax. Subtract line 15f from line 14. If zero, skip lines 17 through 20 and enter -0-
on line 21

		<!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">................................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
          </div>
        		16
        </div>
<div class="styLNAmountBox" style="height:8mm;padding-top:1mm;">
							<br/>
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/NetIncomeTax"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 17 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">17</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Net regular tax. Subtract line 15f from line 12. If zero or less, enter -0- &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..........</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				17
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/NetRegularTax"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 18 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">18</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Enter 25% (.25) of the excess, if any, of line 17 over $25,000 (see instructions) &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">......</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				18
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/ExcessAmount"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 19 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">19</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Subtract line 18 from line 16. If zero or less, enter -0- &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				19
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/SubtractLine18FromLine16"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 20 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4.5mm;">20a</div>
							<div class="styLNDesc" style="width:99mm">
         		General business credit (Form 3800, line 19)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">.........</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.5mm;padding-top:0mm;">20a</div>
							<div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/GeneralBusinessCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0px"/>
							<div class="styShadingCell" style="height:4.5mm;background-color:white;"/>
						</div>
						<!-- 20b -->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="padding-left:4.5mm">b</div>
							<div class="styLNDesc" style="width:99mm">
         						Empowerment zone and renewal community employment credit (Form 8844, line 26)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">...................</span>
							</div>
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;">
								<div class="styLNRightNumBoxNBB" style="height:3.75mm;width:7.75mm;border-left-width:0px;background-color:lightgrey;padding-bottom:0px">
        			</div>
							20b</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:4mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/EmpowermentZoneCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:8mm;border-right:0px"/>
							<div class="styShadingCell" style="height:8mm;background-color:white;"/>
						</div>
						<!-- 20c -->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="height:4.5mm;padding-left:4.5mm">c</div>
							<div class="styLNDesc" style="width:99mm">
				         		Work opportunity credit (Form 5884, line 22)
    		     		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">.........</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.5mm;padding-top:0mm;">20c</div>
							<div class="styLNAmountBox" style="height:4.5mm;padding-top:0mm;">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/WorkOpportunityCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:4.5mm;border-right:0px"/>
							<div class="styShadingCell" style="height:4.5mm;background-color:white;"/>
						</div>
						<!-- 20d -->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="height:4mm;padding-left:4.5mm">d</div>
							<div class="styLNDesc" style="width:99mm">
         		Alcohol fuels credit (Form 6478, line 24)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">..........</span>
							</div>
							<div class="styLNRightNumBox" style="height:4.25mm;padding-top:0mm;padding-bottom:0mm">20d</div>
							<div class="styLNAmountBox" style="height:4.25mm;padding-top:0mm;padding-bottom:0mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/AlcoholFuelsCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:4.25mm;border-right:0px;padding-bottom:0mm"/>
							<div class="styShadingCell" style="height:4.25mm;background-color:white;padding-bottom:0mm"/>
						</div>
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="padding-left:4.5mm;">e</div>
							<div class="styLNDesc" style="width:99mm">
         						Renewable electricity, refined coal, and Indian coal production credit (Form 8835, line 43)
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;">...................</span>
							</div>
							<!-- 20e -->
							<div class="styLNRightNumBox" style="height:8mm;padding-top:0mm;padding-bottom:0mm">
								<div class="styLNRightNumBoxNBB" style="height:3.75mm;width:7.75mm;border-left-width:0px;background-color:lightgrey;padding-bottom:0px">
        						</div>
							20e</div>
							<div class="styLNAmountBox" style="height:8mm;padding-top:4mm;padding-bottom:0mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/RenewableEnergyCredit"/>
								</xsl:call-template>
							</div>
							<div class="styShadingCellRB" style="width:8mm;height:8mm;border-right:0px"/>
							<div class="styShadingCell" style="height:8mm;background-color:white;"/>
						</div>
						<!-- Line 20f -->
						<div style="width:187mm;">
							<div class="styLNLeftLtrBoxDD" style="height:4mm;padding-left:4.5mm">f</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Add lines 20a through 20e
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">.........................</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				20f
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/SumLines20aThrough20e"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 21 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">21</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
         		Subtract line 20f from line 19. If zero or less, enter -0- &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">...............</span>
							</div>
							<div class="styLNRightNumBox" style="height:4mm;padding-top:.25mm;">
				21
	  		</div>
							<div class="styLNAmountBox" style="height:4mm;padding-top: .25mm">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/SubtractLine20fFromLine19"/>
								</xsl:call-template>
							</div>
						</div>
						<!-- Line 22 -->
						<div style="width:187mm;">
							<div class="styLNLeftNumBox" style="height:4mm;">22</div>
							<div class="styLNDesc" style="width:139mm;height:4mm;padding-right:1mm;">
								<span style="font-weight: bold">Credit allowed for the current year.</span> Enter the smaller of line 11 or 21. Report this amount
on Form 1040, line 55; Form 1040NR, line 50; Form 1120, Schedule J, line 5c; or the
applicable line of your return. If line 21 is smaller than line 11, see instructions &#160;
         		 <!--Dotted Line-->
								<span style="letter-spacing:3.3mm;font-weight:bold;padding-right:1mm;skiplink:display:none;">..............</span>
							</div>
							<div class="styLNRightNumBox" style="height:10.5mm;padding-top:0mm;padding-bottom:0mm;border-bottom:0px">
								<div class="styLNRightNumBoxNBB" style="height:6mm;padding-bottom:0mm;width:7.75mm;border-left-width:0px;background-color:lightgrey;">
          </div>
			22
	  		</div>
							<div class="styLNAmountBox" style="height:10.5mm;padding-top: 7mm;border-bottom:0px">
								<xsl:call-template name="PopulateAmount">
									<xsl:with-param name="TargetNode" select="$Form8846Data/CreditForCurrentYear"/>
								</xsl:call-template>
							</div>
						</div>
					</div>
					<!-- Page End -->
					<div style="width:187mm;">
						<span class="styBoldText">For Paperwork Reduction Act Notice, see back of form.</span>
						<span style="width:128px;"/>  
        Cat. No. 16148Z
        <span style="width:115px;"/>  
        Form <span class="styBoldText">8846</span> (2007)
      </div>
					<br class="pageEnd"/>
					<!-- BEGIN Left Over Table -->
					<!-- Additonal Data Title Bar and Button -->
					<div class="styLeftOverTitleLine" id="LeftoverData">
						<div class="styLeftOverTitle">
              Additional Data        
            </div>
						<div class="styLeftOverButtonContainer">
							<input class="styLeftoverTableBtn" TabIndex="1" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
						</div>
					</div>
					<!-- Additional Data Table -->
					<table class="styLeftOverTbl">
						<xsl:call-template name="PopulateCommonLeftover">
							<xsl:with-param name="TargetNode" select="$Form8846Data"/>
							<xsl:with-param name="DescWidth" select="100"/>
						</xsl:call-template>
						 <xsl:call-template name="PopulateLeftoverRow">          
        						<xsl:with-param name="Desc">Form 8846, Line 10 - Credit Indicator</xsl:with-param>    
        						<xsl:with-param name="TargetNode" select="$Form8846Data/CarrybackCredit/@creditIndicator"/>            
        						<xsl:with-param name="DescWidth" select="100"/>                          
     						 </xsl:call-template>   
					</table>
					<!-- END Left Over Table -->
				</form>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
