<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS8912Style.xsl"/>

<xsl:output method="html" indent="yes" />
<xsl:strip-space elements="*" />

<xsl:param name="Form8912Data" select="$RtnDoc/IRS8912" />

<xsl:template match="/">

<html lang="EN-US">
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form8912Data)"></xsl:with-param></xsl:call-template></title>
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Cache-Control" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private" />
    <!-- Define Character Set -->
    <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
    
    <meta name="Description" content="IRS Form 8912" />
    <META name="GENERATOR" content="IBM WebSphere Studio"/>
     <xsl:call-template name="GlobalStylesForm"/>
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>  
    <style type="text/css">
      <xsl:if test="not($Print) or $Print=''">
                     <xsl:call-template name="IRS8912Style"></xsl:call-template>    
                     <xsl:call-template name="AddOnStyle"></xsl:call-template>    
     </xsl:if>

    </style>
    <xsl:call-template name="GlobalStylesForm"/>
  </head>

<body class="styBodyClass">
  <form name="Form8912">
    <xsl:call-template name="DocumentHeader"></xsl:call-template>      
    
    <!-- Begin Form Number and Name -->
    <div class="styBB" style="width:187mm;">
    <div class="styFNBox" style="width:31mm;height:20mm;border-right:none;">
      <span style="height:7mm;">
        Form <span class="styFormNumber">8912</span>
      </span>
       <span class="styAgency">      <br/>
        <br/><br/>
        Department of the Treasury
        <br />
        Internal Revenue Service
      </span>
    </div>
    <div class="styFTBox" style="width:123mm;border-right:1px solid black;border-left:1px solid black;height:20mm;">
      <div style="height:13.5mm;" class="styMainTitle">
        Credit for Clean Renewable Energy<br/>and Gulf Tax Credit Bonds
      </div>      
      <div class="styFST" style="height:5mm;font-size:7pt;">
        <img src="{$ImagePath}/8912_Bullet.gif" alt="Bullet Image"/>
        Attach to your tax return.
       
      </div>
    </div>
    <div class="styTYBox" style="width:32mm;border-left:none;">
        <div class="styOMB" style="height:2mm;">OMB No. 1545-2025</div>
        <div class="styTaxYear">
          20<span class="styTYColor">07</span>
        </div>
        <div  style="margin-left:3mm; text-align:left;">
          Attachment<br/>Sequence No. <span class="styBoldText">154</span>
        </div>
      </div>
  </div>    
  <!-- End Form Number and Name section -->
  
  <!-- Begin Name and Identifying number section -->
    <div class="styBB" style="width:187mm;">
          <div class="styNameBox" style="width:140mm;height:8mm;font-size:7pt;">
            Name(s) shown on return<br/>
           <div style="font-family:verdana;font-size:7pt;height:6.25mm;">
             <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>  
             <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template> 
           </div>
          </div>
          <div class="styEINBox" style="width:46mm;height:4mm;padding-left:2mm;font-size:7pt;">
            Identifying number<br/><br/>
            <span style="font-weight:normal;">  
              <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>
            </span>              
          </div>
        </div>

  
  <!-- End Names and Identifying number section -->

  <!-- BEGIN Part I Title -->
  <div style="width:187mm;" class="styBB">
    <div class="styGenericDiv" style="width:150mm;float:left;">
      <div class="styPartName">Part I</div>
      <div class="styPartDesc" style="width:50mm;padding-bottom:0;"></div><br/>
      <div style="font-size:8pt;font-weight:bold;">Section A. Clean Renewable Energy Bond Credit</div>
    </div>
    <!-- Table expand/collapse toggle button -->
    <div class="styGenericDiv" style="float:right;height:1mm;">
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/Item"/>
          <xsl:with-param name="containerHeight" select="5"/>
          <xsl:with-param name="headerHeight" select="1"/>
          <xsl:with-param name="containerID" select=" 'CREBCctn' "/>
          </xsl:call-template>
     </div>

  </div>
  <!-- END Part I Title -->
      
  <div  id="CREBCctn" class="styTableContainerNBB">
    <xsl:call-template name="SetInitialState"/>
    <table style="font-size:7pt;border-color:black;" class="styTable" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" name="CREBCtable" id="CREBCtable" >
      <thead class="styTableThead">
        <tr>
    
          <th scope="col" class="styTableCell" style="width:39mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;" colspan="2">(a)</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(e)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(f)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(g)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(h)</th>        
        </tr>
        <tr>
          
          <th scope="col" class="styTableCell" style="width:39mm;font-size:7pt;text-align:center;font-weight:normal;" colspan="2">Bond issuer's name, city <br />or town, and state</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:6pt;text-align:center;font-weight:normal;">Date<br /> bond issued</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:6pt;text-align:center;font-weight:normal;">Date bond <br />disposed of<br/>(if applicable)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;font-weight:normal;">Outstanding<br/>bond principal</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;">Credit<br/>rate</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;font-weight:normal;"><br/>(d) x (e)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;"><br/>%</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-right:none;font-weight:normal;">Credit<br/>(f) x (g)</th>
        </tr>
      </thead>
    <tfoot></tfoot>
    <tbody>
    <xsl:for-each select="$Form8912Data/CleanRenewableEnergyBondCredit/Item">
    	<xsl:if test="($Print != $Separated) or (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &lt;=5)">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:6pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:value-of select="position()"/>
              </xsl:when>
              <xsl:otherwise>
                <span style="width:1px;"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>    
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:6pt;font-weight:normal;font-family:verdana">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine1"/>
            </xsl:call-template>
            <br/>
             <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine2"/>
            </xsl:call-template>
         
            <xsl:if test="City !=''">
            <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="City"/>
              </xsl:call-template>,
            </xsl:if>
            <xsl:if test="State !=''">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="State"/>
              </xsl:call-template>
              <span style="width:1mm;"/>
            </xsl:if>
          </td>
          
          <td class="styTableCell" style="width:15mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondIssued"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:15mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondDisposedOf"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="OutstandingBondPrinciple"/>
            </xsl:call-template>          
          </td>  
           <td class="styTableCell" style="width:20mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="CreditRate"/>
            </xsl:call-template>          
          </td> 
           <td class="styTableCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditdxe"/>
            </xsl:call-template>          
          </td> 
                     <td class="styTableCell" style="width:20mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="Percent"/>
            </xsl:call-template>          
          </td> 
          <td class="styTableCell" style="width:26mm;text-align:right;border-right:none;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditfxg"/>
            </xsl:call-template>
          </td>
        </tr>
       </xsl:if>
      </xsl:for-each>
          
      <xsl:if test="count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &lt; 1 or (($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;vertical-align:top;">1</td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;font-family:verdana;vertical-align:top;">
          <xsl:choose>											
			<xsl:when test="($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5)">
				<xsl:call-template name="PopulateAdditionalDataTableMessage">
					<xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/Item"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span class="styTableCellPad"></span>
			</xsl:otherwise>
          </xsl:choose>
          </td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>          
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>          
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>      
      <xsl:if test="count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &lt; 2 or (($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &lt; 3 or (($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &lt; 4 or (($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
           <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
           <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
            <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &lt; 5 or (($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
    	     <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>                            
      </tbody>
    </table>       
      <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/Item"/>
      <xsl:with-param name="containerHeight" select="5"/>
      <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'CREBCctn' "/>
      </xsl:call-template>  
  </div>

<!-- Part I Line 2 -->
  <div class="styGenericDiv" style="width:187mm;">
    <div class="styLNLeftNumBox" style="height:4mm;"><span style="width:5px;"/>2</div>
    <div class="styLNDesc" style="width:139.60mm;height:4mm;float:left;">
<b>Total credit.</b> Add the amounts on line 1, column (h). See the instructions for how to report as interest
income            <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/TotalCredit"/>
      </xsl:call-template>    
      <span style="letter-spacing:3.5mm;font-weight:bold;">..............................</span>
    </div>
    <div class="styLNRightNumBox" style="width:7mm;height:8mm;padding-bottom:none;"><br/>2</div>    
    <div class="styLNAmountBox" style="height:8.0mm;padding-bottom:none;width:32mm;font-size:7pt;">
	<br/>
	      <xsl:call-template name="PopulateAmount">
	        <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/TotalCredit"/>
	      </xsl:call-template>    

    </div>
          
  </div>
  
<!-- Part I, Line 3 -->
    <div class="styGenericDiv" style="width:187mm; clear: left;">
        <div class="styLNLeftNumBox" style="height:4.5mm;"><span style="width:5px;"/>3</div>
        <div class="styLNDesc" style="width:139.60mm;height:4.5mm;">
         Clean renewable energy bond credits from partnerships, S corporations, estates, and trusts        <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ....</span>
        </div>


    <div class="styLNRightNumBox" style="width:7mm;height:4.5mm;padding-bottom:none;">3</div>    
    <div class="styLNAmountBox" style="height:4.5mm;padding-bottom:none;width:32mm;font-size:7pt;">
	
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/BondCredit"/>
          </xsl:call-template>

        </div>
      
      </div>
      
<!-- Part I, Line 4 -->
    <div class="styGenericDiv" style="width:187mm; clear: left;">
        <div class="styLNLeftNumBox" style="height:4mm;"><span style="width:5px;"/>4</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
Add line 2 and line 3. Estates and trusts go to line 5; partnerships and S corporations, report this amount
on Schedule K; all others, go to Part II           <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ....................</span>
        </div>


        <div class="styLNRightNumBox" style="width:6.50mm;height:8mm;padding-top:0mm;">
          <div class="" style="width:6.50mm;border-left-width:0px;background-color:lightgrey;height:4mm;"></div>          
          4
        </div>
        <div class="styLNAmountBox" style="height:8mm;width:32mm;font-size:7pt;border-top:1px;">
	<br/>
		 <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/CurrentYearBondCredits"/>
          </xsl:call-template>

        </div>

      </div>
      
      
      
<!-- Part I, Line 5 -->
    <div class="styGenericDiv" style="width:187mm; clear: left;">
        <div class="styLNLeftNumBox" style="height:4mm;"><span style="width:5px;"/>5</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
         Amount allocated to the beneficiaries of the estate or trust (see instructions)          
         <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ........</span>
        </div>


    <div class="styLNRightNumBox" style="width:7mm;height:4mm;padding-bottom:none;">5</div>    
    <div class="styLNAmountBox" style="height:4.0mm;padding-bottom:none;width:32mm;font-size:7pt;">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/AmtAllocatedBeneficiariesEstTr"/>
          </xsl:call-template>

        </div>
      
      </div>
 <!-- Part I, Line 6 -->
    <div class="styBB" style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;"><span style="width:5px;"/>6</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
<b>Estates and trusts.</b> Subtract line 5 from line 4. Use this amount to complete Part II          
         <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ......</span>
        </div>


    <div class="styLNRightNumBoxNBB" style="width:7mm;height:4mm;padding-bottom:none;">6</div>    
    <div class="styLNAmountBoxNBB" style="height:4.0mm;padding-bottom:none;width:32mm;font-size:7pt;">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/SubtractLines"/>
          </xsl:call-template>

        </div>
      
      </div>     
      
      
      
      
      
      
      
      
      
<!-- End Part I -->

   <!-- BEGIN Section B Title -->
  <div style="width:187mm" class="styBB">
    <div class="styGenericDiv" style="width:150mm;float:left;">
      <div align="left" style="height:6mm;width:100mm;padding-left:none;padding-top:1mm;padding-bottom:1mm;margin-left:none;font-size:8pt;font-weight:bold;">Section B. Gulf Tax Credit Bond Credit</div>
   </div>
    <!-- Table expand/collapse toggle button -->
      <div class="styGenericDiv" style="height:4.50mm;float:right;">
      <!--div style="width:5mm;float:right;vertical-align:top;"-->
          <xsl:call-template name="SetDynamicTableToggleButton">
          <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/Item"/>
          <xsl:with-param name="containerHeight" select="5"/>
          <xsl:with-param name="headerHeight" select="1"/>
          <xsl:with-param name="containerID" select=" 'GBCctn' "/>
          </xsl:call-template>
      </div>
    </div>
  <!-- END Section B Title -->
    
  <div  id="GBCctn" class="styTableContainerNBB">
    <xsl:call-template name="SetInitialState"/>
    <table style="font-size:7pt;border-color:black;" class="styTable" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" name="GBCtable" id="GBCtable" >
      <thead class="styTableThead">
        <tr>
          <th scope="col" class="styTableCell" style="width:39mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;" colspan="2">(a)</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(e)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(f)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(g)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(h)</th>        
        </tr>
        <tr>
          <th scope="col" class="styTableCell" style="width:39mm;font-size:7pt;text-align:center;font-weight:normal;" colspan="2">Bond issuer's name, city <br />or town, and state</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:6pt;text-align:center;font-weight:normal;">Date<br /> bond issued</th>
          <th scope="col" class="styTableCell" style="width:15mm;font-size:6pt;text-align:center;font-weight:normal;">Date bond<br/>disposed of<br/>(if applicable)</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;font-weight:normal;">Outstanding<br/>bond principal</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;">Credit<br/>rate</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;font-weight:normal;"><br/>(d) x (e)</th>
          <th scope="col" class="styTableCell" style="width:20mm;font-size:7pt;text-align:center;font-weight:normal;"><br/>%</th>
          <th scope="col" class="styTableCell" style="width:26mm;font-size:7pt;text-align:center;border-right:none;font-weight:normal;">Credit<br/>(f) x (g)</th>
        </tr>
      </thead>
    <tfoot></tfoot>
    <tbody>
    <xsl:for-each select="$Form8912Data/GulfBondCredit/Item">
    	<xsl:if test="($Print != $Separated) or (count($Form8912Data/GulfBondCredit/Item) &lt;=5)">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;">
            <xsl:choose>
              <xsl:when test="position() = 1">
               7
              </xsl:when>
              <xsl:otherwise>
                <span style="width:1px;"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>    
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:6pt;font-weight:normal;font-family:verdana">
             <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine1"/>
            </xsl:call-template>
            <br/>
             <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine2"/>
            </xsl:call-template>
         
            <xsl:if test="City !=''">
            <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="City"/>
              </xsl:call-template>,
            </xsl:if>
            <xsl:if test="State !=''">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="State"/>
              </xsl:call-template>
              <span style="width:1mm;"/>
            </xsl:if>
          </td>
          
          <td class="styTableCell" style="width:15mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondIssued"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:15mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondDisposedOf"/>
            </xsl:call-template>
          </td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="OutstandingBondPrinciple"/>
            </xsl:call-template>          
          </td>  
           <td class="styTableCell" style="width:20mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="CreditRate"/>
            </xsl:call-template>          
          </td> 
           <td class="styTableCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditdxe"/>
            </xsl:call-template>          
          </td> 
                     <td class="styTableCell" style="width:20mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="Percent"/>
            </xsl:call-template>          
          </td> 
          <td class="styTableCell" style="width:26mm;text-align:right;border-right:none;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditfxg"/>
            </xsl:call-template>
          </td>
        </tr>
       </xsl:if>
      </xsl:for-each>
          
      <xsl:if test="count($Form8912Data/GulfBondCredit/Item) &lt; 1 or (($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;vertical-align:top;">7</td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;font-family:verdana;vertical-align:top;">
          <xsl:choose>											
			<xsl:when test="($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5)">
				<xsl:call-template name="PopulateAdditionalDataTableMessage">
					<xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/Item"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span class="styTableCellPad"></span>
			</xsl:otherwise>
          </xsl:choose>
          </td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>          
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>          
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>      
      <xsl:if test="count($Form8912Data/GulfBondCredit/Item) &lt; 2 or (($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8912Data/GulfBondCredit/Item) &lt; 3 or (($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8912Data/GulfBondCredit/Item) &lt; 4 or (($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>
      <xsl:if test="count($Form8912Data/GulfBondCredit/Item) &lt; 5 or (($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5))">
        <tr>
          <td class="styTableCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" rowspan="1" style="width:34mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:left;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:15mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:26mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="width:20mm;text-align:right;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
          <td class="styTableCell" style="text-align:right;width:26mm;border-right:none;font-size:7pt;font-weight:normal;height:8mm;"><span class="styTableCellPad"></span></td>
        </tr>
      </xsl:if>                            
      </tbody>
    </table>        
      <xsl:call-template name="SetInitialDynamicTableHeight">
      <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/Item"/>
      <xsl:with-param name="containerHeight" select="5"/>
      <xsl:with-param name="headerHeight" select="1"/>
      <xsl:with-param name="containerID" select=" 'GBCctn' "/>
      </xsl:call-template>  
  </div>






<!-- section b Line 8 -->
  <div class="styGenericDiv" style="width:187mm; clear: left;">
    <div class="styLNLeftNumBox" style="height:4mm;"><span style="width:5px;"/>8</div>
    <div class="styLNDesc" style="width:139.60mm;height:4mm;float:left;">
<b>Total credit.</b> Add the amounts on line 7, column (h). See the instructions for how to report as interest
income            <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$Form8912Data/CleanRenewableEnergyBondCredit/TotalCredit"/>
      </xsl:call-template>    
      <span style="letter-spacing:3.5mm;font-weight:bold;">..............................</span>
    </div>
    <div class="styLNRightNumBox" style="width:7mm;height:8mm;padding-bottom:none;"><br/>8</div>    
    <div class="styLNAmountBox" style="height:8.0mm;padding-bottom:none;width:32mm;font-size:7pt;">
	<br/>
	      <xsl:call-template name="PopulateAmount">
	        <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/TotalCredit"/>
	      </xsl:call-template>    

    </div>
          
  </div>
  
<!-- section b Line 9 -->
    <div class="styGenericDiv" style="width:187mm;clear: left;">
        <div class="styLNLeftNumBox" style="height:4mm;"><span style="width:5px;"/>9</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
         Gulf tax credit bond credits from partnerships, S corporations, estates, and trusts          <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> .......</span>
        </div>


    <div class="styLNRightNumBox" style="width:7mm;height:4mm;padding-bottom:none;">9</div>    
    <div class="styLNAmountBox" style="height:4mm;padding-bottom:none;width:32mm;font-size:7pt;">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/BondCredit"/>
          </xsl:call-template>

        </div>
      
      </div>
      
<!-- section b Line 10 -->
    <div class="styGenericDiv" style="width:187mm; clear: left;">
        <div class="styLNLeftNumBox" style="height:4mm;">10</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
Add line 8 and line 9. Estates and trusts go to line 11; partnerships and S corporations, report this
amount on Schedule K; all others, go to Part II           <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> .................</span>
        </div>


        <div class="styLNRightNumBox" style="width:6.50mm;height:8mm;padding-top:0mm;">
          <div class="" style="width:6.50mm;border-left-width:0px;background-color:lightgrey;height:4mm;"></div>          
          10
        </div>
        <div class="styLNAmountBox" style="height:8mm;width:32mm;font-size:7pt;border-top:1px;">
	<br/>
		 <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/CurrentYearBondCredits"/>
          </xsl:call-template>

        </div>

      </div>
      
      
      
<!-- section b Line 11 -->
    <div class="styGenericDiv" style="width:187mm; clear: left;">
        <div class="styLNLeftNumBox" style="height:4mm;">11</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
         Amount allocated to the beneficiaries of the estate or trust (see instructions)         
         <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ........</span>
        </div>


    <div class="styLNRightNumBox" style="width:7mm;height:4mm;padding-bottom:none;">11</div>    
    <div class="styLNAmountBox" style="height:4.0mm;padding-bottom:none;width:32mm;font-size:7pt;">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/AmtAllocatedBeneficiariesEstTr"/>
          </xsl:call-template>

        </div>
      
      </div>
 <!-- section b Line 12  -->
    <div class="styGenericDiv" style="width:187mm; clear: left;">
        <div class="styLNLeftNumBox" style="height:4mm;">12</div>
        <div class="styLNDesc" style="width:139.60mm;height:4mm;">
<b>Estates and trusts.</b> Subtract line 11 from line 10. Use this amount to complete Part II         
         <!--Dotted Line-->
          <span style="letter-spacing:3.8mm;font-weight:bold;"> ......</span>
        </div>


    <div class="styLNRightNumBoxNBB" style="width:7mm;height:4mm;padding-bottom:none;">12</div>    
    <div class="styLNAmountBoxNBB" style="height:4.0mm;padding-bottom:none;width:32mm;font-size:7pt;">
            <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/GulfBondCredit/SubtractLines"/>
          </xsl:call-template>

        </div>
      
      </div>     






    <div style="width:187mm;" >
      <span class="styBoldText">For Paperwork Reduction Act Notice, see instructions.</span> 
      <span style="width:110px;"></span>                      
      Cat. No. 37722B
      <span style="width:130px;"></span>  
      Form <span class="styBoldText">8912</span>(2007)
    </div>
    
    <br class="pageend" />    
    
    
            
<!--Begin Page 2 -->
        <!-- Page Header -->
        <div style="width:187mm;padding-top:.5mm;">
          <div style="float:left;">Form 8912 (2007)<span style="width:148mm;"/>
          </div>
          <div style="float:right;">Page <span style="font-weight:bold;font-size:8pt;">2</span>
          </div>
        </div>
        <!-- END Page Header -->

     <!-- BEGIN Part II Title -->
  <div class="styBB" style="width:187mm;border-top:1px solid black;height:7mm;padding-top:1.50mm;">
    <div class="styPartName">Part II</div>
    <div class="styPartDesc">Allowable Credit</div>
  </div>
  <!-- END Part II Title -->
  
  <!-- Part II, Line 13 -->
  <div class="styBB" style="width:187mm;">
    <div style="width:187mm;">
   <div class="styLNLeftNumBox ">13</div>
   <div style="float:left">
    Regular tax before credits:
   </div>
   <div style="float:right">
    <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>
    <div class="styIRS8912LNAmountBox" style="border-bottom:0;height:4.5mm;"></div>
   </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8912LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8912_Bullet_Round.gif" alt="dot" /> Individuals. Enter the amount from Form 1040, line 44 or Form 1040NR, line 41     </div>
     <div style="float:right">
       <span class="styDotLn">
         ......<span style="width:7px;"/>                     
          </span>
				          <div class="styIRS8912LNLeftNumBox" style="position:relative;width:2mm;">
            <span style="z-index:1;position:absolute;top:8px;right:2mm;"><img src="{$ImagePath}/8912_Bracket_Lg.gif" alt="Curly Bracket Image"/></span> 
          </div> 
          <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8912LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8912LNLeftLtrBox"></div>
     <div style="float:left">
     <img src="{$ImagePath}/8912_Bullet_Round.gif" alt="dot" />
      Corporations. Enter the amount from Form 1120, Schedule J, line 2, or the applicable
     </div>
     <div style="float:right">
      <div class="styIRS8912LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8912LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm;height:4.5mm;">
     <div class="styLNLeftNumBox"></div>
     <div style="float:left">
      line of your return  
     </div>
     <div style="float:right">
             <span class="styDotLn" style="">
             .......................... <span style="width:7px;"/>
          </span>

      <div class="styIRS8912LNRightNumBox" style="height:4.50mm;padding-top:0.80mm;">13</div>
      <div class="styIRS8912LNAmountBox" style="font-size:7pt;height:4.50mm;">
             <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form8912Data/RegularTaxBeforeCredit"/>
              </xsl:call-template>
      </div>
     </div>
    </div>
    <div style="width:187mm">
       <div class="styIRS8912LNLeftLtrBox"></div>
       <div style="float:left">
          <img src="{$ImagePath}/8912_Bullet_Round.gif" alt="dot"/>  Estates and trusts. Enter the sum of the amounts from Form 1041, Schedule G, lines
       </div>
       <div style="float:right">
          <div class="styIRS8912LNLeftNumBox" style="width:15mm;"></div>
          <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
          <div class="styIRS8912LNAmountBox" style="border-bottom:0;"></div>
       </div>
    </div>
    
    <div style="width:187mm;">
     <div class="styIRS8912LNLeftNumBox"></div>
     <div style="float:left">
      1a and 1b, or the amount from the applicable line of your return
     </div>
     <div style="float:right">
             <span class="styDotLn">
             ............<span style="width:15px;"/>
          </span>

      <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8912LNAmountBox" style="border-bottom:0;">
      </div>
     </div>
    </div>








  <!-- Part II, Line 14 -->
      <div style="width:187mm">
   <div class="styLNLeftNumBox ">14</div>
   <div style="float:left">
    Alternative minimum tax:
  </div>
   <div style="float:right">
    <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;height:4.5mm;"></div>
    <div class="styIRS8912LNAmountBox" style="border-bottom:0;;height:4.5mm;"></div>
   </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8912LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8912_Bullet_Round.gif" alt="dot" /> Individuals. Enter the amount from Form 6251, line 35
     </div>
     <div style="float:right">
       <span class="styDotLn">
         ..............<span style="width:9px;"/>                   
          </span>
				          <div class="styIRS8912LNLeftNumBox" style="position:relative;width:2mm;">
            <span style="z-index:1;position:absolute;top:8px;right:2mm;"><img src="{$ImagePath}/8912_Bracket_Sm.gif" alt="Curly Bracket Image"/></span> 
          </div> 
          <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0"></div>
          <div class="styIRS8912LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8912LNLeftLtrBox"></div>
     <div style="float:left">
       <img src="{$ImagePath}/8912_Bullet_Round.gif" alt="dot" />
      Corporations. Enter the amount from Form 4626, line 14
   </div>
     <div style="float:right">
             <span class="styDotLn">
           ..............<span style="width:9px;"/>
              </span>
            <div class="styIRS8912LNRightNumBox" style="height:4.5mm;padding-top:0.70mm;">14
      </div>
      <div class="styIRS8912LNAmountBox" style="font-size:7pt;height:4.5mm;">
              <xsl:call-template name="PopulateAmount">
                <xsl:with-param name="TargetNode" select="$Form8912Data/AlternativeMinimumTax"/>
              </xsl:call-template>
      </div>
     </div>
    </div>
    <div style="width:187mm">
     <div class="styIRS8912LNLeftLtrBox"></div>
     <div style="float:left">
      <img src="{$ImagePath}/8912_Bullet_Round.gif" alt="dot"/>  Estates and trusts. Enter the amount from Form 1041, Schedule I, line 56
       </div>
     <div style="float:right">
       <span class="styDotLn">
         ........<span style="width:9px;"/>                     
          </span>
      <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8912LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
  
       
<!-- Part II, Line 15 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">15</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
          Add line 13 and line 14
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.........................</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top:1mm;">    
        15
        </div>
        
        <div class="styLNAmountBox" style="height:5mm;font-size:7pt;width:33mm;">          
                <span style="">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/SumRegularTaxAndAMT"/>
          </xsl:call-template>
          </span>
        </div>
      </div>

<!-- Part II, Line 16a -->
 <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">16a</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Credits from Form 1040, lines 47 through 50 and lines 52 through 54      
            </div>
        <div style="float:right;">              
          <!--Dotted Line-->
         </div>
        </div>
       
        <div class="styLNRightNumBox" style="border-bottom-width:0;height:4.5mm;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0;height:4.5mm;font-size:7pt;"> </div>
        
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
       
      </div>  
      
       <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;"></div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
          (or Form 1040NR, lines  44 through 45 and lines 47 through 49)
            </div>
             <!--Dotted Line-->            
        <div style="float:right;">                 
          <span style="letter-spacing:3.5mm;font-weight:bold;">...</span>
          <span style="width:5px;"/>
        </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16a</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CreditsFromF1040"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>


   

<!-- Part II, Line 16b -->
  <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">b</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
          Foreign tax credit        
          </div>
          <div style="float:right;">
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.................</span>
            <span style="width:5px;"/>            
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16b</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
        <span style="">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/ForeignTaxCredit"/>
          </xsl:call-template>
          </span>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
<!-- Part II, Line 16c -->      
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">c</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Credits from Forms 5735 and 8834
            </div>
          <div style="float:right;">  
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">............</span>
            <span style="width:5px;"/>            
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16c</div>
        <xsl:choose>
          <xsl:when test="$Version = '2007v1.0' ">
          <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CreditsFromF5735AndF8834"/>
          </xsl:call-template>
        </div>
          </xsl:when>
          <xsl:otherwise>
          <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CreditsFromF5735AndF8834"/>
          </xsl:call-template>
        </div>
          </xsl:otherwise>
        
        </xsl:choose>
        
        
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Part II Line 16d -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">d</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Alternative motor vehicle credit (Form 8910, line 18)
            </div>
          <div style="float:right;">
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">......</span>
            <span style="width:5px;"/>          
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16d</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/AlternativeMotorVehicleCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
<!-- Part II, Line 16e -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">e</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Alternative fuel vehicle refueling property credit (Form 8911, line 19)
          </div>
          <div style="float:right;">  
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16e</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/AlternativeFuelVehicleCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>

<!-- Part II, Line 16f -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">f</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            General business credit (see instructions)
          </div>
          <div style="float:right;">          
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..........</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16f</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/GeneralBusinessCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      
<!-- Part II, Line 16g -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">g</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            Credit for prior year minimum tax (Form 8801, line 25; or Form
          </div>
          <div style="float:right;">  
            <!-- Dotted Line -->
            
           
          </div>
        </div>
        <div class="styLNRightNumBox" style="border-bottom-width:0;height:4.5mm;"></div>
        <div class="styLNAmountBox" style="border-bottom-width:0;height:4.5mm;font-size:7pt;">
         
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;"></div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
            8827, line 8)
          </div>
          <div style="float:right;">  
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..................</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16g</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/CreditForPriorYearMinimumTax"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div>
  
<!-- Part II, Line 16h -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">h</div>
        <div class="styLNDesc" style="width:98.25mm;height:4.5mm;">
          <div style="float:left;">
Qualified zone academy bond credit (Form 8860, line 9)
            <xsl:call-template name="SetFormLinkInline">
        <xsl:with-param name="TargetNode" select="$Form8912Data/QualifiedZoneAcademyBondCredit"/>
      </xsl:call-template>    
          </div>
          <div style="float:right;">  
            <!-- Dotted Line -->
            <span style="letter-spacing:3.5mm;font-weight:bold;">.....</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16h</div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/QualifiedZoneAcademyBondCredit"/>
          </xsl:call-template>
        </div>
        <div class="styLNRightNumBoxNBB" style="width:8.25mm;background-color:lightgrey;height:4.5mm;border-right-width:1px;"></div>
      </div> 
 
                  
<!-- Part II, Line 16i -->
      <div style="width:187mm;">
        <div class="styLNLeftLtrBox" style="height:4.5mm;">i</div>
        <div class="styLNDesc" style="width:138mm;height:4.5mm;">
          <div style="float:left;">
            Add lines 16a through 16h
          </div>
          <div style="float:right;">  
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">........................</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">16i
        </div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/TotalOfCredits"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Line Part II, Line 17 -->      
      <div style="width:187mm">
        <div class="styLNLeftNumBox" style="height:4.5mm;">17</div>
        <div class="styLNDesc" style="width:138mm;height:4.5mm;">
          <div style="float:left;">
            Net income tax. Subtract line 16i from line 15
          </div>
          <div style="float:right;">  
            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..................</span>
            <span style="width:5px;"/>
          </div>          
        </div>
        <div class="styLNRightNumBox" style="height:4.5mm;">17
      </div>
        <div class="styLNAmountBox" style="height:4.5mm;font-size:7pt;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/NetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>

<!-- Part II, Line 18 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">18</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;text-align:justified;padding-right:2mm; ">
            <span class="styBoldText" >Clean renewable energy bond credit allowed for the current year.</span> Enter the <span class="styBoldText" >smallest</span> of line
4, line 17, or the amount as limited by the formula in the instructions for line 18 (if line 18 is smaller
than line 4, see instructions).<span class="styBoldText" > Estates and trusts,</span> enter the <span class="styBoldText" >smallest</span> of line 6, line 17, or the
amount as limited by the formula in the instructions for line 18 (if line 18 is smaller than line 6, see
instructions). Report this amount (plus the amount, if any, from line 20 below) on Form 1040, line
55 or Form 1040NR, line 50; Form 1120, Schedule J, line 5e; Form 1041, Schedule G, line 3; or
the applicable line of your return            <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">..............................</span>
            
        </div>
        <div class="styLNRightNumBoxNBB" style="height:24mm;padding-top:0mm;border-bottom:1px black solid;">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
            <br/><br/><br/><br/> <br/><br/>          </div>
          18
        </div>
        <div class="styLNAmountBoxNBB" style="height:24mm;border-bottom:1px black solid;font-size:7pt;">
        <span style="vertical-align:baseline;height:100%;"></span><span>
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8912Data/CYCleanRnwblEnergyBondCr"/>
            </xsl:call-template>
         </span>
        </div>
      </div>
      
      
       <div style="width:187mm">
     <div class="styIRS8912LNLeftLtrBox"></div>
     <div style="float:left">
      <span class="styBoldText">Note:</span> If line 10 is zero or blank, stop here.
             </div>
     <div style="float:right">

      <div class="styIRS8912LNLeftNumBox" style="width:15mm;"></div>
      <div class="styIRS8912LNRightNumBox" style="background-color:lightgrey;border-bottom:0;"></div>
      <div class="styIRS8912LNAmountBox" style="border-bottom:0;"></div>
     </div>
    </div>
  
       
<!-- Part II, Line 19 -->
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4mm;">19</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;">
          <div style="float:left;">
         Subtract line 18 from line 17
          </div>
          <div style="float:right;">
          <!--Dotted Line-->
            <span style="letter-spacing:3.5mm;font-weight:bold;">........................</span>
            <span style="width:5px;"/>
          </div>
        </div>
        <div class="styLNRightNumBox" style="width:8mm;height:5mm;padding-top:1mm;">    
        19
        </div>
        <div class="styLNAmountBox" style="height:5mm;font-size:7pt;">          
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$Form8912Data/SubtractBondCrFromNetIncomeTax"/>
          </xsl:call-template>
        </div>
      </div>


      
      <!-- Part II, Line 20 -->      
      <div style="width:187mm;">
        <div class="styLNLeftNumBox" style="height:4.5mm;">20</div>
        <div class="styLNDesc" style="width:138mm;height:4mm;text-align:justified;padding-right:2mm;">
            <span class="styBoldText">Gulf tax credit bond credit allowed for the current year.</span> Enter the <span class="styBoldText">smallest</span> of line 10, line 19,
or the amount as limited by the formula in the instructions for line 20 (if line 20 is smaller than line
10, see instructions). <span class="styBoldText">Estates and trusts,</span> enter the <span class="styBoldText">smallest</span> of line 12, line 19, or the amount as
limited by the formula in the instructions for line 20 (if line 20 is smaller than line 12, see
instructions). Report this amount (plus the amount, if any, from line 18 above) on Form 1040, line
55 or Form 1040NR, line 50; Form 1120, Schedule J, line 5e; Form 1041, Schedule G, line 3; or
the applicable line of your return            
<!--Dotted Line-->
        </div>
        <div class="styLNRightNumBoxNBB" style="height:21mm;padding-top:0mm">
          <div class="styLNRightNumBoxNBB" style="width:7.75mm;border-left-width:0px;background-color:lightgrey;">
            <br/><br/><br/><br/><br/>
          </div>
          20        </div>
        <div class="styLNAmountBoxNBB" style="height:21mm;font-size:7pt;">
         <span style="vertical-align:baseline;height:100%;"></span><span>
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="$Form8912Data/CurrentYearGulfBondCr"/>
            </xsl:call-template>
           </span>
        </div>
      </div>
    </div>
    
    <div style="width:187mm;" >
      <span class="styBoldText"></span> 
      <span style="width:190px;"></span>                      

      <span style="width:426px;"></span>  
      Form <span class="styBoldText">8912</span>(2007)
    </div>
    
    <br class="pageend" />        
    
    <!-- BEGIN Left Over Table -->  
    <!-- Additonal Data Title Bar and Button -->
    <div class="styLeftOverTitleLine" id="LeftoverData">
      <div class="styLeftOverTitle">
        Additional Data        
      </div>
      <div class="styLeftOverButtonContainer">
        <input class="styLeftoverTableBtn" TabIndex="1"  type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
      </div>      
    </div>
    <!-- Additional Data Table -->
    <table class="styLeftOverTbl">
      <xsl:call-template name="PopulateCommonLeftover">
        <xsl:with-param name="TargetNode" select="$Form8912Data" />
        <xsl:with-param name="DescWidth" select="100"/>
      </xsl:call-template>          
    </table>
    <!-- END Left Over Table -->
        
        
       <!-- Separated Data for Part I Section A-->
       <xsl:if test="($Print = $Separated) and (count($Form8912Data/CleanRenewableEnergyBondCredit/Item) &gt; 5)">
       <br/><br/>
        <span class="styRepeatingDataTitle">Form 8912 - Part I - Clean Renewable Energy Bond Credit, Line 1:</span><br/>               	  
		<table class="styDepTbl" style="font-size:7pt;" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" name="CREBCtable" id="CREBCtable" >
		      <thead class="styTableThead">
		        <tr class="styDepTblHdr">
		          <th scope="col" class="styDepTblCell" style="width:43mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;border-bottom:none;" colspan="2">(a)</th>
		          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
		          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
		          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
		          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(e)</th>
		          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(f)</th>
		          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(g)</th>
         		 <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(h)</th>      
		          
		      </tr>
		        <tr class="styDepTblHdr">
          <th scope="col" class="styDepTblCell" style="width:43mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none;border-top:none;" colspan="2">Bond issuer's name, city <br />or town, and state</th>
          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:6pt;text-align:center;font-weight:normal;border-top:none;">Date<br /> bond issued</th>
          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:6pt;text-align:center;border-top:none;font-weight:normal;">Date bond<br/>disposed of<br/>(if applicable)</th>
          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none;">Outstanding<br/>bond principal</th>
          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none;">Credit<br/>rate</th>
          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none;"><br/>(d) x (e)</th>
          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;font-weight:normal;border-top:none;"><br/>%</th>
          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-right:none;font-weight:normal;border-top:none;">Credit<br/>(f) x (g)</th>
         </tr>
		      </thead>
		    <tfoot></tfoot>
		    <tbody>
		    <xsl:for-each select="$Form8912Data/CleanRenewableEnergyBondCredit/Item">
		        <tr>
	                   <!-- Define background colors to the rows -->
	              	<xsl:attribute name="class">
	                        <xsl:choose>
	                          <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                          <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                        </xsl:choose>
	                   </xsl:attribute>
		          <td class="styDepTblCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;">
		            <xsl:choose>
		              <xsl:when test="position() = 1">
		                <xsl:value-of select="position()"/>
		              </xsl:when>
		              <xsl:otherwise>
		                <span style="width:1px;"/>
		              </xsl:otherwise>
		            </xsl:choose>
		          </td>    
		          
		   <td class="styDepTblCell" rowspan="1" style="border-left:none;width:43mm;text-align:left;font-size:6pt;font-weight:normal;font-family:verdana">		    
               <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine1"/>
            </xsl:call-template>
            <br/>
             <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine2"/>
            </xsl:call-template>

	          
              <xsl:if test="City !=''">
          <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="City"/>
              </xsl:call-template>,
            </xsl:if>
       
            <xsl:if test="State !=''"> 
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="State"/>
              </xsl:call-template>
              <span style="width:1mm;"/>
            </xsl:if>
          </td>
		          
		          
		              <td class="styDepTblCell" style="width:16mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondIssued"/>
            </xsl:call-template>
          </td>
          <td class="styDepTblCell" style="width:16mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondDisposedOf"/>
            </xsl:call-template>
          </td>
          <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="OutstandingBondPrinciple"/>
            </xsl:call-template>          
          </td>  
           <td class="styDepTblCell" style="width:17mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="CreditRate"/>
            </xsl:call-template>          
          </td> 
           <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditdxe"/>
            </xsl:call-template>          
          </td> 
                     <td class="styDepTblCell" style="width:17mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="Percent"/>
            </xsl:call-template>          
          </td> 
          <td class="styDepTblCell" style="width:26mm;text-align:right;border-right:none;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditfxg"/>
            </xsl:call-template>
          </td>
		          
		       
		          
		          
		          
		        </tr>
      		</xsl:for-each>
   	     </tbody>
          </table>
          <br/>
       </xsl:if>
       <!-- /Separated Data for Part I -->
       
       
       
       
       
       
            <!-- Separated Data for Section B -->
       <xsl:if test="($Print = $Separated) and (count($Form8912Data/GulfBondCredit/Item) &gt; 5)">
       <br/><br/>
        <span class="styRepeatingDataTitle">Form 8912 - Section B - Gulf Tax Credit Bond Credit, Line 7:</span><br/>               	  

		<table class="styDepTbl" style="font-size:7pt;" cellspacing="0" summary="Table displaying entity name or names and corresponding employer identification numbers" name="GBCtable" id="GBCtable" >
		      <thead class="styTableThead">
		        <tr class="styDepTblHdr">
		          <th scope="col" class="styDepTblCell" style="width:43mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;border-left:none;" colspan="2">(a)</th>
		          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(b)</th>
		          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(c)</th>
		          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(d)</th>
		          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(e)</th>
		          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(f)</th>
		          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;border-bottom:none;font-weight:bold;">(g)</th>
         		 <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-bottom:none;border-right:none;font-weight:bold;">(h)</th>      
		          
		      </tr>
		        <tr class="styDepTblHdr">
          <th scope="col" class="styDepTblCell" style="width:43mm;font-size:7pt;text-align:center;border-top:none;font-weight:normal;border-left:none;" colspan="2">Bond issuer's name, city <br />or town, and state</th>
          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:6pt;text-align:center;border-top:none;font-weight:normal;">Date<br /> bond issued</th>
          <th scope="col" class="styDepTblCell" style="width:16mm;font-size:6pt;text-align:center;border-top:none;font-weight:normal;">Date bond<br/>disposed of<br/>(if applicable)</th>
          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-top:none;font-weight:normal;">Outstanding<br/>bond principal</th>
          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;border-top:none;font-weight:normal;">Credit<br/>rate</th>
          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-top:none;font-weight:normal;">Credit<br/>(d) x (e)</th>
          <th scope="col" class="styDepTblCell" style="width:17mm;font-size:7pt;text-align:center;border-top:none;font-weight:normal;"><br/>%</th>
          <th scope="col" class="styDepTblCell" style="width:26mm;font-size:7pt;text-align:center;border-top:none;border-right:none;font-weight:normal;">Credit<br/>(f) x (g)</th>
         </tr>
		      </thead>
		    <tfoot></tfoot>
		    <tbody>
		    <xsl:for-each select="$Form8912Data/GulfBondCredit/Item">
		        <tr>
	                   <!-- Define background colors to the rows -->
	              	<xsl:attribute name="class">
	                        <xsl:choose>
	                          <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                          <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                        </xsl:choose>
	                   </xsl:attribute>
		          <td class="styDepTblCell" style="width:5mm;font-size:7pt;text-align:center;border-right:none;font-weight:bold;vertical-align:top;">
		            <xsl:choose>
		              <xsl:when test="position() = 1">
<!--		                <xsl:value-of select="position()"/> --> 7
		              </xsl:when>
		              <xsl:otherwise>
		                <span style="width:1px;"/>
		              </xsl:otherwise>
		            </xsl:choose>
		          </td>    
		          
		          
                       
              <td class="styDepTblCell" rowspan="1" style="border-left:none;width:43mm;text-align:left;font-size:6pt;font-weight:normal;font-family:verdana">
            <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine1"/>
            </xsl:call-template>
            <br/>
             <xsl:call-template name="PopulateText">
              <xsl:with-param name="TargetNode" select="NameOfBondIssuer/BusinessNameLine2"/>
            </xsl:call-template>

         
            <xsl:if test="City !=''">
            <br/>
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="City"/>
              </xsl:call-template>,
            </xsl:if>
            <xsl:if test="State !=''">
              <xsl:call-template name="PopulateText">
                <xsl:with-param name="TargetNode" select="State"/>
              </xsl:call-template>
              <span style="width:1mm;"/>
            </xsl:if>
          </td>
		          
		          
		              <td class="styDepTblCell" style="width:16mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondIssued"/>
            </xsl:call-template>
          </td>
          <td class="styDepTblCell" style="width:16mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateMonthDayYear">
              <xsl:with-param name="TargetNode" select="DateBondDisposedOf"/>
            </xsl:call-template>
          </td>
          <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="OutstandingBondPrinciple"/>
            </xsl:call-template>          
          </td>  
           <td class="styDepTblCell" style="width:17mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="CreditRate"/>
            </xsl:call-template>          
          </td> 
           <td class="styDepTblCell" style="width:26mm;text-align:right;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditdxe"/>
            </xsl:call-template>          
          </td> 
                     <td class="styDepTblCell" style="width:17mm;text-align:center;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulatePercent">
              <xsl:with-param name="TargetNode" select="Percent"/>
            </xsl:call-template>          
          </td> 
          <td class="styDepTblCell" style="width:26mm;text-align:right;border-right:none;font-size:6pt;font-weight:normal;">
            <xsl:call-template name="PopulateAmount">
              <xsl:with-param name="TargetNode" select="Creditfxg"/>
            </xsl:call-template>
          </td>	          
	</tr>
      		</xsl:for-each>
   	     </tbody>
          </table>
          <br/>
       </xsl:if>
       <!-- /Separated Data for Section B --> 
       
      </form>
    </body>
  </html>
</xsl:template>
</xsl:stylesheet>
