<?xml version="1.0"?>
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:include href="PopulateTemplate.xsl"/>
<xsl:include href="CommonPathRef.xsl"/>
<xsl:include href="AddHeader.xsl"/>
<xsl:include href="AddOnTable.xsl"/>
<xsl:include href="IRS926Style.xsl"/>

<xsl:output method="html" indent="yes" encoding="iso-8859-1"/>
<xsl:strip-space elements="*" />
<xsl:param name="Form926Data" select="$RtnDoc/IRS926" />

<xsl:template match="/">
<html>
  <head>
    <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($Form926Data)"></xsl:with-param></xsl:call-template></title>    
    <!-- No Browser Caching -->
    <meta http-equiv="Pragma" content="no-cache"/>
    <meta http-equiv="Cache-Control" content="no-cache"/>
    <meta http-equiv="Expires" content="0"/>
    <!-- No Proxy Caching -->
    <meta http-equiv="Cache-Control" content="private"/>    
    <meta name="Description" content="Form 926"/>
    <meta name="GENERATOR" content="IBM WebSphere Studio"/>
    <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
    <xsl:call-template name="InitJS"></xsl:call-template>
    
    <style type="text/css">    
  <xsl:if test="not($Print) or $Print=''">
        <xsl:call-template name="IRS926Style"></xsl:call-template>  
        <xsl:call-template name="AddOnStyle"></xsl:call-template>    
  </xsl:if>
    </style>    
    
    <xsl:call-template name="GlobalStylesForm"/>
  </head>
  
  <body class="styBodyClass">    
    <form name="Form926">    
      <xsl:call-template name="DocumentHeader"></xsl:call-template>
      
      <div class="styBB" style="width:187mm;">
        <div class="styFNBox" style="height:19mm; width:31mm;">
          <div>
            Form &nbsp; <span class="styFormNumber">926</span>
            <br/>(Rev. December 2005)<br/>
            <div style="font-size:6pt; padding-top:1.8mm">
              Department of the Treasury<br/>Internal Revenue Service
            </div>
          </div>          
        </div>
        <div class="styFTBox" style="width:125mm">
          <div class="styMainTitle" style="padding-top:1mm">Return by a U.S. Transferor of Property<br/>to a Foreign Corporation</div>
          <div class="styFBT" style="margin-top:2mm;">            
            <img src="{$ImagePath}/926_Bullet_Title.gif" alt="Arrow Bullet"/> Attach to your income tax return.
          </div>
        </div>
        <div class="styTYBox" style="width:31mm; height:19mm">
          <div style="padding-top:5mm">OMB No. 1545-0026</div>              
          <div style="padding-left:5mm; text-align:left; margin-top:3mm; padding-bottom:2mm; line-height: 100%;">Attachment<br/>Sequence No. <b style="font-size:8pt">128</b></div>              
        </div>
      </div>
      
    <!-- BEGIN Part I Title -->
      <div class="styBB" style="width:187mm;">
        <div class="styPartName">Part I</div>
        <div class="styPartDesc">U.S. Transferor Information <span class="styNormalText">(see instructions)</span></div>              
      </div>
    <!-- END Part I Title -->
      
      <div class="styBB" style="width:187mm">
        <div class="styFNBox" style="width:127mm; height:9mm">          
          Name of transferor
          <div style="line-height:100%; padding-left:10mm;font-family:verdana;font-size:6pt">  
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form926Data/TransferorName/BusinessNameLine1"/></xsl:call-template>&nbsp;
            <xsl:if test="normalize-space($Form926Data/TransferorName/BusinessNameLine2)!=''">
              <br /><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form926Data/TransferorName/BusinessNameLine2"/></xsl:call-template>
            </xsl:if>
          </div>    
        </div>
        
        <div style="float:left; padding-left:1mm">          
          <b>Identifying number</b> (see instructions)
          <div style="text-align:left; padding-top:2mm">
            <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" 
            select="$Form926Data/TransferorIdentificationNumber"/></xsl:call-template>          
          </div> 
        <xsl:if test="$Form926Data/TransferorMissingEINReason !=' '">            
                  <span style="font-weight:normal;">  
                      <xsl:call-template name="PopulateText">
                       <xsl:with-param name="TargetNode" select="$Form926Data/TransferorMissingEINReason"/>
                       </xsl:call-template>
                  </span> 
              </xsl:if>  
        </div>
      </div>    
          
      <div style="padding-top:1mm; width:187mm">
        <div class="styIRS926OL">&nbsp;1</div>
        <div style="float:left">
          If the transferor was a corporation, complete questions 1a, 1b, and 1c.    
        </div>                        
      </div>
      
      <div style="padding-top:1mm; width:187mm">
        <div class="styIRS926OL" style="text-align:right">a</div>
        <div style="float:left">
          If the transfer was a section 361(a) or (b) transfer, was the transferor controlled (under section 368(c)) by                  
        </div>  
      </div>
      
      <div style="width:187mm">
        <div class="styIRS926OL"></div>
        <div style="float:left">
          5 or fewer domestic corporations?                    
        </div>    
        <div style="float:right; padding-right:0.5mm">
          <span class="styIRS926DotLn">
            .........................                         
          </span>
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/CtrlBy5OrFewerDomesticCorp" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/CtrlBy5OrFewerDomesticCorp"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/CtrlBy5OrFewerDomesticCorp"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/CtrlBy5OrFewerDomesticCorp" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/CtrlBy5OrFewerDomesticCorp"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/CtrlBy5OrFewerDomesticCorp"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>        
      </div>
      
      <div style="padding-top:1mm; width:187mm">
        <div class="styIRS926OL" style="text-align:right">b</div>
        <div style="float:left">
          Did the transferor remain in existence after the transfer?                    
        </div>  
        <div style="float:right; padding-right:0.5mm">
          <span class="styIRS926DotLn">
            ..................                                      
          </span>
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/ExistedAfterTransfer" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/ExistedAfterTransfer"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/ExistedAfterTransfer"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/ExistedAfterTransfer" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/ExistedAfterTransfer"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/ExistedAfterTransfer"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>    
      </div>          
      
      <div class="styBB" style="width:187mm; padding-top:1mm">    
        <div style="float:left; padding-left:8mm">
          If not, list the controlling shareholder(s) and their identifying number(s):        
          <div style="float:right; vertical-align:bottom">              
            <!-- button display logic -->          
            <xsl:call-template name="SetDynamicTableToggleButton">
              <xsl:with-param name="TargetNode" select="$Form926Data/ControllingShareholder" />
              <xsl:with-param name="containerHeight" select="6" />
              <xsl:with-param name="containerID" select="'part1TPctn'" />
            </xsl:call-template>               
             <!-- end button display logic -->  
          </div>                    
        </div>                  
      </div>          
      
      <div class="styIRS926TableContainer" id="part1TPctn">
        <xsl:attribute name="style">  
          <xsl:if test="count($Form926Data/ControllingShareholder) &gt;6">
            height:55.5mm;              
          </xsl:if>
        </xsl:attribute>   
        <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
        <!-- end -->                  
        <table class="styIRS926Table" cellspacing="0" cellpadding="0" border="0">  
          <thead class="styTableThead">
            <tr align="center" style="height:8mm">            
              <th class="styIRS926TblRB">Controlling shareholder</th>
              <th class="styIRS926TblCell">Identifying number</th>                              
            </tr>    
          </thead>  
          <tfoot></tfoot>
          <tbody>

           <xsl:if test="($Print != $Separated) or (count($Form926Data/ControllingShareholder) &lt;=6)">
		<xsl:for-each select="$Form926Data/ControllingShareholder">
              <tr style="height:8mm; font-size: 7pt">                
			      <td class="styIRS926TblRB" style="font-family:verdana;font-size:6pt;">                      
				        <xsl:call-template name="PopulateText">
				        		<xsl:with-param name="TargetNode" select="Name/BusinessNameLine1"/>
					 </xsl:call-template>							 
				        <xsl:if test="normalize-space(Name/BusinessNameLine2)!=''">
				          <br/>
				          <xsl:call-template name="PopulateText">
				          		<xsl:with-param name="TargetNode" select="Name/BusinessNameLine2"/>
				          </xsl:call-template>
				        </xsl:if>				        
				        <span style="width: 2px"></span>  					        
			      </td>
			      					      
			      <td class="styIRS926TblCell" align="center">  
				        <xsl:choose>
				          <xsl:when test="normalize-space(ControllingShareholderEIN)">                    
				            <xsl:call-template name="PopulateEIN">
				              	<xsl:with-param name="TargetNode" select="ControllingShareholderEIN"/>
				            </xsl:call-template>  
				            <span style="width: 2px"></span>
				          </xsl:when>  
				              <xsl:when test="normalize-space(EINMissingReason)">                    
				            <xsl:call-template name="PopulateText">
				              	<xsl:with-param name="TargetNode" select="EINMissingReason"/>
				            </xsl:call-template>  
				            <span style="width: 2px"></span>
				          </xsl:when>  

				          <xsl:otherwise> 
				            <xsl:call-template name="PopulateSSN">
				             	 	<xsl:with-param name="TargetNode" select="ControllingShareholderSSN"/>
				            </xsl:call-template>    
				            <span style="width: 2px"></span>
				          </xsl:otherwise>   
				        </xsl:choose>                
			      </td>                
			</tr>     
		</xsl:for-each>     
         </xsl:if>
           		
           		<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/ControllingShareholder) &lt; 1 or ((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell" style="border-right:1 solid black;font- family:verdana;font-size:6pt">
		                      <xsl:if test="((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                        <xsl:call-template name="PopulateAdditionalDataTableMessage">
		                          <xsl:with-param name="TargetNode" select="$Form926Data/ControllingShareholder/Name/BusinessNameLine1"/>
		                        </xsl:call-template>
		                      </xsl:if><span style="width: 2px"></span>

		                    </td>
		                    <td class="styIRS926TblCell">
		                    <span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>
                                	
               	<xsl:if test="count($Form926Data/ControllingShareholder) &lt; 2 or ((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                  <tr>
		                    <td class="styIRS926TblCell" style="width:50mm;  border-right:1 solid black;">
		                      <span style="width:4px"/>
		                    </td>
		                    <td class="styIRS926TblCell">
		                      <span style="width:4px"/>
		                      <br/>
		                      <span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>		        
		        <xsl:if test="count($Form926Data/ControllingShareholder) &lt; 3 or ((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                  <tr>
		                    <td class="styIRS926TblCell" style="width:50mm;  border-right:1 solid black;">
		                      <span style="width:4px"/>
		                    </td>
		                    <td class="styIRS926TblCell">
		                      <span style="width:4px"/>
		                      <br/>
		                      <span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>  
			<xsl:if test="count($Form926Data/ControllingShareholder) &lt; 4 or ((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                  <tr>
		                    <td class="styIRS926TblCell" style="width:50mm;  border-right:1 solid black;">
		                      <span style="width:4px"/>
		                    </td>
		                    <td class="styIRS926TblCell">
		                      <span style="width:4px"/>
		                      <br/>
		                      <span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>
			 <xsl:if test="count($Form926Data/ControllingShareholder) &lt; 5 or ((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                  <tr>
		                    <td class="styIRS926TblCell" style="width:50mm;  border-right:1 solid black;">
		                      <span style="width:4px"/>
		                    </td>
		                    <td class="styIRS926TblCell">
		                      <span style="width:4px"/>
		                      <br/>
		                      <span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>
			 <xsl:if test="count($Form926Data/ControllingShareholder) &lt; 6 or ((count($Form926Data/ControllingShareholder) &gt;6) and ($Print = $Separated))">
		                  <tr>
		                    <td class="styIRS926TblCell" style="width:50mm;  border-right:1 solid black;">
		                      <span style="width:4px"/>
		                    </td>
		                    <td class="styIRS926TblCell">
		                      <span style="width:4px"/>
		                      <br/>
		                      <span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>
          </tbody>    
        </table>  
      </div>              
      
      <div style="width:187mm; padding-top:1mm">
        <div class="styIRS926OL" style="text-align:right">c</div>
        <div style="float:left">
          If the transferor was a member of an affiliated group filing a consolidated return, was it the parent                  
        </div>  
      </div>  
        
      <div style="width:187mm">
        <div class="styIRS926OL"></div>
        <div style="float:left">
          corporation?              
        </div>  
        <div style="float:right; padding-right:0.5mm">
          <span class="styIRS926DotLn">
            ................................                      
          </span>
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/WasItParentCorporation" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/WasItParentCorporation"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/WasItParentCorporation"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/WasItParentCorporation" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/WasItParentCorporation"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/WasItParentCorporation"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>    
      </div>      

      <div style="width:184mm; padding-top:2mm; padding-bottom:2mm">    
        <div style="float:left; padding-left:8mm">
          If not, list the name and employer identification number (EIN) of the parent corporation:        
        </div>        
      </div>        
        
      <table class="styIRS926InerTable" cellpadding="0" cellspacing="0">
        <tr>
          <th class="styIRS926TblRB">Name of parent corporation</th>
          <th class="styIRS926TblCell">EIN of parent corporation</th>
        </tr>
        <tr style="height:8mm">
          <td class="styIRS926TblRB" style="font-size: 6pt;font-family:verdana;">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" 
            select="$Form926Data/NameOfParentCorporation/BusinessNameLine1"/></xsl:call-template>
            <xsl:if test="normalize-space($Form926Data/NameOfParentCorporation/BusinessNameLine2)!=''">
              <br /><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode"
               select="$Form926Data/NameOfParentCorporation/BusinessNameLine2"/></xsl:call-template>
            </xsl:if>&nbsp;   
          </td>
          <td align="center" class="styIRS926TblCell" style="font-size: 7pt">
            <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" 
            select="$Form926Data/EINofParentCorporation"/></xsl:call-template>&nbsp;
            
            <xsl:if test="$Form926Data/MissingEINReason !=' '">            
                  <span style="font-weight:normal;">  
                      <xsl:call-template name="PopulateText">
                       <xsl:with-param name="TargetNode" 
                       select="$Form926Data/MissingEINReason"/>
                       </xsl:call-template>
                  </span> 
              </xsl:if>
          </td>
        </tr>        
      </table>  
      
      <div style="width:187mm">
        <div class="styIRS926OL">&nbsp;2</div>
        <div style="float:left">
          If the transferor was a partner in a partnership that was the actual transferor (but is not treated as such under section 367),<br />list the name and EIN of the transferor's partnership:
        </div>                        
      </div>      
        
      <table class="styIRS926InerTable" cellpadding="0" cellspacing="0">
        <tr>
          <th class="styIRS926TblRB">Name of partnership</th>
          <th class="styIRS926TblCell">EIN of partnership</th>
        </tr>
        <tr style="height:8mm; font-size: 7pt">
          <td style="border-right:1 solid black; padding-left:2mm;font-family:verdana;font-size:6pt;">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode"
             select="$Form926Data/NameOfPartnership/BusinessNameLine1"/></xsl:call-template>
            <xsl:if test="normalize-space($Form926Data/NameOfPartnership/BusinessNameLine2)!=''">
              <br /><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode"
               select="$Form926Data/NameOfPartnership/BusinessNameLine2"/></xsl:call-template>
            </xsl:if>&nbsp;    
          </td>
          <td align="center">
            <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode" 
            select="$Form926Data/EINofPartnership"/></xsl:call-template>&nbsp;
            
            <xsl:if test="$Form926Data/EINofPartnershipMissingReason !=' '">            
                  <span style="font-weight:normal;">  
                      <xsl:call-template name="PopulateText">
                       <xsl:with-param name="TargetNode" 
                       select="$Form926Data/EINofPartnershipMissingReason"/>
                       </xsl:call-template>
                  </span> 
              </xsl:if>

            
          </td>
        </tr>        
      </table>      
              
    <!-- END Part I Line Items -->
  
    <!-- BEGIN Part II Title -->  
      <div class="styBB" style="border-top-width:1px;width:187mm">
        <div class="styPartName">Part II</div>
        <div class="styPartDesc">Transferee Foreign Corporation Information <span class="styNormalText">(see instructions)</span></div>        
      </div>
    <!-- END Part II Title -->
    
    <!-- BEGIN Part II Line Items -->
      <div class="styBB" style="width:187mm">
        <div class="styFNBox" style="width:127mm; height:10mm">
          <div class="styIRS926OL">&nbsp;3</div>
          <div style="float:left">
            Name of transferee (foreign corporation)
            <div style="font-family:verdana;font-size:6pt;">
              <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form926Data/TransfereeName/BusinessNameLine1"/></xsl:call-template>
              <xsl:if test="normalize-space($Form926Data/TransfereeName/BusinessNameLine2)!=''">  
                <br /><xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form926Data/TransfereeName/BusinessNameLine2"/></xsl:call-template>  
              </xsl:if> 
            </div>
          </div>          
        </div>
        <div style="float:left">
          <div class="styIRS926OL" style="width:4mm">4</div>
          <div style="float:left">
            <b>Identifying number</b>, if any
            <div style="text-align:center; padding-top: 2mm">        
              <xsl:call-template name="PopulateEIN"><xsl:with-param name="TargetNode"
               select="$Form926Data/TransfereeIdentificationNumber"/></xsl:call-template> 
             
                 <xsl:if test="$Form926Data/EINMissingReason !=' '">            
                  <span style="font-weight:normal;">  
                      <xsl:call-template name="PopulateText">
                       <xsl:with-param name="TargetNode" 
                       select="$Form926Data/EINMissingReason"/>
                       </xsl:call-template>
                  </span> 
              </xsl:if>

                
            </div>      
          </div>            
        </div>        
      </div>  
      
      <div class="styBB" style="height:8mm; width:187mm">        
        <div class="styIRS926OL">&nbsp;5</div>
        <div style="float:left">
          Address (including country)    
        </div>   
           <div style="margin-left:8mm"><br/>
        
	        <xsl:if test="$Form926Data/TransfereeUSAddress">
                <xsl:call-template name="PopulateUSAddressTemplate">
                <xsl:with-param name="TargetNode" select="$Form926Data/TransfereeUSAddress"/>
                </xsl:call-template>
              </xsl:if>

              <xsl:if test="$Form926Data/TransfereeForeignAddress">
                <xsl:call-template name="PopulateForeignAddressTemplate">
                <xsl:with-param name="TargetNode" select="$Form926Data/TransfereeForeignAddress"/>
                </xsl:call-template>
              </xsl:if>
              
         </div>  
      </div>  
            
      <div class="styBB" style="height:8mm; width:187mm">
        <div class="styIRS926OL">&nbsp;6</div>
        <div style="float:left">
          Country of incorporation or organization
          <div style="text-align:left">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" 
            select="$Form926Data/TransfereeCountryOfIncorp"/></xsl:call-template>
          </div>  
        </div>          
      </div>  
      
      <div class="styBB" style="height:8mm; width:187mm">
        <div class="styIRS926OL">&nbsp;7</div>
        <div style="float:left">
          Foreign law characterization (see instructions)
          <div style="text-align:left">
            <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode"
             select="$Form926Data/ForeignLawCharacterization"/></xsl:call-template>        
          </div>
        </div>          
      </div>  
      
      <div class="styBB" style="width:187mm; padding-bottom:0.5mm">
        <div class="styIRS926OL">&nbsp;8</div>
        <div style="float:left">
          Is the transferee foreign corporation a controlled foreign corporation?                
        </div>
        <div style="float:right; padding-right:0.5mm">
          <span class="styIRS926DotLn">
            ..............                          
          </span>        
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/IsTransfereeForeignCorp" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/IsTransfereeForeignCorp"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/IsTransfereeForeignCorp"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/IsTransfereeForeignCorp" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/IsTransfereeForeignCorp"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/IsTransfereeForeignCorp"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>            
      </div>  
    <!-- END Part II Line Items -->    
    
    <div style="padding-top:1mm; width:187mm; border-top:1 solid black">    
      <div style="float:left">
        <b>For Paperwork Reduction Act Notice, see page 4.</b>
      </div>    
      <div style="float:right">
      Cat No. 16982D
      <span style="width:45mm"></span>
      Form <b style="font-size:8pt">926</b> (Rev. 12-2005)
      </div>      
    </div>      
    
    <div style="width:187mm; border-bottom:1 solid black; page-break-before:always">    
      <div style="float:left">
        Form 926 (Rev. 12-2005)
      </div>    
      <div style="float:right">
        Page <b style="font-size:8pt">2</b>
      </div>      
    </div>      
    
    <!-- BEGIN Part III Title -->  
      <div class="styBB" style="width:187mm">
        <div class="styPartName">Part III</div>
        <div class="styPartDesc">Information Regarding Transfer of Property <span class="styNormalText">(see instructions)</span></div>        
      </div>
    <!-- END Part III Title -->
      
    <!-- BEGIN Part III Line Items -->  
      <div class="styBB" style="width:187mm">
        <div class="styFNBox" style="width:94mm; height:8mm">
          <div class="styIRS926OL">&nbsp;9</div>
          <div style="float:left">
            Date of transfer
            <span style="width:5mm;"/>
            <!-- Form to Form Link (Push Pin) -->
      		<xsl:call-template name="SetFormLinkInline">
          		<xsl:with-param name="TargetNode" select="$Form926Data/DateOfTransfer"/>
      		</xsl:call-template>  
            <div style="text-align:center; padding-top:1.5mm">
              <xsl:call-template name="PopulateText">
              	<xsl:with-param name="TargetNode" select="$Form926Data/DateOfTransfer"/>
              </xsl:call-template>
            </div>  
          </div>          
        </div>
        <div style="float:left">
          <div class="styIRS926OL" style="width:4mm">10</div>
          <div style="float:left">
            Type of nonrecognition transaction (see instructions)
            <div style="text-align:left; width:100%; padding-top: 1.5mm">
              <xsl:call-template name="PopulateText"><xsl:with-param name="TargetNode" select="$Form926Data/NonrecognitionTransactionType"/></xsl:call-template>
            </div>      
          </div>                      
        </div>                    
      </div>        
    
      <div class="styBB" style="width:187mm;">
        <div class="styIRS926OL">11</div>
        <div style="float:left">Description of property transferred:          
          <div style="float:right; vertical-align:bottom">       
                 
            <!-- button display logic -->          
            <xsl:call-template name="SetTableToggleButton">
              <xsl:with-param name="TargetNode" select="$Form926Data/PropertyDescriptionTransferred" />
              <xsl:with-param name="containerHeight" select="5" />
              <xsl:with-param name="containerID" select="'part3TPctn1'" />
            </xsl:call-template>               
             <!-- end button display logic -->  
          </div>              
        </div>            
      </div>      
            
      <div class="styIRS926TableContainer" id="part3TPctn1">  
        <xsl:attribute name="style">  
          <xsl:if test="count($Form926Data/PropertyDescriptionTransferred)&gt; 5">
            height:39mm
          </xsl:if>
        </xsl:attribute>   
        <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>
        <!-- end -->            
        
        <table class="styIRS926Table" cellspacing="0" cellpadding="0" border="0">  
          <tfoot></tfoot>
          <tbody>

          	<xsl:if test="($Print != $Separated) or (count($Form926Data/PropertyDescriptionTransferred) &lt;=5)">
			<xsl:for-each select="$Form926Data/PropertyDescriptionTransferred">
	                    <tr style="height:8mm; font-size: 7pt">                
				      <td class="styIRS926TblCell">                      
					        <xsl:call-template name="PopulateText">
					        		<xsl:with-param name="TargetNode" select="."/>
						 </xsl:call-template>							 					        
				      </td>					      
				</tr>     
			</xsl:for-each>     
         	</xsl:if>
         	
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/PropertyDescriptionTransferred) &lt; 1 or ((count($Form926Data/PropertyDescriptionTransferred) &gt;5) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                      <xsl:if test="((count($Form926Data/PropertyDescriptionTransferred) &gt;5) and ($Print = $Separated))">
		                        <xsl:call-template name="PopulateAdditionalDataTableMessage">
		                          <xsl:with-param name="TargetNode" select="$Form926Data/PropertyDescriptionTransferred"/>
		                        </xsl:call-template>
		                      </xsl:if><span style="width: 2px"></span>

		                     </td>
		                  </tr>
		        </xsl:if>
		
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/PropertyDescriptionTransferred) &lt; 2 or ((count($Form926Data/PropertyDescriptionTransferred) &gt;5) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                    	<span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>		        		        
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/PropertyDescriptionTransferred) &lt; 3 or ((count($Form926Data/PropertyDescriptionTransferred) &gt;5) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                    	<span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/PropertyDescriptionTransferred) &lt; 4 or ((count($Form926Data/PropertyDescriptionTransferred) &gt;5) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                    	<span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/PropertyDescriptionTransferred) &lt; 5 or ((count($Form926Data/PropertyDescriptionTransferred) &gt;5) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                    	<span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>		        		        
         
          </tbody> 		
          </table>
       </div>
    
      
      <div style="padding-top:1mm;width:187mm">
        <div class="styIRS926OL">12</div>
        <div style="float:left">
          Did this transfer result from a change in the classification of the transferee to that of a foreign corporation?                  
        </div>
        <div style="float:right; padding-right:0.5mm">  
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/ResultedInChangeClassification" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/ResultedInChangeClassification"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/ResultedInChangeClassification"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/ResultedInChangeClassification" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/ResultedInChangeClassification"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/ResultedInChangeClassification"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>      
      </div>
      
      <div style="width:187mm; padding-top:1mm">
        <div class="styIRS926OL">13</div>
        <div style="float:left">
          Was the transferor required to recognize income under Temporary Regulations sections 1.367(a)-4T  
          <xsl:call-template name="SetFormLinkInline">
            <xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome"/>
          </xsl:call-template>                  
        </div>
      </div>    
      
      <div style="width:187mm">
        <div class="styIRS926OL"></div>
        <div style="float:left">
          through 1.367(a)-6T (e.g., for tainted property, depreciation recapture, branch loss recapture, etc.)?                            
        </div>
        <div style="float:right; padding-right:0.5mm">
          <span class="styIRS926DotLn">
            ....
          </span>                
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/RequiredToRecognizeIncome"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>      
      </div>
      
      <div style="width:187mm; padding-top:1mm">
        <div class="styIRS926OL">14a</div>
        <div style="float:left">
          Was intangible property (within the meaning of section 936(h)(3)(B)) transferred as a result of the                        
        </div>  
      </div>  
        
      <div style="width:187mm">
        <div class="styIRS926OL"></div>
        <div style="float:left">
          transaction?                        
        </div>    
        <div style="float:right; padding-right:0.5mm">          
          <span class="styIRS926DotLn">
            ................................                                              
          </span>    
          <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
            <span>
                <xsl:call-template name="PopulateSpan">
                <xsl:with-param name="TargetNode" select="$Form926Data/IntangiblePropertyTransferred" />    
              </xsl:call-template>                  
              <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateYesCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/IntangiblePropertyTransferred"/>  </xsl:call-template></input>
          </span> &nbsp;
            <label><xsl:call-template name="PopulateLabelYes"><xsl:with-param name="TargetNode" select="$Form926Data/IntangiblePropertyTransferred"/></xsl:call-template>
              <b>Yes</b>
            </label>
            <span style="width:2px;"></span>
        </div>
       <div class="styLNDesc" style="width:15mm;text-align:right;padding-top:0mm;padding-bottom:0mm;">
        <span>
            <xsl:call-template name="PopulateSpan">
            <xsl:with-param name="TargetNode" select="$Form926Data/IntangiblePropertyTransferred" />    
          </xsl:call-template>                  
           <input type="Checkbox" class="styCkbox"><xsl:call-template name="PopulateNoCheckbox"><xsl:with-param name="TargetNode" select="$Form926Data/IntangiblePropertyTransferred"/></xsl:call-template></input>
        </span> &nbsp;
          <label><xsl:call-template name="PopulateLabelNo"><xsl:with-param name="TargetNode" select="$Form926Data/IntangiblePropertyTransferred"/></xsl:call-template>
            <b>No</b>
          </label>
        </div>
        </div>
      </div>  
     
      <div class="styBB" style="width:187mm; padding-top:1mm">
        <div class="styIRS926OL" style="text-align:right">b</div>
        <div style="float:left">If yes, describe the nature of the rights to the intangible property that was transferred in the transfer:      
          <!-- button display logic -->
          <div style="float:right; vertical-align:bottom">  
            <xsl:call-template name="SetTableToggleButton">
              <xsl:with-param name="TargetNode" select="$Form926Data/NatureRightsIntangibleProperty" />
              <xsl:with-param name="containerHeight" select="3" />
              <xsl:with-param name="containerID" select="'part3TPctn2'" />
            </xsl:call-template>
           </div>  
           <!-- end button display logic -->  
        </div>      
      </div>          
      
      <div class="styIRS926TableContainer" id="part3TPctn2">  
        <xsl:attribute name="style">  
          <xsl:if test="count($Form926Data/NatureRightsIntangibleProperty)&gt; 3">
            height:23mm;  
          </xsl:if>
        </xsl:attribute>     
        <!-- print logic -->
        <xsl:call-template name="SetInitialState"/>    
        <!-- end -->                                              
            
        <table class="styIRS926Table" cellspacing="0" cellpadding="0" border="0">  
          <tfoot></tfoot>
          <tbody>
          	<xsl:if test="($Print != $Separated) or (count($Form926Data/NatureRightsIntangibleProperty) &lt;=3)">
			<xsl:for-each select="$Form926Data/NatureRightsIntangibleProperty">
	                    <tr style="height:8mm; font-size: 7pt">                
				      <td class="styIRS926TblCell">                      
					        <xsl:call-template name="PopulateText">
					        		<xsl:with-param name="TargetNode" select="."/>
						 </xsl:call-template>							 					        
				      </td>					      
				</tr>     
			</xsl:for-each>     
         	</xsl:if>        
         	
		<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/NatureRightsIntangibleProperty) &lt; 1 or ((count($Form926Data/NatureRightsIntangibleProperty) &gt;3) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                      <xsl:if test="((count($Form926Data/NatureRightsIntangibleProperty) &gt;3) and ($Print = $Separated))">
		                        <xsl:call-template name="PopulateAdditionalDataTableMessage">
		                          <xsl:with-param name="TargetNode" select="$Form926Data/NatureRightsIntangibleProperty"/>
		                        </xsl:call-template>
		                      </xsl:if><span style="width: 2px"></span>

		                     </td>
		                  </tr>
		        </xsl:if>
		
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/NatureRightsIntangibleProperty) &lt; 2 or ((count($Form926Data/NatureRightsIntangibleProperty) &gt;3) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                    	<span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>		        		        
         	<!-- Table Filler Rows -->
		      	<xsl:if test="count($Form926Data/NatureRightsIntangibleProperty) &lt; 3 or ((count($Form926Data/NatureRightsIntangibleProperty) &gt;3) and ($Print = $Separated))">
		                  <tr style="font-size: 7pt">
		                    <td class="styIRS926TblCell">
		                    	<span style="width:4px"/>
		                    </td>
		                  </tr>
		        </xsl:if>         	 
          </tbody> 		
          </table>		        
      </div>      
      
    <!-- END Part III Line Items -->  
    
      
      
      <p style="page-break-before:always" />    
      
      <div class="styLeftOverTitleLine" style="font-family:verdana, arial, sans-serif">
        <div class="styLeftOverTitle">
          Additional Data    
        </div>
        <div class="styLeftOverButtonContainer">
          <input class="styLeftoverTableBtn" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage()" tabindex="1"/>
        </div>      
      </div>
      
      
      <!-- Additional Data Table -->
      <table class="styLeftOverTbl">
        <xsl:call-template name="PopulateCommonLeftover">
          <xsl:with-param name="TargetNode" select="$Form926Data" />              
        </xsl:call-template>          
      </table>  
      
      
          <!-- Additional Data Table-->
          
          <!-- Separated Data for Part I -->
          <xsl:if test="($Print = $Separated) and  (count($Form926Data/ControllingShareholder) &gt; 6)">
            <br/>
            <span class="styRepeatingDataTitle">Form 926, Line 1b - List the controlling shareholder(s) and their identifying number(s):</span>
            <table class="styDepTbl" style="font-size:7pt;">
              <thead class="styTableThead">
                <!--  Label the Column Headers -->
                <tr class="styDepTblHdr">
                  <th class="styDepTblCell" scope="col" style="padding-left:5mm; padding-bottom:4mm"><br/>Controlling shareholder<br/></th>
                  <th class="styDepTblCell" scope="col"><br/>Identifying number<br/></th>
                </tr>
              </thead>
              <tfoot/>
              <tbody>               
                 <xsl:for-each select="$Form926Data/ControllingShareholder">
                   <tr>
	                    <!-- Define background colors to the rows -->
	        		<xsl:attribute name="class">
	                      <xsl:choose>
	                        <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                        <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                      </xsl:choose>
	               	</xsl:attribute>
	
	                    <!-- First Column -->
	                    <td class="styTableCellText" style="width:104mm;font-family:verdana;font-size:6pt;">
	                      <span style="width:4px"/>
	                      <xsl:if test="Name/BusinessNameLine1">
	                        <xsl:call-template name="PopulateText">
	                          <xsl:with-param name="TargetNode" select="Name/BusinessNameLine1"/>
	                        </xsl:call-template>
		                        <xsl:if test="normalize-space(Name/BusinessNameLine2)">
				          	<br/>
				          	<span style="width:4px"/>
					          <xsl:call-template name="PopulateText">
					          		<xsl:with-param name="TargetNode" select="Name/BusinessNameLine2"/>
					          </xsl:call-template>
				          </xsl:if>  				
	                      </xsl:if>
	                    </td>
	                    
  				<td class="styTableCellText" style="width:73mm; text-align:center; padding-left:5mm">
	  				<xsl:choose>
				    	<xsl:when test="ControllingShareholderEIN">                    
				        	<xsl:call-template name="PopulateEIN">
				            	<xsl:with-param name="TargetNode" select="ControllingShareholderEIN"/>
				            </xsl:call-template>  
				         </xsl:when> 
				            
				         <xsl:when test="EINMissingReason">                    
				         	<xsl:call-template name="PopulateText">
				            	<xsl:with-param name="TargetNode" select="EINMissingReason"/>
				            </xsl:call-template>  
				         </xsl:when>  
				         <xsl:otherwise> 
				         	<xsl:call-template name="PopulateSSN">
				            	<xsl:with-param name="TargetNode" select="ControllingShareholderSSN"/>
				            </xsl:call-template>    
				            <span style="width: 2px"></span>
				          </xsl:otherwise>
                  </xsl:choose>   
        
            
			        </td>			               
                  </tr>
                </xsl:for-each>
              </tbody>
            </table>
          </xsl:if>
          <!-- /Separated Data for Part I -->
      
          <!-- Separated Data for Part III - 11 -->
	   <xsl:if test="($Print = $Separated) and  (count($Form926Data/PropertyDescriptionTransferred) &gt; 5)">
            <br/><br/>
            <span class="styRepeatingDataTitle">Form 926, Line 11 - Description of property transferred:</span>
            <table class="styDepTbl" style="font-size:7pt;">
              <thead class="styTableThead">
                <!-- Label the Column Headers -->
                <tr class="styDepTblHdr">
                  <th class="styDepTblCell" scope="col" style="padding-left:5mm; padding-bottom:4mm"><br/>Description of property transferred:<br/></th>
                </tr>
              </thead>
              <tfoot/>
              <tbody>               
                 <xsl:for-each select="$Form926Data/PropertyDescriptionTransferred">
                   <tr>
	                    <!-- Define background colors to the rows -->
	        		<xsl:attribute name="class">
	                      <xsl:choose>
	                        <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                        <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                      </xsl:choose>
	               	</xsl:attribute>	
	                    <!-- First Column -->
	                    <td class="styTableCellText" style="width:186mm; height:7mm">
	                        <xsl:call-template name="PopulateText">
	                          <xsl:with-param name="TargetNode" select="."/>
	                        </xsl:call-template>
	                    </td>	                    
                    </tr>
                </xsl:for-each>
              </tbody>
            </table>
          </xsl:if>          
          <!-- /Separated Data for Part III - 11 -->
          
          <!-- Separated Data for Part III - 14b -->
	   <xsl:if test="($Print = $Separated) and (count($Form926Data/NatureRightsIntangibleProperty) &gt; 3)">
            <br/><br/>
            <span class="styRepeatingDataTitle">Form 926, Line 14b - Describe the nature of the rights to the intangible property that was transferred in the transfer:</span>
            <table class="styDepTbl" style="font-size:7pt;">
              <thead class="styTableThead">
                <!-- Label the Column Headers -->
                <tr class="styDepTblHdr">
                  <th class="styDepTblCell" scope="col" style="padding-left:5mm; padding-bottom:4mm"><br/>If yes, describe the nature of the rights to the intangible property that was transferred in the transfer:<br/></th>
                </tr>
              </thead>
              <tfoot/>
              <tbody>               
                 <xsl:for-each select="$Form926Data/NatureRightsIntangibleProperty">
                   <tr>
	                    <!-- Define background colors to the rows -->
	        		<xsl:attribute name="class">
	                      <xsl:choose>
	                        <xsl:when test="position() mod 2 = 1">styDepTblRow1</xsl:when>
	                        <xsl:otherwise>styDepTblRow2</xsl:otherwise>
	                      </xsl:choose>
	               	</xsl:attribute>
	
	                    <!-- First Column -->
	                    <td class="styTableCellText" style="width:186mm; height:7mm">
	                        <xsl:call-template name="PopulateText">
	                          <xsl:with-param name="TargetNode" select="."/>
	                        </xsl:call-template>
	                    </td>	                    
                    </tr>
                </xsl:for-each>
              </tbody>
            </table>
          </xsl:if>                    
          <!-- /Separated Data for Part III - 14b -->
                                              
    </form>    
  </body>
</html>
</xsl:template>

</xsl:stylesheet>