<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
    <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
  <xsl:output method="html" indent="yes"/>
  <xsl:strip-space elements="*"/>
  <!-- Defines the stage of the data, e.g. original or latest -->
  
  <xsl:include href="PopulateTemplate.xsl"/>
  <xsl:include href="AddHeader.xsl"/>  
  <xsl:include href="CommonPathRef.xsl"/>
  <xsl:include href="AddOnTable.xsl"/>
  <xsl:include href="IRS1118ScheduleJStyle.xsl"/>
  
  <xsl:param name="FormData" select="$RtnDoc/IRS1118ScheduleJ"/>

<xsl:template match="/">
<html>
<head>
  <title><xsl:call-template name="FormTitle"><xsl:with-param name="RootElement" select="local-name($FormData)"></xsl:with-param></xsl:call-template></title>

  <!-- No Browser Caching -->
  <meta http-equiv="Pragma" content="no-cache" />
  <meta http-equiv="Cache-Control" content="no-cache" />
  <meta http-equiv="Expires" content="0" />
  <!-- No Proxy Caching -->
  <meta http-equiv="Cache-Control" content="private" />
  <!-- Define Character Set -->
  <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
  <meta name="Description" content="IRS Form 1118 Schedule J" />
  
  <!-- javascript include -->
  <script language="JavaScript" src="{$ScriptPath}/FormDisplay.js" type="text/javascript"></script>
  <xsl:call-template name="InitJS"></xsl:call-template>
  <!-- Commented out the following line because of the defect 2296 --> 
  <!--xsl:call-template name="AddOnStyle"></xsl:call-template-->
  <style type="text/css">

<!--   <xsl:if test="not($Print) or $Print=''">    -->

      <xsl:call-template name="IRS1118ScheduleJStyle"/>
      <xsl:call-template name="AddOnStyle"/>

<!--   </xsl:if>     -->
  </style>
  
<xsl:call-template name="GlobalStylesForm"/>
</head>
<body class="styBodyClass">

<xsl:call-template name="DocumentHeader"></xsl:call-template>
<!-- BEGIN FORM HEADER -->
    <div  class="styBB" style="width:187mm;">

<div class="styFNBox" style="width:26mm;height:33.25mm;border-right-width:.5mm;">
      <span class="styFormNumber" style="font-size: 10pt;">Schedule J 
         <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$FormData"/>
         </xsl:call-template>
     </span><br />
      <div class="styFormNumber" style="font-size: 9pt;">(Form 1118)</div>
      <br />
     <div style="font-size:6pt;padding-top:2mm;padding-bottom:10mm;height:6mm;">(Rev. December 2007)</div>
        <span class="styAgency" style="text-align:center;">Department of the Treasury</span><br /><span class="styAgency" style="text-align:center">Internal Revenue Service</span>
 </div>
  <!-- Form Title Box -->

  <div class="styFTBox" style="width:129.5mm;height:33.25mm;">
    		<span class="styMainTitle" style="height:8mm;">Adjustments to Separate Limitation Income (Loss) Categories for Determining Numerators of Limitation Fractions, Year-End Recharacterization Balances, and Overall Foreign Loss Account Balances
             </span>
                <br/>
    For calendar year 
           <span style="width:10mm;border-bottom: 1 solid black">
             <xsl:call-template name="PopulateReturnHeaderTaxYear"></xsl:call-template>
          </span>
            , or other tax year beginning 
            <span style="width:18mm;border-bottom: 1 solid black;text-align:left;">
               <xsl:call-template name="PopulateReturnHeaderTaxPeriodBeginDate"></xsl:call-template>
            </span>  ,<br /> and ending  
            <span style="width:18mm;border-bottom: 1 solid black;text-align:left;">
               <xsl:call-template name="PopulateReturnHeaderTaxPeriodEndDate"></xsl:call-template>
           </span>
      <br /><br/>
              <span class="styBoldText" style="font-size:6pt;">
             <img src="{$ImagePath}\1118SchJ_Bullet.gif" alt="Right arrow" border="0"/>Attach to Form 1118.  For Paperwork Reduction Act Notice, see the Instructions for Form 1118.
          </span>
         </div>

    <!-- OMB No. -->
 <div class="styTYBox" style="width:29.5mm;height:33.25mm;border-left-width:.5mm;padding-top:15mm;padding-bottom:1mm;border-bottom-width:0px;text-align:center;float:left;">   
 OMB No. 1545-0122
</div>
</div>
<!-- Name and Address -->
<div class="styBB" style="width:187mm;">
 <div class="styNameBox" style="width:143mm;height:9mm;font-weight:normal;font-size:7pt;">
 <!--
 <div class="styINBox" style="width:186mm;height:8mm;border-right-width:0px;border-bottom-width:0px;"> -->
     Name of corporation<br/>
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine1</xsl:with-param></xsl:call-template><br/>
    <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">BusinessNameLine2</xsl:with-param></xsl:call-template>
  </div>
     <div class="styEINDateAssets" style="width:43mm;height:9mm;border-top-width:0px;border-bottom-width:0px;">
         <span style="font-weight:bold">Employer identification number<br/><br /></span>
     <div class="styBoldText">
      <xsl:call-template name="PopulateReturnHeaderFiler"><xsl:with-param name="TargetNode">EIN</xsl:with-param></xsl:call-template>      
    </div>    
  </div>
</div>
<!-- end form number and name section -->

<!-- Part I-->
<div class="styBB" style="width:187mm;border-top-width:0px; ">
  <div class="styTitleName" style="height:4.7mm;border-bottom-width:1px;">Part I</div>
  <div class="styTitleDesc" style="height:4.7mm;font-size:8pt;padding-left:4px;border-right-width:0px;border-top-width:1px;border-bottom-width:1px;">
       <span class="styBoldText">
         Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions 
       </span><span class="styNormalText">
       (See instructions.)</span>
  </div>
</div>

<!-- If the Separate Print Solution is ON and there exists any data for the repeating element more than once, -->
<!-- display an EMPTY table.                                                                                  -->
<xsl:if test="($Print = $Separated) and 
               ( (count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/OtherIncomeColm) &gt; 1) )">

	<!-- Part I table 1 separated-->
	<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="adjSepLimInc">
	   <table cellspacing="0" style="font-size:7pt;">
	     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
	     <tr>
	      <th class="IRS1118ScheduleJ_GenericCell" style=" width:61mm;height:10mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(i)</span><br/>General category income
	        	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(ii)</span><br/>Passive category income
	      </th>
	   
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;border-right-width:1px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(iii)</span>
	        <br/>Other income*
	      </th>
	      	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;border-right-width:0px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(iv)</span>
	        <br/>U.S. income
	      </th>

	    </tr>
	     </thead>
	     <tfoot></tfoot>
	     <tbody>
	     <!-- Part I, line 1 -->
	    <tr>
	      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:1px;padding-right:5mm;" scope="row">1</td>
	      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:1px;" scope="row">Income or (loss) before adjustments (see instructions).</td>
	     
		 <td class="IRS1118ScheduleJ_GenericCell" style="text-align:left;"> 
			<xsl:call-template name="PopulateAdditionalDataTableMessage">
			  <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome"/>
			    <xsl:with-param name="ShortMessage"	select=" 'true' " />
			</xsl:call-template>
			<span class="styTableCellPad"></span>
		</td>
		<td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
             </td>
		<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
		</td>
				<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
		</td>

	    </tr>
	<tr>
        <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">2</td>
        <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;">Allocation of separate limitation losses:</td>
      </tr> 
      <!-- line 2a separated data --> 
	<tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;border-bottom-width:2px;border-right-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
       </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	 </td>
	         <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>

	    </tr>
	    <!-- line 2b separated data  blank rows-->
    <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income </td>
        <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span>(<span style="width:16px;">)</span>			 
        </td>
	  <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;border-right-width:2px;border-bottom-width:2px"><span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
   	   <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	   </td>
	   	         <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>

    </tr>
    <!-- line 2c separated data top blank rows -->
     <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other income* </td>
        <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span>(<span style="width:16px;">)</span>			 
        </td>
        <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span>(<span style="width:16px;">)</span>			 
        </td>
   	   <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:1px;border-bottom-width:2px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	   </td>
	   	         <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>

    </tr>
      <tr>
        <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">3</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2c</td>
        <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>
	 <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
						 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
 
       </tr>
       
       <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">4</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of overall foreign losses</td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	   </td>
	   <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>

		  </tr>
		  <!-- line 5 -->
		  <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">5</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of domestic losses</td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	  </td>
	  <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
   			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
   			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>

		  </tr>
		  <!-- line 6 blank -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 3 through 5.</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
       </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr> 
	  <!-- separated line 7 -->        
	  <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">7</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses</td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	  </td>
	  <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
         </td>
   			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
   			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>

		  </tr>
		  <!-- separated data line 8 -->
       <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">8</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 and 7.</td>
         <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span><span style="width:16px;"></span>
	  </td>
	 <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
       
		<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"><span class="styTableCellPad"></span><span style="width:16px;"></span>
		</td>
				<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"><span class="styTableCellPad"></span><span style="width:16px;"></span>
		</td>

	 </tr>
 
    <!-- line 9 separated data -->       
  	<tr>
        <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">9</td>
        <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
      </tr> 
      <!-- line 2a separated data --> 
	<tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;border-bottom-width:2px;border-right-width:2px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
       </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>
	         <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>

	    </tr>
	  
	  
	  	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
	<td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;border-bottom-width:2px;border-right-width:2px"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
       </td>
	 
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	    
<!-- separated data line 7c -->
	  <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span><span style="width:16px;"></span>
	 </td>
	 <td class="IRS1118ScheduleJ_GenericCell"><span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
      
			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:1px;border-bottom-width:2px;border-right-width:2px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>
			 		 		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

		  </tr>

	  <!-- line 10 separated -->
	  <tr>
         <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">10</td>
         <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses</td>
         <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
	  </td>
	  <td class="IRS1118ScheduleJ_GenericCell"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
         </td>
   			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
				<span class="styTableCellPad"></span><span style="width:16px;"></span>
			 </td>
   			 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;"> 
				<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
			 </td>

		  </tr>	  <!-- line 11 -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:1px;padding-right:5mm;" scope="row" valign="top">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:1px;" scope="row" ><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Combine lines 8 through 10. Enter
each result here and on Part II, line 6, of corresponding Schedule B..</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
       		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 			 		 		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	      <!-- Part II title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
  <div class="styTitleName" style="height:4.7mm;">Part II</div>
       
        <span style="width:3mm;"></span> 
        Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey"><span style="width:4px;"></span></td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 
	  </tr>
	  <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-right:width:1px;"><span style="width:4px;"></span></td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
	   <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	
	  <tr>
       <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
       <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
       <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
       </td>
     
		 <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-right-width:1px;"><span style="width:4px;"></span></td>
			 		 		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;padding-top:5px;">
  <div class="styTitleName" style="height:4.7mm;">Part III</div>
       
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br /><span style="padding-left:3.5mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>
    <!-- Part III line 1 separated data -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
    		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 2 separated data -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
      	 		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 3 separated data -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III, line 4 separated -->
	  <!-- Part III line 5 separated data -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 7)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad">(</span><span style="width:16px;">)</span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad">(</span><span style="width:16px;">)</span>
		 </td>
		<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 6 separated data, blank line -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
      	<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr> 
	  	  <!-- PartIV title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;padding-top:5px;">
  <div class="styTitleName" style="height:4.7mm;">Part IV</div>
       
        <span style="width:3mm;"></span> 
        Overall Domestic Loss Account Balances (section 904(g)(1))<br /><span style="padding-left:3.5mm;">
        </span>
      </td>
    </tr>
    <!-- Part III line 1 separated data -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
    		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 	<td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 2 separated data -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
      	 		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 	<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 3 separated data -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span>(<span style="width:16px;">)</span>
		 </td>
		<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III, line 4 separated -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
      		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 		 	<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 5 separated data -->
	  <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
		 <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>
		 		 	<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:0px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr>
	  <!-- Part III line 6 separated data, blank line -->
	
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" style="padding-right:5mm;">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
	<td class="IRS1118ScheduleJ_GenericCell"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
      </td>
      	<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
	</td>
		<td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;border-bottom-width:1px;"> 
			<span class="styTableCellPad"></span><span style="width:16px;"></span>
		 </td>

	  </tr> 

	 </tbody>
  </table>
 </div>
 <!--BEGIN FOOTER-->
  <div style="width:187mm">
        <div style="float: left; clear: none;">
           <span class="styBoldText">* Important: </span>
              <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>
           </span>in instructions.
        </div>
           <span style="width:13mm;"></span>
          Cat. No. 10309U 
          <span style="width:29px;"></span>  
          <span class="styBoldText">Schedule J (Form 1118) (Rev. 12-2007)</span>
    </div>     
    <div class="pageEnd"></div>
  <!--END FOOTER-->  

</xsl:if>

<!-- If the Separate Print Option is OFF OR if the Separate Print Option is ON and there is 0 or 1 data -->
<!-- for each repeating element, print the table with data inline.                                      -->
<xsl:if test=" ($Print != $Separated) or 
               ( ($Print = $Separated) and 
                 ( (count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome) &lt; 2) and
                   (count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome) &lt; 2) and
                   (count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome) &lt; 2) and
                   (count($FormData/OtherIncomeColm) &lt; 2) ) )">
                
<!-- Part I  table 1 This is the primary table I think-->                 
<div class="IRS1118ScheduleJ_TableContainer" style="width:187mm; border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="adjSpLmInc">
<!--   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;font-weight:normal;text-align:center;">
 </thead>
     <tfoot></tfoot>
     <tbody>  -->
     <!-- line 1 work here -->
      
	   <table cellspacing="0" style="font-size:7pt;">
	     <thead  style="display:table-header-group;font-weight:normal;text-align:center;">
	     <tr>
	      <th class="IRS1118ScheduleJ_GenericCell" style="width:61mm;height:10mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(i)</span><br/>General category income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(ii)</span><br/>Passive category income
	      </th>
	    
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;border-right-width:1px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(iii)</span>
	<xsl:call-template name="SetFormLinkInline">
	    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]"/>
	</xsl:call-template>
	        <br/>Other income*
	      </th>
	      	      <th class="IRS1118ScheduleJ_GenericCell" style="width:32mm;height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(iv)</span><br/>U.S. income
	                        <xsl:call-template name="SetFormLinkInline">
                  <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm"/>
                  <xsl:with-param name="Style">width:10mm;text-align:right;padding-left:16mm</xsl:with-param>
                </xsl:call-template>

	      </th>
	    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>
       <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px;" scope="row" >Income or (loss) before adjustments</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeLossBeforeAdjustments"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;"  valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeLossBeforeAdjustments"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px; " valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;"  valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm/IncomeLossBeforeAdjustments"/>
        </xsl:call-template>
      </td>

    </tr>  
    <!-- line 2 -->       
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  colspan="5" scope="row">Allocation of separate limitation losses:</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  scope="row">General category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;font-size:10px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-top-width:1px;font-size:10px;">
         <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-top-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-top-width:1px;background-color:lightgrey;"></td>

    </tr> 
    <!-- line 2b leftover -->        
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
         <xsl:call-template name="PopulateNegativeNumber">
            <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;font-size:10px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
       </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
    </xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"> </td>
   
    </tr>
    <!--Need to show the row c even when there is no data -->
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)">
      <tr class="styDepTblRow1">    
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell"   scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>
        </td>
         <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;background-color:lightgrey;"></span>)
        </td>

      </tr>
    </xsl:if>

    <!-- Tracks the number of rows repeating for c to determine the color that row 3 would start. -->
    <xsl:variable name="twoICounter" select="count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>    
      <!-- If the position of the repeating c row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      <td class="IRS1118ScheduleJ_SubIndexCell"  scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px; border-right-width:1px;border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"></td>
    
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>     
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2c</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;" >
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeOrLossAndAllocationForCY"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeOrLossAndAllocationForCY"/>
         </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-top-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>

    </tr> 
    <!-- Part I line 4 -->        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  scope="row">Allocation of overall foreign losses</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocnOfOverallForeignLosses"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocnOfOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocnOfOverallForeignLosses"/>
    </xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;font-size:10px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/AllocnOfOverallForeignLosses"/>
    </xsl:call-template>
      </td>
   
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;"  scope="row">Allocation of domestic losses</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
         <xsl:call-template name="PopulateNegativeNumber" >
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationOfDomesticLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;" >
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationOfDomesticLosses"/>
         </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationOfDomesticLosses"/>
       </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;font-size:10px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/AllocationOfDomesticLosses"/>
       </xsl:call-template>
      </td>

    </tr>
       <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-size:10px;font-weight:bold;">Subtotal&#151;</span><span style="font-size:10px;"> lines 3 through 5.</span></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
        <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>

    </tr>         
      <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"  style="font-size:10px;">Recapture of overall foreign losses</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallForeignLosses"/>
         </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallForeignLosses"/>
       </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;font-size:10px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/RecaptureOverallForeignLosses"/>
       </xsl:call-template>
      </td>

    </tr>
    <!-- Tracks the number of rows repeating for c to determine the color that the row 8 would start. -->
    <xsl:variable name="sevenICount" select="count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)" />
    
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7.</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
 
    </tr>         
   <!-- Part I, line 9 for now -->     
   
        <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5"  style="font-size:10px;" scope="row">Recharacterization of separate limitation income:</td>
    </tr>  

        <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"  style="font-size:10px;">General category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;font-size:10px;">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;font-size:10px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-top-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-top-width:1px;background-color:lightgrey;"></td>

    </tr> 
        <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;border-width:2px;">
         <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
       </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
    </xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"> </td>
   
    </tr>
        <xsl:if test="not($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)">
      <tr class="styDepTblRow1">    
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell"  scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>
        </td>
         <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;background-color:lightgrey;"></span>)
        </td>

      </tr>
    </xsl:if>
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>    
      <!-- If the position of the repeating c row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      
      <td class="IRS1118ScheduleJ_SubIndexCell"  scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell"  style="font-size:10px;" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="font-size:10px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-width:2px;font-size:10px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"></td>
    
    </tr>
    </xsl:for-each>         
    <tr>
        <td class="IRS1118ScheduleJ_IndexCell" scope="row" valign="top">10</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px;" scope="row">Recapture of overall domestic
losses</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom"  style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallDomesticLosses"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom"  style="font-size:10px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallDomesticLosses"/>
         </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallDomesticLosses"/>
    </xsl:call-template>
      </td>
          <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;border-top-width:1px;border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/RecaptureOverallDomesticLosses"/>
    </xsl:call-template>
      </td>
  
    </tr>
    
    <!-- Part I line 11 -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" valign="top">11</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Combine lines 8 through 10. Enter each result here and on Part II, line 6,
of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom"  style="font-size:10px;">
        <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/NumeratorOfLimitationFraction"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom"  style="font-size:10px;">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/NumeratorOfLimitationFraction"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;border-right-width:1px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey; border-right-width:0px;" valign="bottom">
  
      </td>

    </tr>  




    <!-- Part II title new part-->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="6" scope="row" style="padding-top:0px;padding-bottom:0px;border-right-width:0px;border-top-width:1px; font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
        <div class="styTitleName" style="height:4.7mm;">Part II</div>
        
        <span style="width:3mm;padding-top:1mm;"></span> 
            Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized<br/><span style="padding-left:4mm;">(section 904(f)(5)(C))</span>
      </td>
    </tr>  
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row" style="font-size:10px;" >General category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncomexx"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px; background-color:lightgrey;">
       </td>

      
    </tr>  
    <!-- Part II row b -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px" scope="row">Passive category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px;">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveCategoryIncome"/>
          </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncomexx"/>
         </xsl:call-template>
      </td>
    <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;font-size:10px">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/PassiveCategoryIncome"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px; background-color:lightgrey;">
      </td>
    </tr> 
    <!-- Part II line c --> 

       <!-- blank lines, row c,  if no data -->
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)">
      <tr>
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
          <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
          <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>

      </tr>
    </xsl:if>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;background-color:lightgrey; ">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
  <!--              <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>   -->
                  <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>

    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->

    <!-- Part III title third -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="6" scope="row" style="border-top-width:1px; border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
        <div class="styTitleName" style="height:4.7mm;">Part III</div>

      
        <span style="width:3mm;background-color:ightblue;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))
        <span style="font-style:italic;font-weight:normal;"><br/><span style="padding-left:3mm;">
        Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px"  scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
   		 </xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px"  scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
   		 </xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    		</xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>
      
    </tr>
    
    <!-- Part III line 3 -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell"   scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    		</xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    		</xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr> 
 
 
    <!-- Part III, line 4 -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px"  scope="row">Current year recapture (from Part I, line 7)</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearRecapture"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearRecapture"/>
    		</xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearRecapture"/>
    </xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr>
    
    <!-- Part III, line 6 top line blank -->         
<!--    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>          -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px"  scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Combine lines 1 through 4.</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
   		 <xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
    		</xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
               <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
    </tr>
    
     <!-- Part IV title forth -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="6" scope="row" style="border-top-width:1px; border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
        <div class="styTitleName" style="height:4.7mm;">Part IV</div>

      
        <span style="width:3mm;"></span> 
        Overall Domestic Loss Account Balances (section 904(g)(1)))
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px"  scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/BeginningBalance"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/BeginningBalance"/>
   		 </xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" style="font-size:10px"  scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/CurrentYearAdditions"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="font-size:10px" >
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/CurrentYearAdditions"/>
   		 </xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;font-size:10px;">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/CurrentYearAdditions"/>
    		</xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>
      
    </tr>
    
    <!-- Part IV line 3 -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="font-size:10px"  scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateNegativeNumber" >
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/CurrentYearReductions"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/CurrentYearReductions"/>
    		</xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/CurrentYearReductions"/>
    		</xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr> 
    <!-- Part IV, line 4 -->        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/Subtotal"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/Subtotal"/>
    		</xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr>     
    <!-- Part IV, line 5 -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 10)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/ OverallDomLossAcctBalances/CurrentYearRecapture"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/CurrentYearRecapture"/>
    		</xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/CurrentYearRecapture"/>
    </xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;"></td>

    </tr>
    
    <!-- Part III, line 6 top line blank -->         
<!--    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>          -->
    <!-- Part IV, line 6  -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5
from line 4.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
   		 <xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/EndingBalance"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/EndingBalance"/>
    		</xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
               <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span><span style="width:16px;"></span>
        </td>
    </tr>
   
    
    </tbody>         
  </table>
  </div>
<!--BEGIN FOOTER-->
 <div style="width:187mm">
        <div style="float: left; clear: none;">
           <span class="styBoldText">* Important: </span>
              <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>
           </span>in instructions.
        </div>
           <span style="width:13mm;"></span>
          Cat. No. 10309U 
          <span style="width:29px;"></span>  
          <span class="styBoldText">Schedule J (Form 1118) (Rev. 12-2007)</span>
    </div>     
    <div class="pageEnd"></div>
      <!--END FOOTER-->  
  </xsl:if>      
  

  <!-- If the Separate Print Option is OFF, repeat table for the repeating column iii. -->
  <!-- the repeating columns of column iii is displayed below -->
  <!-- first column iii -->
  <xsl:if test="($Print != $Separated) and count($FormData/OtherIncomeColm) &gt; 1">
    <xsl:for-each select="$FormData/OtherIncomeColm">
      <xsl:variable name="pos" select="position()"/>
      <xsl:if test="$pos mod 9 = 2">
        <!-- //////////////////////////////////////////////////////////////////////////////////////////
        
          Repeat the Whole Table Here 
          
          ///////////////////////////////////////////////////////////////////////////////////////// -->
<!-- Part I-->
<div class="styBB" style="width:187mm;border-top-width:1px;">
  <div class="styTitleName" style="height:4.7mm;border-bottom-width:1px;">Part I</div>
  <div class="styTitleDesc" style="height:4.7mm;font-size:8pt;padding-left:4px;border-right-width:0px;border-top-width:1px;border-bottom-width:1px;">
       <span class="styBoldText">
         Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions 
       </span><span class="styNormalText">
       (See instructions.)</span>
  </div>
</div>

<!-- Part I table 1 -->

<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;page-break-after;always;" id="adSeLmIn">
   <table cellspacing="0" style="font-size:7pt;">
     <thead style="display:table-header-group;">
     <tr>
      <th class="IRS1118ScheduleJ_GenericCell" style="width:61mm;height:10mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]"/>
        </xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span>
        <xsl:call-template name="SetFormLinkInline">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]"/>
        </xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;border-right-width:0px;" scope="col">
        <span class="styBoldText">(iii)</span>
        <xsl:call-template name="SetFormLinkInline">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]"/>
        </xsl:call-template>        
        <br/>Other Income*
      </th>
        
    </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>
    <!-- line 1 -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:1px;" scope="row" valign="top">1</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:1px;" scope="row">Income or (loss) before adjustments (see 
           instructions). </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    		<xsl:call-template name="PopulateAmount">
     			 <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeLossBeforeAdjustments"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    		<xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeLossBeforeAdjustments"/>
   		 </xsl:call-template>
      </td>
          <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
   		 <xsl:call-template name="PopulateAmount">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/IncomeLossBeforeAdjustments"/>
    		</xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Allocation of separate limitation losses:</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    		</xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
   		 <xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    		</xsl:call-template>
      </td>
      
    </tr>
    <!-- repeating data line 2b -->         
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
   		 <xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
   		 </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    		</xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    		<xsl:call-template name="PopulateNegativeNumber">
      			<xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    		</xsl:call-template>
      </td>
        </tr>
    <!-- repeating data line 2c -->
         
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:1px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;border-right-width:0px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
         </xsl:call-template>
      </td>
       </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2c</td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeOrLossAndAllocationForCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeOrLossAndAllocationForCY"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/IncomeOrLossAndAllocationForCY"/>
        </xsl:call-template>
      </td>
    </tr>
    <!-- line 4 -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLosses"/>
         </xsl:call-template>
      </td>
        </tr> 
        <!-- line 5 -->        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
   </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr> 
    
    <!-- line 6 -->        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
       <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
       </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
       <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
      </xsl:call-template>
      </td>
</tr> 
<!-- line 7 -->        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="10" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>         
<!-- repeating rows -->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
        </xsl:call-template>
      </td>
       </tr> 
       <!-- line 7 b -->        
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/PassiveIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/PassiveIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
       <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/PassiveIncome"/>
        </xsl:call-template>
      </td>
      </tr>
   
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////--> 
    <!-- line 7c -->     
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width1px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
       </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;border-right-width:0px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7c.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
       <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
       </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
       <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
       </xsl:call-template>
      </td>
   </tr> 
   
    <!-- line 9 repeating data -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
       </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
       <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
       </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- line 10 repeating data -->       
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="padding-left:.5mm;" valign="top" scope="row">10</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of current year U.S. source losses (see instructions)</td>
    
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
     
    </tr> 
    <!-- line 11 blank -->        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:1px;padding-left:.5mm;" valign="top" scope="row">11</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:1px;" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Subtract line 10 from line 5. Enter each result here and on Part II, line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="11" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
<div class="styTitleName" style="height:4.7mm;">Part II</div>
        
        <span style="width:3mm;"></span> 
        Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized 
      </td>
    </tr> 

<!-- repeating rows Part II, line a-->       
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
       <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncomeXX"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
       </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
       </xsl:call-template>
      </td>
   </tr> 
  
   <!-- line b -->        
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/PassiveIncomeXX"/>
       </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
       </xsl:call-template>
      </td>
    </tr>
         
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;" >
          <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
          </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
    
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
       <div class="styTitleName" style="height:4.7mm;">Part III</div>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:3mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell" >
          <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/BeginningBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" >
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/BeginningBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/BeginningBalance"/>
        </xsl:call-template>
      </td>
  </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
        </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
         <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
       </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
        </xsl:call-template>
      </td>
 </tr>  
 <!--Part III,  line 4 repeating data if not separated -->       
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/Subtotal"/>
          </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
          <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/Subtotal"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/Subtotal"/>
        </xsl:call-template>
      </td>
    </tr>
    <!-- Part III, line 5 repeating data if not separated -->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>    
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
    </tr> 
        <!-- line 6 first line blank-->         
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_DescCell" style="border-bottom-width:0px;" scope="row">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;">&nbsp;</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-bottom-width:0px;">&nbsp;</td>
    </tr>
        
    <tr>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance&#151;</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell" >
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/EndingBalance"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  >
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/EndingBalance"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos+ 2]/OverallForeignLossAcctBalances/EndingBalance"/>
       </xsl:call-template>
      </td>
    </tr>
   </tbody>         
 </table>
  </div>
    <!--BEGIN FOOTER-->
 <div style="width:187mm">
        <div style="float: left; clear: none;">
           <span class="styBoldText">* Important: </span>
              <span class="styItalicText">See <span class="styBoldText">Computer-Generated Schedule J </span>
           </span>in instructions.
        </div>
           <span style="width:13mm;"></span>
          Cat. No. 10309U 
          <span style="width:29px;"></span>  
          <span class="styBoldText">Schedule J (Form 1118) (Rev. 12-2007)</span>
    </div>     
    <div class="pageEnd"></div>
      <!--END FOOTER-->      
      </xsl:if>
    </xsl:for-each>
  </xsl:if>
  <!-- end display repeating column iii -->
    
        <!-- leftover data table -->
        <br />
        <br />
        <br />
        
<!-- BEGIN Left Over Table -->  
  <!-- Additonal Data Title Bar and Button -->
  <div class="styLeftOverTitleLine" id="LeftoverData">
    <div class="styLeftOverTitle">
      Additional Data        
    </div>
    <div class="styLeftOverButtonContainer">
      <input class="styLeftoverTableBtn" type="button" value="Return to Form" onclick="javascript:returnToWriteInImage();"/>
    </div>      
  </div>
  <!-- Additional Data Table -->
  <table class="styLeftOverTbl">
    <xsl:call-template name="PopulateCommonLeftover">
      <xsl:with-param name="TargetNode" select="$FormData" />
      <xsl:with-param name="DescWidth" select="100"/>
    </xsl:call-template>
  </table>  
<!-- END Left Over Table header -->  

<!-- If the Separate Print Solution is ON and there exists any data for the repeating element -->
<!-- more than once, display the additional data in the table here.                           -->
<xsl:if test="($Print = $Separated) and 
               ( (count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome) &gt; 1) or
                 (count($FormData/OtherIncomeColm) &gt; 1) )">
<!-- this should start blue table -->
<span class="styRepeatingDataTitle" style="width:187mm;">Form 1118 Schedule J, Part I - Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of Limitation Fractions (See instructions.):</span>
<!-- Part I table 1 Start Here-->
	<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;" id="adjSLmInc">
	   <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
	     <thead class="styTableThead" style="display:table-header-group;font-weight:normal;text-align:center;">
	     <tr class="styDepTblHdr">
	      <th class="IRS1118ScheduleJ_GenericCell" style="width:61mm;height:10mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(i)</span><br/>General category income
	      </th>
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(ii)</span><br/>Passive category income
	      </th>
	    
	      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;border-right-width:1px;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	       <span class="styBoldText">(iii)</span>
	<xsl:call-template name="SetFormLinkInline">
	    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]"/>
	</xsl:call-template>
	        <br/>Other income*
	      </th>
	      	      <th class="IRS1118ScheduleJ_GenericCell" style="width:32mm;height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
	        <span class="styBoldText">(iv)</span><br/>U.S. income
	      </th>

	      
	    </tr>
     </thead>
     <tfoot></tfoot>
     <tbody>
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row" >Income or (loss) before adjustments</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeLossBeforeAdjustments"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeLossBeforeAdjustments"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm/IncomeLossBeforeAdjustments"/>
        </xsl:call-template>
      </td>

    </tr>  
    <!-- line 2 left over table -->       
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row">Allocation of separate limitation losses:</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
         <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-top-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-top-width:1px;background-color:lightgrey;"></td>

    </tr> 
    <!-- line 2b leftover -->        
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
            <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
       </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
    </xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"> </td>
   
    </tr>
    <!-- line 2c --> 
   
    <!--Need to show the row c even when there is no data -->
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)">
      <tr class="styDepTblRow1">    
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>
        </td>
         <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;background-color:lightgrey;"></span>)
        </td>

      </tr>
    </xsl:if>
       
    <!-- Tracks the number of rows repeating for c to determine the color that row 3 would start. -->
    <xsl:variable name="twoICounter" select="count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>    
      <!-- If the position of the repeating c row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="position() mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"></td>
    
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->

<!-- Part I, line 3 -->
    <tr>     
      <!-- If the number of data for 2c is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2c</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/IncomeOrLossAndAllocationForCY"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/IncomeOrLossAndAllocationForCY"/>
         </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>

    </tr> 
    <!-- Part I line 4 -->        
    <tr>
      <!-- If the number of data for 2c is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of overall foreign losses</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocnOfOverallForeignLosses"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocnOfOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocnOfOverallForeignLosses"/>
    </xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/AllocnOfOverallForeignLosses"/>
    </xsl:call-template>
      </td>
   
    </tr>         
    <tr>
      <!-- If the number of data for 2c is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of domestic losses</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationOfDomesticLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationOfDomesticLosses"/>
         </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationOfDomesticLosses"/>
       </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/AllocationOfDomesticLosses"/>
       </xsl:call-template>
      </td>

    </tr>         
    <tr>
      <!-- If the number of data for 2c is odd or has no data, set this row to styDepTblRow1. -->
      <!-- Otherwise, set this row to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 3 through 5.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
        <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>

    </tr>         
    <!-- start here -->
      <tr>
      <!-- If the number of data for 2c is odd or has no data, set this row to styDepTblRow2. -->
      <!-- Otherwise, set this row to styDepTblRow1.                                          -->
      <xsl:choose>
        <xsl:when test="( $twoICounter mod 2 = 1 ) or ( $twoICounter = 0 )">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallForeignLosses"/>
         </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
        <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallForeignLosses"/>
       </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/RecaptureOverallForeignLosses"/>
       </xsl:call-template>
      </td>

    </tr>
 

    <!-- Tracks the number of rows repeating for c to determine the color that the row 8 would start. -->
    <xsl:variable name="sevenICount" select="count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)" />
    
    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>    
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.       -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current row to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Combine lines 6 through 7.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
           <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
 
    </tr>         
   <!-- Part I, line 9 for now -->     
   
        <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row">Recharacterization of separate limitation income:</td>
    </tr>  

        <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-top-width:1px;background-color:lightgrey;"></td>

    </tr> 

        <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
       </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/PassiveCategoryIncome"/>
    </xsl:call-template>
      </td>
         <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"> </td>
   
    </tr>

        <xsl:if test="not($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)">
      <tr class="styDepTblRow1">    
        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;"></span>)
        </td>
        
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
          <span class="styTableCellPad"></span>
        </td>
         <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>(<span style="width:16px;background-color:lightgrey;"></span>)
        </td>

      </tr>
    </xsl:if>
    

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>    
      <!-- If the position of the repeating c row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="position() mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AllocationCYSeparateLmtLosses/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
        <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;border-bottom-width:0px;"></td>
    
    </tr>
    </xsl:for-each>         
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.       -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current row to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                  -->      
    <!--  <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      
      <td class="IRS1118ScheduleJ_IndexCell" style="border-top-width:1px;" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-top-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/AdjIncmLossAndLimitationIncm"/>
    </xsl:call-template>
      </td>   -->
    
    <!-- Part I line 10 -->         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.       -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current row to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" valign="top">10</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall domestic
losses</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/RecaptureOverallDomesticLosses"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/RecaptureOverallDomesticLosses"/>
         </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/RecaptureOverallDomesticLosses"/>
    </xsl:call-template>
      </td>
          <td class="IRS1118ScheduleJ_GenericCell" style="border-top-width:1px;border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/USIncomeColm[1]/RecaptureOverallDomesticLosses"/>
    </xsl:call-template>
      </td>
  
    </tr>
    
    <!-- Part I line 11 -->         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.       -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current row to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                  -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" valign="top">11</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction&#151;</span>Combine lines 8 through 10. Enter each result here and on Part II, line 6,
of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
        <xsl:call-template name="PopulateAmount">
         <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/NumeratorOfLimitationFraction"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/NumeratorOfLimitationFraction"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey; border-right-width:0px;" valign="bottom">
  
      </td>

    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.   -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_DescCell" colspan="6" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
        <div class="styTitleName" style="height:4.7mm;">Part II</div>
        <span style="width:3mm;"></span> 
        Year-End Balances of Future Separate Limitation Income That Must Be Recharacterized <span style="font-size:7px;">(section 904(f)(5)(C))</span>
      </td>
    </tr>  
<!-- repeating rows --> 
<!-- Part II, line a -->      
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.   -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
      
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/GeneralCategoryIncome"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/GeneralCategoryIncome"/>
    </xsl:call-template>
      </td>
          <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;">
      </td>
  
    </tr> 
    <!-- Part II, line b -->        
    <tr>
    
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.   -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                              -->
           
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveCategoryIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/PassiveCategoryIncome"/>
    </xsl:call-template>
      </td>
       <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px; background-color:lightgrey;">
      </td>
     
    </tr> 
   
    <xsl:if test="not($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)">
      <tr>
	      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.   -->
	      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current to--> 
	      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
	      <xsl:choose>
	        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
	          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
	        </xsl:when>
	        <xsl:otherwise>
	          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
	        </xsl:otherwise>
	      </xsl:choose>

        <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
        <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
        <td class="IRS1118ScheduleJ_GenericCell">
          <span class="styTableCellPad"></span>
        </td>
       
        <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;">
          <span class="styTableCellPad"></span>
        </td>
      </tr>
    </xsl:if>

    <!-- Tracks the number of rows repeating for i to determine the color the row following c should start. -->
    <xsl:variable name="partTwoICntr" select="count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)"/>   

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="pos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c and 7c.   -->
      <!-- Therefore, if the sum of the number of data for 2c and 7c is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                              -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount ) mod 2 = 1">
          <xsl:choose>
            <xsl:when test="position() mod 2 = 1">
              <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="position() mod 2 = 1">
              <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:otherwise>
      </xsl:choose>
    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;background-color:lightgrey;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/EOYBalancesOfFutureSepLmtIncm/OtherIncome[$pos]"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; border-right-width:0px;background-color:lightgrey;">
      </td>

    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
   	 <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_DescCell" colspan="6" scope="row" style="border-top-width:1px; border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;padding-top:7px;">
        <div class="styTitleName" style="height:4.7mm;">Part III</div>        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:17.5mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/BeginningBalance"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;">
      </td>
      
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
       </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
  <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;">
      </td>

    </tr> 
    <!-- Part III, line 3 -->      
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II c.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II c is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
       <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearReductions"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
    <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey; ">
     </td>

    </tr>
    
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 7)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/CurrentYearRecapture"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/CurrentYearRecapture"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/CurrentYearRecapture"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;border-right-width:0px;background-color:lightgrey;">
       </td>
      
    </tr>
    <!-- Part III, line 6 -->         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance--</span>Subtract line 1 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallForeignLossAcctBalances/EndingBalance"/>
       </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:1px;background-color:lightgrey;border-right-width:0px;">
      </td>

    </tr>
        <!-- Part IV title -->       
    <tr>
   	 <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_DescCell" colspan="6" scope="row" style="border-top-width:1px; border-right-width:0px;font-weight:bold;font-size:8pt;width:256mm;padding-left:0px;height:8mm;padding-top:7px;">
        <div class="styTitleName" style="height:4.7mm;">Part IV</div>        <span style="width:3mm;"></span> 
        Overall Domestic Loss Account Balances (section 904(g)(1))        
      </td>
    </tr>  
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/BeginningBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/BeginningBalance"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px; background-color:lightgrey;border-right-width:0px;">  </td>

    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/CurrentYearAdditions"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/CurrentYearAdditions"/>
       </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
            <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;background-color:lightgrey;border-right-width:0px;">
        </td>

    </tr> 
    <!-- Part IV, line 3 -->      
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II c.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II c is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/CurrentYearReductions"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
       <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/CurrentYearReductions"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
               <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;background-color:lightgrey;border-right-width:0px;">
        </td>
    </tr>
    
    <!-- Part III, line 4 -->         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/Subtotal"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/Subtotal"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
                   <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;background-color:lightgrey;border-right-width:0px;">
</td>
    </tr>         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow1. Otherwise, set it to styDepTblRow2.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 10)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/ OverallDomLossAcctBalances/CurrentYearRecapture"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances /CurrentYearRecapture"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/ OverallDomLossAcctBalances/CurrentYearRecapture"/>
    </xsl:call-template>
      </td>
     <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;background-color:lightgrey;border-right-width:0px;"></td>

    </tr>
    <!-- Part IV, line 6 -->         
    <tr>
      <!-- The color of the current row is dependent on the number of rows in 2c, 7c, and Part II i.   -->
      <!-- Therefore, if the sum of the number of data for 2c, 7c, and Part II i is odd, set current to--> 
      <!-- styDepTblRow2. Otherwise, set it to styDepTblRow1.                                          -->      
      <xsl:choose>
        <xsl:when test="( $twoICounter + $sevenICount + $partTwoICntr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance--</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/GeneralLimitationIncomeColm/OverallDomLossAcctBalances/EndingBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/PassiveIncomeColm/OverallDomLossAcctBalances/EndingBalance"/>
       </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:1px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[1]/OverallDomLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-bottom-width:0px;background-color:lightgrey;border-right-width:0px;"></td>
    </tr>
 

    </tbody>         
  </table>
  </div>

  <!-- display repeating column iii -->
  <!-- the repeating columns of column iii are displayed below -->
  <!-- first column iii -->
  <xsl:if test="count($FormData/OtherIncomeColm) &gt; 1">
    <xsl:for-each select="$FormData/OtherIncomeColm">
      <xsl:variable name="pos" select="position()"/>
      <xsl:if test="$pos mod 9 = 2">
        <!-- //////////////////////////////////////////////////////////////////////////////////////////
        
          Repeat the Whole Table Here 
          
          ///////////////////////////////////////////////////////////////////////////////////////// -->

<!-- Part I-->
<br />
<span class="styRepeatingDataTitle" style="width:187mm;">Column (iii) Repeating data: Form 1118 Schedule J, Parts I, 2, and 3:</span>
<!-- Part I table 1 -->


<div class="IRS1118ScheduleJ_TableContainer" style="border-top-width:0px;border-bottom-width:0px;" id="adjSepLmInc">
   <table class="styDepTbl" cellspacing="0" style="font-size:7pt;">
     <thead class="styTableThead" style="display:table-header-group;">
     <tr class="styDepTblHdr">
      <th class="IRS1118ScheduleJ_GenericCell" style="width:61mm;height:10mm;font-weight:normal;text-align:center;" colspan="2" scope="col">&nbsp;</th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span>
           <xsl:call-template name="SetFormLinkInline">
              <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]"/>
          </xsl:call-template>        
        <br/>Other Income*
      </th>
      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;font-weight:normal;text-align:center;" scope="col">
        <span class="styBoldText">(iii)</span>
          <xsl:call-template name="SetFormLinkInline">
             <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]"/>
          </xsl:call-template>        
        <br/>Other Income*
      </th>
       
      <th class="IRS1118ScheduleJ_GenericCell" style="height:10mm;font-size:7pt;border-right-width:0px;font-weight:normal;text-align:center;" scope="col">
       <span class="styBoldText">(iii)</span>
<xsl:call-template name="SetFormLinkInline">
    <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]"/>
</xsl:call-template>        
        <br/>Other Income*
      </th>
    </tr>
    </thead>
    <tfoot></tfoot>
    <tbody>
    
    <!-- Part I, line 1 -->
    
 <tr class="styDepTblRow1">
     <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;padding-top:7px;">
        <div class="styTitleName" style="height:4.7mm;">Part I</div>
        <span style="width:3mm;"></span><span class="styBoldText">
       Adjustments to Separate Limitation Income or (Losses) in Determining Numerators of <br /><span class="styBoldText" style="width:3mm;"></span>Limitation Fractions </span> <span class="styNormalText">(See Instructions).</span>
      </td>
</tr>
  
    
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Income or (loss) before adjustments (see <br/>instructions).</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeLossBeforeAdjustments"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeLossBeforeAdjustments"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/IncomeLossBeforeAdjustments"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;">Allocation of separate limitation losses:</td>
    </tr>  
    
<!-- repeating rows -->       
    <tr class="styDepTblRow2">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AllocationCYSeparateLmtLosses/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr class="styDepTblRow1">
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AllocationCYSeparateLmtLosses/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr> 
   
    <!-- Tracks the number of rows repeating for c to determine the color that the row after i would start. -->
    <xsl:variable name="twoICtr" select="count($FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/AllocationCYSeparateLmtLosses/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
      <!-- If the position of the repeating c row is odd, then the current row is set to styDepTblRow1. -->
      <!-- Otherwise, the current row is set to styDepTblRow2.                                          -->
      <xsl:choose>
        <xsl:when test="position() mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>       
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:1px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AllocationCYSeparateLmtLosses/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span> combine lines 1 through 2c</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/IncomeOrLossAndAllocationForCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/IncomeOrLossAndAllocationForCY"/>
       </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/IncomeOrLossAndAllocationForCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLosses"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLosses"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/OverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Recapture of overall foreign losses </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
         </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part I, line 6 -->       
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal&#151;</span>Subtract line 5 from line 3.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">7</td>
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;">Recharacterization of separate limitation income:</td>
    </tr>         
<!-- repeating rows --> 
<!-- Part I, line 7a -->      
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
        </xsl:call-template>
      </td>
           
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecharacterizationSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr> 
    
    <!-- Part I, line 7b -->        
    <tr>
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
      <xsl:choose>
        <xsl:when test="$twoICtr mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/PassiveIncome"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/PassiveIncome"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecharacterizationSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr> 
      
      <!-- If the number of data for 2c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                              -->
    
    
    <!-- Tracks the number of rows repeating for c to determine the color that the row after 7c would start. -->
    <xsl:variable name="sevenICtr" select="count($FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome)" />

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/RecharacterizationSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->
    <!-- Part I, line 7c -->      
    <tr>
		 <!-- If the number of repeating 2c rows is odd or there is no data, then set curent row to styDepTblRow1.-->
		 <!-- Otherwise, set it to styDepTblRow2                                                                  -->
		 <xsl:choose>
			 <xsl:when test="$twoICtr mod 2 = 1">
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:when>
			 <xsl:otherwise>
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:otherwise>
		 </xsl:choose>
    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-width:2px;">
         <xsl:call-template name="PopulateNegativeNumber">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;border-width:2px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecharacterizationSepLmtIncm/OtherIncome[$rowpos]"/>
    </xsl:call-template>
      </td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">8</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Combine lines 6 through 7c.</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
        </xsl:call-template>
      </td>
    
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>         
         
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">9</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Enter amounts from Part I, line 8</td>
      <td class="IRS1118ScheduleJ_GenericCell">
          <xsl:call-template name="PopulateAmount">
             <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AdjustedIncomeLossAndAllocnCY"/>
          </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AdjustedIncomeLossAndAllocnCY"/>
         </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AdjustedIncomeLossAndAllocnCY"/>
    </xsl:call-template>
      </td>
    </tr>
    
    <!-- Part I, line 10 -->         
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" valign="top">10</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Allocation of current year U.S. source losses<br/>(see instructions)</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
          <xsl:call-template name="PopulateAmount">
            <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/AllocationCYUSSourcesLosses"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/AllocationCYUSSourcesLosses"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/AllocationCYUSSourcesLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row" valign="top">11</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Numerator of Limitation Fraction--</span>Subtract line 10
        <br/>from line 9.  Enter each result here and on Part II,
        <br/>line 6, of corresponding Schedule B.</td>
      <td class="IRS1118ScheduleJ_GenericCell" valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/NumeratorOfLimitationFraction"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell"  valign="bottom">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/NumeratorOfLimitationFraction"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;" valign="bottom">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/NumeratorOfLimitationFraction"/>
    </xsl:call-template>
      </td>
    </tr>  
    
    <!-- Part II title -->       
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;">
        <div class="styTitleName" style="height:4.7mm;">Part II</div>
        <span style="width:3mm;"></span> 
        Balances of Future Separate Limitation Income That Must Be Recharacterized
      </td>
    </tr>  
<!-- repeating rows -->       
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">a</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">General category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
         </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/EOYBalancesOfFutureSepLmtIncm/GeneralLimitationIncome"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c and 7c is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">b</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Passive category income</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>

      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/EOYBalancesOfFutureSepLmtIncm/PassiveIncome"/>
    </xsl:call-template>
      </td>
    </tr> 
 
    <!-- Tracks the number of rows repeating for c to determine the color that the row following i would start. -->
    <xsl:variable name="partTwoICtr" select="count($FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome)"/>

    <xsl:for-each select="$FormData/GeneralLimitationIncomeColm/EOYBalancesOfFutureSepLmtIncm/OtherIncome">
    <xsl:variable name="rowpos" select="position()"/>   
    <!--///////////////////////////////////////////////////////////////////////////////////
    
      Note that the repeating rows are assumed to be filled in full by the corresponding columns - otherwise there is no way to
      find out how they line up.  Hence the number of repetition are assumed to be the SAME for all columns.
    
    ///////////////////////////////////////////////////////////////////////////////////-->      
    <tr>
		 <!-- If the number of repeating 2c rows and 7c rows is odd, and if the current data position is odd,          -->
		 <!-- then set curent row to styDepTblRow1, but if the current data position is even, set it to styDepTblRow2. -->
		 <!-- Otherwise if the sum of rows in 2c and 7c is even, and if the current data position is set it to         -->
		 <!-- styDepTblRow2, but if the current data position is even then set it to styDepTblRow1.                    -->
		 <xsl:choose>
			 <xsl:when test="( $twoICtr + $sevenICtr ) mod 2 = 1">
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:when>
			 <xsl:otherwise>
			   <xsl:choose>
			     <xsl:when test="position() mod 2 = 1">
			       <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
			     </xsl:when>
			     <xsl:otherwise>
			       <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
			     </xsl:otherwise>
			   </xsl:choose>
			 </xsl:otherwise>
		 </xsl:choose>
    
      <td class="IRS1118ScheduleJ_SubIndexCell" scope="row">c</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Other Income*</td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="background-color:lightgrey;"></td>
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;background-color:lightgrey;"></td>
    </tr>
    </xsl:for-each>         
<!-- end repeating rows -->
    <!-- Part III title -->       
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_DescCell" colspan="5" scope="row" style="border-right-width:0px;font-weight:bold;font-size:8pt;width:187mm;padding-left:0px;height:8mm;padding-top:7px;">
       <div class="styTitleName" style="height:4.7mm;">Part III</div>
        <span style="width:3mm;"></span> 
        Overall Foreign Loss Account Balances (section 904(f)(1))<br/><span style="padding-left:3mm;">
        <span style="font-style:italic;font-weight:normal;">Complete for <span style="font-weight:bold;">each </span>
        separate limitation income category</span></span>
      </td>
    </tr>  
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>      
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">1</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Beginning balance</td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/BeginningBalance"/>
        </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/BeginningBalance"/>
        </xsl:call-template>
      </td>
      
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/OverallForeignLossAcctBalances/BeginningBalance"/>
    </xsl:call-template>
      </td>
    </tr>   
    <!-- Part III, line 2 -->      
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">2</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year additions</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/OverallForeignLossAcctBalances/CurrentYearAdditions"/>
    </xsl:call-template>
      </td>
    </tr>
    <!-- part III, line 3 -->         
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">3</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year reductions (other than recapture)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateNegativeNumber">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateNegativeNumber">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/OverallForeignLossAcctBalances/CurrentYearReductions"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow2.  -->      
      <!-- Otherwise, set it to styDepTblRow1.                                                     -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">4</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Subtotal--</span>Combine lines 1 through 3</td>
      <td class="IRS1118ScheduleJ_GenericCell">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/Subtotal"/>
         </xsl:call-template>
      </td>
           
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/OverallForeignLossAcctBalances/Subtotal"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">5</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row">Current year recapture (from Part I, line 5)</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/RecaptureOverallForeignLosses"/>
         </xsl:call-template>    
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/RecaptureOverallForeignLosses"/>
        </xsl:call-template>
      </td>
   
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/RecaptureOverallForeignLosses"/>
    </xsl:call-template>
      </td>
    </tr>         
    <tr>
      <!-- If the number of data for 2c, 7c, and Part II i is odd, then set the current row to styDepTblRow1.  -->      
      <!-- Otherwise, set it to styDepTblRow2.                                                                 -->
      <xsl:choose>
        <xsl:when test="( $twoICtr + $sevenICtr + $partTwoICtr ) mod 2 = 1">
          <xsl:attribute name="class">styDepTblRow1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">styDepTblRow2</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>    
      <td class="IRS1118ScheduleJ_IndexCell" scope="row">6</td>
      <td class="IRS1118ScheduleJ_DescCell" scope="row"><span style="font-weight:bold;">Ending balance--</span>Subtract line 5 from line 4</td>
      <td class="IRS1118ScheduleJ_GenericCell">
         <xsl:call-template name="PopulateAmount">
           <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos]/OverallForeignLossAcctBalances/EndingBalance"/>
         </xsl:call-template>
      </td>
      <td class="IRS1118ScheduleJ_GenericCell">
        <xsl:call-template name="PopulateAmount">
          <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 1]/OverallForeignLossAcctBalances/EndingBalance"/>
        </xsl:call-template>
      </td>
     
      <td class="IRS1118ScheduleJ_GenericCell" style="border-right-width:0px;">
    <xsl:call-template name="PopulateAmount">
      <xsl:with-param name="TargetNode" select="$FormData/OtherIncomeColm[$pos + 2]/OverallForeignLossAcctBalances/EndingBalance"/>
    </xsl:call-template>
      </td>
    </tr>
    </tbody>         
  </table>
  </div>
      </xsl:if>
    </xsl:for-each>
  </xsl:if>
</xsl:if>

   </body>
</html>
</xsl:template>

</xsl:stylesheet>
